Class: Lob::AddressDomestic
- Inherits:
-
Object
- Object
- Lob::AddressDomestic
- Defined in:
- lib/lob/models/address_domestic.rb
Instance Attribute Summary collapse
-
#address_city ⇒ Object
Returns the value of attribute address_city.
-
#address_country ⇒ Object
The country associated with this address.
-
#address_line1 ⇒ Object
The building number, street name, street suffix, and any street directionals.
-
#address_line2 ⇒ Object
The suite or apartment number of the recipient address, if applicable.
-
#address_state ⇒ Object
Returns the value of attribute address_state.
-
#address_zip ⇒ Object
Optional postal code.
-
#company ⇒ Object
Either ‘name` or `company` is required, you may also add both.
-
#description ⇒ Object
An internal description that identifies this resource.
-
#email ⇒ Object
Must be no longer than 100 characters.
-
#metadata ⇒ Object
Use metadata to store custom information for tagging and labeling back to your internal systems.
-
#name ⇒ Object
Either ‘name` or `company` is required, you may also add both.
-
#phone ⇒ Object
Must be no longer than 40 characters.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AddressDomestic
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AddressDomestic
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/lob/models/address_domestic.rb', line 111 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::AddressDomestic` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::AddressDomestic`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'address_line1') self.address_line1 = attributes[:'address_line1'] end if attributes.key?(:'address_line2') self.address_line2 = attributes[:'address_line2'] end if attributes.key?(:'address_city') self.address_city = attributes[:'address_city'] end if attributes.key?(:'address_state') self.address_state = attributes[:'address_state'] end if attributes.key?(:'address_zip') self.address_zip = attributes[:'address_zip'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'company') self.company = attributes[:'company'] end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'address_country') self.address_country = attributes[:'address_country'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end end |
Instance Attribute Details
#address_city ⇒ Object
Returns the value of attribute address_city.
24 25 26 |
# File 'lib/lob/models/address_domestic.rb', line 24 def address_city @address_city end |
#address_country ⇒ Object
The country associated with this address.
47 48 49 |
# File 'lib/lob/models/address_domestic.rb', line 47 def address_country @address_country end |
#address_line1 ⇒ Object
The building number, street name, street suffix, and any street directionals. For US addresses, the max length is 64 characters.
19 20 21 |
# File 'lib/lob/models/address_domestic.rb', line 19 def address_line1 @address_line1 end |
#address_line2 ⇒ Object
The suite or apartment number of the recipient address, if applicable. For US addresses, the max length is 64 characters.
22 23 24 |
# File 'lib/lob/models/address_domestic.rb', line 22 def address_line2 @address_line2 end |
#address_state ⇒ Object
Returns the value of attribute address_state.
26 27 28 |
# File 'lib/lob/models/address_domestic.rb', line 26 def address_state @address_state end |
#address_zip ⇒ Object
Optional postal code. For US addresses, must be either 5 or 9 digits.
29 30 31 |
# File 'lib/lob/models/address_domestic.rb', line 29 def address_zip @address_zip end |
#company ⇒ Object
Either ‘name` or `company` is required, you may also add both.
38 39 40 |
# File 'lib/lob/models/address_domestic.rb', line 38 def company @company end |
#description ⇒ Object
An internal description that identifies this resource. Must be no longer than 255 characters.
32 33 34 |
# File 'lib/lob/models/address_domestic.rb', line 32 def description @description end |
#email ⇒ Object
Must be no longer than 100 characters.
44 45 46 |
# File 'lib/lob/models/address_domestic.rb', line 44 def email @email end |
#metadata ⇒ Object
Use metadata to store custom information for tagging and labeling back to your internal systems. Must be an object with up to 20 key-value pairs. Keys must be at most 40 characters and values must be at most 500 characters. Neither can contain the characters ‘"` and `\`. i.e. ’: "NEWYORK2015"‘ Nested objects are not supported. See [Metadata](#section/Metadata) for more information.
50 51 52 |
# File 'lib/lob/models/address_domestic.rb', line 50 def @metadata end |
#name ⇒ Object
Either ‘name` or `company` is required, you may also add both. Must be no longer than 40 characters. If both `name` and `company` are provided, they will be printed on two separate lines above the rest of the address.
35 36 37 |
# File 'lib/lob/models/address_domestic.rb', line 35 def name @name end |
#phone ⇒ Object
Must be no longer than 40 characters.
41 42 43 |
# File 'lib/lob/models/address_domestic.rb', line 41 def phone @phone end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/lob/models/address_domestic.rb', line 71 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/lob/models/address_domestic.rb', line 53 def self.attribute_map { :'address_line1' => :'address_line1', :'address_line2' => :'address_line2', :'address_city' => :'address_city', :'address_state' => :'address_state', :'address_zip' => :'address_zip', :'description' => :'description', :'name' => :'name', :'company' => :'company', :'phone' => :'phone', :'email' => :'email', :'address_country' => :'address_country', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
396 397 398 |
# File 'lib/lob/models/address_domestic.rb', line 396 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/lob/models/address_domestic.rb', line 94 def self.openapi_nullable Set.new([ :'address_line2', :'address_city', :'address_state', :'address_zip', :'description', :'name', :'company', :'phone', :'email', :'address_country', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/lob/models/address_domestic.rb', line 76 def self.openapi_types { :'address_line1' => :'String', :'address_line2' => :'String', :'address_city' => :'String', :'address_state' => :'String', :'address_zip' => :'String', :'description' => :'String', :'name' => :'String', :'company' => :'String', :'phone' => :'String', :'email' => :'String', :'address_country' => :'String', :'metadata' => :'Hash<String, String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/lob/models/address_domestic.rb', line 363 def ==(o) return true if self.equal?(o) self.class == o.class && address_line1 == o.address_line1 && address_line2 == o.address_line2 && address_city == o.address_city && address_state == o.address_state && address_zip == o.address_zip && description == o.description && name == o.name && company == o.company && phone == o.phone && email == o.email && address_country == o.address_country && == o. end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/lob/models/address_domestic.rb', line 435 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Lob.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
506 507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/lob/models/address_domestic.rb', line 506 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/lob/models/address_domestic.rb', line 403 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) # // guardrails-disable-line elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line end elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array) for base_type in type do res = _deserialize(base_type, attributes[self.class.attribute_map[key]]) if !res.nil? self.send("#{key}=", res) # // guardrails-disable-line break end end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line end end self end |
#eql?(o) ⇒ Boolean
382 383 384 |
# File 'lib/lob/models/address_domestic.rb', line 382 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
388 389 390 |
# File 'lib/lob/models/address_domestic.rb', line 388 def hash [address_line1, address_line2, address_city, address_state, address_zip, description, name, company, phone, email, address_country, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/lob/models/address_domestic.rb', line 177 def list_invalid_properties invalid_properties = Array.new if !@address_line1.nil? && @address_line1.to_s.length > 200 invalid_properties.push('invalid value for "address_line1", the character length must be smaller than or equal to 200.') end if !@address_line2.nil? && @address_line2.to_s.length > 200 invalid_properties.push('invalid value for "address_line2", the character length must be smaller than or equal to 200.') end if !@address_city.nil? && @address_city.to_s.length > 200 invalid_properties.push('invalid value for "address_city", the character length must be smaller than or equal to 200.') end if !@address_state.nil? && @address_state.to_s.length > 200 invalid_properties.push('invalid value for "address_state", the character length must be smaller than or equal to 200.') end if !@address_zip.nil? && @address_zip.to_s.length > 40 invalid_properties.push('invalid value for "address_zip", the character length must be smaller than or equal to 40.') end if !@description.nil? && @description.to_s.length > 255 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.') end if !@name.nil? && @name.to_s.length > 40 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 40.') end if !@company.nil? && @company.to_s.length > 40 invalid_properties.push('invalid value for "company", the character length must be smaller than or equal to 40.') end if !@phone.nil? && @phone.to_s.length > 40 invalid_properties.push('invalid value for "phone", the character length must be smaller than or equal to 40.') end if !@email.nil? && @email.to_s.length > 100 invalid_properties.push('invalid value for "email", the character length must be smaller than or equal to 100.') end pattern = Regexp.new(/US/) if !@address_country.nil? && @address_country !~ pattern invalid_properties.push("invalid value for \"address_country\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
482 483 484 |
# File 'lib/lob/models/address_domestic.rb', line 482 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
488 489 490 491 492 493 494 495 496 497 498 499 500 |
# File 'lib/lob/models/address_domestic.rb', line 488 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) # // guardrails-disable-line if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
476 477 478 |
# File 'lib/lob/models/address_domestic.rb', line 476 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/lob/models/address_domestic.rb', line 229 def valid? return false if !@address_line1.nil? && @address_line1.to_s.length > 200 return false if !@address_line2.nil? && @address_line2.to_s.length > 200 return false if !@address_city.nil? && @address_city.to_s.length > 200 return false if !@address_state.nil? && @address_state.to_s.length > 200 return false if !@address_zip.nil? && @address_zip.to_s.length > 40 return false if !@description.nil? && @description.to_s.length > 255 return false if !@name.nil? && @name.to_s.length > 40 return false if !@company.nil? && @company.to_s.length > 40 return false if !@phone.nil? && @phone.to_s.length > 40 return false if !@email.nil? && @email.to_s.length > 100 return false if !@address_country.nil? && @address_country !~ Regexp.new(/US/) true end |