Class: Lob::Buckslip

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/buckslip.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Buckslip

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/lob/models/buckslip.rb', line 172

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::Buckslip` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::Buckslip`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'auto_reorder')
    self.auto_reorder = attributes[:'auto_reorder']
  else
    self.auto_reorder = false
  end

  if attributes.key?(:'reorder_quantity')
    self.reorder_quantity = attributes[:'reorder_quantity']
  end

  if attributes.key?(:'threshold_amount')
    self.threshold_amount = attributes[:'threshold_amount']
  else
    self.threshold_amount = 0
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'raw_url')
    self.raw_url = attributes[:'raw_url']
  end

  if attributes.key?(:'front_original_url')
    self.front_original_url = attributes[:'front_original_url']
  end

  if attributes.key?(:'back_original_url')
    self.back_original_url = attributes[:'back_original_url']
  end

  if attributes.key?(:'thumbnails')
    if (value = attributes[:'thumbnails']).is_a?(Array)
      self.thumbnails = value
    end
  end

  if attributes.key?(:'available_quantity')
    self.available_quantity = attributes[:'available_quantity']
  else
    self.available_quantity = 0
  end

  if attributes.key?(:'allocated_quantity')
    self.allocated_quantity = attributes[:'allocated_quantity']
  else
    self.allocated_quantity = 0
  end

  if attributes.key?(:'onhand_quantity')
    self.onhand_quantity = attributes[:'onhand_quantity']
  else
    self.onhand_quantity = 0
  end

  if attributes.key?(:'pending_quantity')
    self.pending_quantity = attributes[:'pending_quantity']
  else
    self.pending_quantity = 0
  end

  if attributes.key?(:'projected_quantity')
    self.projected_quantity = attributes[:'projected_quantity']
  else
    self.projected_quantity = 0
  end

  if attributes.key?(:'buckslip_orders')
    if (value = attributes[:'buckslip_orders']).is_a?(Array)
      self.buckslip_orders = value
    end
  end

  if attributes.key?(:'stock')
    self.stock = attributes[:'stock']
  end

  if attributes.key?(:'weight')
    self.weight = attributes[:'weight']
  end

  if attributes.key?(:'finish')
    self.finish = attributes[:'finish']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = 'buckslip'
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  else
    self.size = '8.75x3.75'
  end
end

Instance Attribute Details

#allocated_quantityObject

The allocated quantity of buckslips.



48
49
50
# File 'lib/lob/models/buckslip.rb', line 48

def allocated_quantity
  @allocated_quantity
end

#auto_reorderObject

True if the buckslips should be auto-reordered.



22
23
24
# File 'lib/lob/models/buckslip.rb', line 22

def auto_reorder
  @auto_reorder
end

#available_quantityObject

The available quantity of buckslips.



45
46
47
# File 'lib/lob/models/buckslip.rb', line 45

def available_quantity
  @available_quantity
end

#back_original_urlObject

The original URL of the back template.



40
41
42
# File 'lib/lob/models/buckslip.rb', line 40

def back_original_url
  @back_original_url
end

#buckslip_ordersObject

An array of buckslip orders that are associated with the buckslip.



60
61
62
# File 'lib/lob/models/buckslip.rb', line 60

def buckslip_orders
  @buckslip_orders
end

#descriptionObject

Description of the buckslip.



74
75
76
# File 'lib/lob/models/buckslip.rb', line 74

def description
  @description
end

#finishObject

Returns the value of attribute finish.



66
67
68
# File 'lib/lob/models/buckslip.rb', line 66

def finish
  @finish
end

#front_original_urlObject

The original URL of the front template.



37
38
39
# File 'lib/lob/models/buckslip.rb', line 37

def front_original_url
  @front_original_url
end

#idObject

Unique identifier prefixed with ‘bck_`.



19
20
21
# File 'lib/lob/models/buckslip.rb', line 19

def id
  @id
end

#objectObject

object



71
72
73
# File 'lib/lob/models/buckslip.rb', line 71

def object
  @object
end

#onhand_quantityObject

The onhand quantity of buckslips.



51
52
53
# File 'lib/lob/models/buckslip.rb', line 51

def onhand_quantity
  @onhand_quantity
end

#pending_quantityObject

The pending quantity of buckslips.



54
55
56
# File 'lib/lob/models/buckslip.rb', line 54

def pending_quantity
  @pending_quantity
end

#projected_quantityObject

The sum of pending and onhand quantities of buckslips.



57
58
59
# File 'lib/lob/models/buckslip.rb', line 57

def projected_quantity
  @projected_quantity
end

#raw_urlObject

The raw URL of the buckslip.



34
35
36
# File 'lib/lob/models/buckslip.rb', line 34

def raw_url
  @raw_url
end

#reorder_quantityObject

The number of buckslips to be reordered.



25
26
27
# File 'lib/lob/models/buckslip.rb', line 25

def reorder_quantity
  @reorder_quantity
end

#sizeObject

The size of the buckslip



77
78
79
# File 'lib/lob/models/buckslip.rb', line 77

def size
  @size
end

#statusObject

Returns the value of attribute status.



68
69
70
# File 'lib/lob/models/buckslip.rb', line 68

def status
  @status
end

#stockObject

Returns the value of attribute stock.



62
63
64
# File 'lib/lob/models/buckslip.rb', line 62

def stock
  @stock
end

#threshold_amountObject

The threshold amount of the buckslip



28
29
30
# File 'lib/lob/models/buckslip.rb', line 28

def threshold_amount
  @threshold_amount
end

#thumbnailsObject

Returns the value of attribute thumbnails.



42
43
44
# File 'lib/lob/models/buckslip.rb', line 42

def thumbnails
  @thumbnails
end

#urlObject

The signed link for the buckslip.



31
32
33
# File 'lib/lob/models/buckslip.rb', line 31

def url
  @url
end

#weightObject

Returns the value of attribute weight.



64
65
66
# File 'lib/lob/models/buckslip.rb', line 64

def weight
  @weight
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



130
131
132
# File 'lib/lob/models/buckslip.rb', line 130

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/lob/models/buckslip.rb', line 102

def self.attribute_map
  {
    :'id' => :'id',
    :'auto_reorder' => :'auto_reorder',
    :'reorder_quantity' => :'reorder_quantity',
    :'threshold_amount' => :'threshold_amount',
    :'url' => :'url',
    :'raw_url' => :'raw_url',
    :'front_original_url' => :'front_original_url',
    :'back_original_url' => :'back_original_url',
    :'thumbnails' => :'thumbnails',
    :'available_quantity' => :'available_quantity',
    :'allocated_quantity' => :'allocated_quantity',
    :'onhand_quantity' => :'onhand_quantity',
    :'pending_quantity' => :'pending_quantity',
    :'projected_quantity' => :'projected_quantity',
    :'buckslip_orders' => :'buckslip_orders',
    :'stock' => :'stock',
    :'weight' => :'weight',
    :'finish' => :'finish',
    :'status' => :'status',
    :'object' => :'object',
    :'description' => :'description',
    :'size' => :'size'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



688
689
690
# File 'lib/lob/models/buckslip.rb', line 688

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



163
164
165
166
167
168
# File 'lib/lob/models/buckslip.rb', line 163

def self.openapi_nullable
  Set.new([
    :'reorder_quantity',
    :'description',
  ])
end

.openapi_typesObject

Attribute type mapping.



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/lob/models/buckslip.rb', line 135

def self.openapi_types
  {
    :'id' => :'String',
    :'auto_reorder' => :'Boolean',
    :'reorder_quantity' => :'Integer',
    :'threshold_amount' => :'Integer',
    :'url' => :'String',
    :'raw_url' => :'String',
    :'front_original_url' => :'String',
    :'back_original_url' => :'String',
    :'thumbnails' => :'Array<Thumbnail>',
    :'available_quantity' => :'Float',
    :'allocated_quantity' => :'Float',
    :'onhand_quantity' => :'Float',
    :'pending_quantity' => :'Float',
    :'projected_quantity' => :'Float',
    :'buckslip_orders' => :'Array<BuckslipOrder>',
    :'stock' => :'String',
    :'weight' => :'String',
    :'finish' => :'String',
    :'status' => :'String',
    :'object' => :'String',
    :'description' => :'String',
    :'size' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
# File 'lib/lob/models/buckslip.rb', line 645

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      auto_reorder == o.auto_reorder &&
      reorder_quantity == o.reorder_quantity &&
      threshold_amount == o.threshold_amount &&
      url == o.url &&
      raw_url == o.raw_url &&
      front_original_url == o.front_original_url &&
      back_original_url == o.back_original_url &&
      thumbnails == o.thumbnails &&
      available_quantity == o.available_quantity &&
      allocated_quantity == o.allocated_quantity &&
      onhand_quantity == o.onhand_quantity &&
      pending_quantity == o.pending_quantity &&
      projected_quantity == o.projected_quantity &&
      buckslip_orders == o.buckslip_orders &&
      stock == o.stock &&
      weight == o.weight &&
      finish == o.finish &&
      status == o.status &&
      object == o.object &&
      description == o.description &&
      size == o.size
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
# File 'lib/lob/models/buckslip.rb', line 727

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



798
799
800
801
802
803
804
805
806
807
808
809
810
# File 'lib/lob/models/buckslip.rb', line 798

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
# File 'lib/lob/models/buckslip.rb', line 695

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


674
675
676
# File 'lib/lob/models/buckslip.rb', line 674

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



680
681
682
# File 'lib/lob/models/buckslip.rb', line 680

def hash
  [id, auto_reorder, reorder_quantity, threshold_amount, url, raw_url, front_original_url, back_original_url, thumbnails, available_quantity, allocated_quantity, onhand_quantity, pending_quantity, projected_quantity, buckslip_orders, stock, weight, finish, status, object, description, size].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/lob/models/buckslip.rb', line 298

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  pattern = Regexp.new(/^bck_[a-zA-Z0-9]+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if @auto_reorder.nil?
    invalid_properties.push('invalid value for "auto_reorder", auto_reorder cannot be nil.')
  end

  if @threshold_amount.nil?
    invalid_properties.push('invalid value for "threshold_amount", threshold_amount cannot be nil.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @url.to_s.length > 2083
    invalid_properties.push('invalid value for "url", the character length must be smaller than or equal to 2083.')
  end

  if @url.to_s.length < 1
    invalid_properties.push('invalid value for "url", the character length must be great than or equal to 1.')
  end

  if @raw_url.nil?
    invalid_properties.push('invalid value for "raw_url", raw_url cannot be nil.')
  end

  if @raw_url.to_s.length > 2083
    invalid_properties.push('invalid value for "raw_url", the character length must be smaller than or equal to 2083.')
  end

  if @raw_url.to_s.length < 1
    invalid_properties.push('invalid value for "raw_url", the character length must be great than or equal to 1.')
  end

  if @front_original_url.nil?
    invalid_properties.push('invalid value for "front_original_url", front_original_url cannot be nil.')
  end

  if @front_original_url.to_s.length > 2083
    invalid_properties.push('invalid value for "front_original_url", the character length must be smaller than or equal to 2083.')
  end

  if @front_original_url.to_s.length < 1
    invalid_properties.push('invalid value for "front_original_url", the character length must be great than or equal to 1.')
  end

  if @back_original_url.nil?
    invalid_properties.push('invalid value for "back_original_url", back_original_url cannot be nil.')
  end

  if @back_original_url.to_s.length > 2083
    invalid_properties.push('invalid value for "back_original_url", the character length must be smaller than or equal to 2083.')
  end

  if @back_original_url.to_s.length < 1
    invalid_properties.push('invalid value for "back_original_url", the character length must be great than or equal to 1.')
  end

  if @thumbnails.nil?
    invalid_properties.push('invalid value for "thumbnails", thumbnails cannot be nil.')
  end

  if @available_quantity.nil?
    invalid_properties.push('invalid value for "available_quantity", available_quantity cannot be nil.')
  end

  if @allocated_quantity.nil?
    invalid_properties.push('invalid value for "allocated_quantity", allocated_quantity cannot be nil.')
  end

  if @onhand_quantity.nil?
    invalid_properties.push('invalid value for "onhand_quantity", onhand_quantity cannot be nil.')
  end

  if @pending_quantity.nil?
    invalid_properties.push('invalid value for "pending_quantity", pending_quantity cannot be nil.')
  end

  if @projected_quantity.nil?
    invalid_properties.push('invalid value for "projected_quantity", projected_quantity cannot be nil.')
  end

  if @buckslip_orders.nil?
    invalid_properties.push('invalid value for "buckslip_orders", buckslip_orders cannot be nil.')
  end

  if @buckslip_orders.length < 0
    invalid_properties.push('invalid value for "buckslip_orders", number of items must be greater than or equal to 0.')
  end

  if @stock.nil?
    invalid_properties.push('invalid value for "stock", stock cannot be nil.')
  end

  if @weight.nil?
    invalid_properties.push('invalid value for "weight", weight cannot be nil.')
  end

  if @finish.nil?
    invalid_properties.push('invalid value for "finish", finish cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  if @description.to_s.length > 255
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



774
775
776
# File 'lib/lob/models/buckslip.rb', line 774

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



780
781
782
783
784
785
786
787
788
789
790
791
792
# File 'lib/lob/models/buckslip.rb', line 780

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



768
769
770
# File 'lib/lob/models/buckslip.rb', line 768

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
# File 'lib/lob/models/buckslip.rb', line 426

def valid?
  return false if @id.nil?
  return false if @id !~ Regexp.new(/^bck_[a-zA-Z0-9]+$/)
  return false if @auto_reorder.nil?
  return false if @threshold_amount.nil?
  return false if @url.nil?
  return false if @url.to_s.length > 2083
  return false if @url.to_s.length < 1
  return false if @raw_url.nil?
  return false if @raw_url.to_s.length > 2083
  return false if @raw_url.to_s.length < 1
  return false if @front_original_url.nil?
  return false if @front_original_url.to_s.length > 2083
  return false if @front_original_url.to_s.length < 1
  return false if @back_original_url.nil?
  return false if @back_original_url.to_s.length > 2083
  return false if @back_original_url.to_s.length < 1
  return false if @thumbnails.nil?
  return false if @available_quantity.nil?
  return false if @allocated_quantity.nil?
  return false if @onhand_quantity.nil?
  return false if @pending_quantity.nil?
  return false if @projected_quantity.nil?
  return false if @buckslip_orders.nil?
  return false if @buckslip_orders.length < 0
  return false if @stock.nil?
  stock_validator = EnumAttributeValidator.new('String', ["text", "cover"])
  return false unless stock_validator.valid?(@stock)
  return false if @weight.nil?
  weight_validator = EnumAttributeValidator.new('String', ["80#"])
  return false unless weight_validator.valid?(@weight)
  return false if @finish.nil?
  finish_validator = EnumAttributeValidator.new('String', ["gloss", "matte"])
  return false unless finish_validator.valid?(@finish)
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["processed", "rendered"])
  return false unless status_validator.valid?(@status)
  return false if @object.nil?
  object_validator = EnumAttributeValidator.new('String', ["buckslip"])
  return false unless object_validator.valid?(@object)
  return false if @description.to_s.length > 255
  size_validator = EnumAttributeValidator.new('String', ["8.75x3.75"])
  return false unless size_validator.valid?(@size)
  true
end