Class: Lob::BuckslipOrdersApi
- Inherits:
-
Object
- Object
- Lob::BuckslipOrdersApi
- Defined in:
- lib/lob/api/buckslip_orders_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#buckslip_order_create_with_http_info(buckslip_id, buckslip_order_editable, opts = {}) ⇒ Array<(BuckslipOrder, Integer, Hash)>
create Creates a new buckslip order given information.
-
#buckslip_orders_retrieve_with_http_info(buckslip_id, opts = {}) ⇒ Array<(BuckslipOrdersList, Integer, Hash)>
get Retrieves the buckslip orders associated with the given buckslip id.
-
#create(buckslip_id, buckslip_order_editable, opts = {}) ⇒ BuckslipOrder
create Creates a new buckslip order given information.
-
#get(buckslip_id, opts = {}) ⇒ BuckslipOrdersList
get Retrieves the buckslip orders associated with the given buckslip id.
-
#initialize(api_client = ApiClient.default) ⇒ BuckslipOrdersApi
constructor
A new instance of BuckslipOrdersApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ BuckslipOrdersApi
Returns a new instance of BuckslipOrdersApi.
19 20 21 |
# File 'lib/lob/api/buckslip_orders_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/lob/api/buckslip_orders_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#buckslip_order_create_with_http_info(buckslip_id, buckslip_order_editable, opts = {}) ⇒ Array<(BuckslipOrder, Integer, Hash)>
create Creates a new buckslip order given information
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/lob/api/buckslip_orders_api.rb', line 39 def buckslip_order_create_with_http_info(buckslip_id, buckslip_order_editable, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BuckslipOrdersApi.buckslip_order_create ...' end # verify the required parameter 'buckslip_id' is set if @api_client.config.client_side_validation && buckslip_id.nil? fail ArgumentError, "Missing the required parameter 'buckslip_id' when calling BuckslipOrdersApi.buckslip_order_create" end pattern = Regexp.new(/^bck_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && buckslip_id !~ pattern fail ArgumentError, "invalid value for 'buckslip_id' when calling BuckslipOrdersApi.buckslip_order_create, must conform to the pattern #{pattern}." end # verify the required parameter 'buckslip_order_editable' is set if @api_client.config.client_side_validation && buckslip_order_editable.nil? fail ArgumentError, "Missing the required parameter 'buckslip_order_editable' when calling BuckslipOrdersApi.buckslip_order_create" end # resource path local_var_path = '/buckslips/{buckslip_id}/orders'.sub('{' + 'buckslip_id' + '}', CGI.escape(buckslip_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(buckslip_order_editable) # return_type return_type = opts[:debug_return_type] || 'BuckslipOrder' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"BuckslipOrdersApi.buckslip_order_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BuckslipOrdersApi#buckslip_order_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#buckslip_orders_retrieve_with_http_info(buckslip_id, opts = {}) ⇒ Array<(BuckslipOrdersList, Integer, Hash)>
get Retrieves the buckslip orders associated with the given buckslip id.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/lob/api/buckslip_orders_api.rb', line 120 def buckslip_orders_retrieve_with_http_info(buckslip_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BuckslipOrdersApi.buckslip_orders_retrieve ...' end # verify the required parameter 'buckslip_id' is set if @api_client.config.client_side_validation && buckslip_id.nil? fail ArgumentError, "Missing the required parameter 'buckslip_id' when calling BuckslipOrdersApi.buckslip_orders_retrieve" end pattern = Regexp.new(/^bck_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && buckslip_id !~ pattern fail ArgumentError, "invalid value for 'buckslip_id' when calling BuckslipOrdersApi.buckslip_orders_retrieve, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling BuckslipOrdersApi.buckslip_orders_retrieve, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling BuckslipOrdersApi.buckslip_orders_retrieve, must be greater than or equal to 1.' end # resource path local_var_path = '/buckslips/{buckslip_id}/orders'.sub('{' + 'buckslip_id' + '}', CGI.escape(buckslip_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'BuckslipOrdersList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"BuckslipOrdersApi.buckslip_orders_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BuckslipOrdersApi#buckslip_orders_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create(buckslip_id, buckslip_order_editable, opts = {}) ⇒ BuckslipOrder
create Creates a new buckslip order given information
28 29 30 31 |
# File 'lib/lob/api/buckslip_orders_api.rb', line 28 def create(buckslip_id, buckslip_order_editable, opts = {}) data, _status_code, _headers = buckslip_order_create_with_http_info(buckslip_id, buckslip_order_editable, opts) data end |
#get(buckslip_id, opts = {}) ⇒ BuckslipOrdersList
get Retrieves the buckslip orders associated with the given buckslip id.
108 109 110 111 |
# File 'lib/lob/api/buckslip_orders_api.rb', line 108 def get(buckslip_id, opts = {}) data, _status_code, _headers = buckslip_orders_retrieve_with_http_info(buckslip_id, opts) data end |