Class: Lob::BuckslipsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/api/buckslips_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ BuckslipsApi

Returns a new instance of BuckslipsApi.



19
20
21
# File 'lib/lob/api/buckslips_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/lob/api/buckslips_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#buckslip_create_with_http_info(buckslip_editable, opts = {}) ⇒ Array<(Buckslip, Integer, Hash)>

create Creates a new buckslip given information

Parameters:

  • buckslip_editable (BuckslipEditable)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :front (Object)

    An optional file upload as either a byte array or file type.

Returns:

  • (Array<(Buckslip, Integer, Hash)>)

    Buckslip data, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/lob/api/buckslips_api.rb', line 39

def buckslip_create_with_http_info(buckslip_editable, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BuckslipsApi.buckslip_create ...'
  end
  # verify the required parameter 'buckslip_editable' is set
  if @api_client.config.client_side_validation && buckslip_editable.nil?
    fail ArgumentError, "Missing the required parameter 'buckslip_editable' when calling BuckslipsApi.buckslip_create"
  end
  # resource path
  local_var_path = '/buckslips'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'front'] = opts[:'front'] if !opts[:'front'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(buckslip_editable)

  # return_type
  return_type = opts[:debug_return_type] || 'Buckslip'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"BuckslipsApi.buckslip_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BuckslipsApi#buckslip_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#buckslip_delete_with_http_info(buckslip_id, opts = {}) ⇒ Array<(BuckslipDeletion, Integer, Hash)>

delete Delete an existing buckslip. You need only supply the unique identifier that was returned upon buckslip creation.

Parameters:

  • buckslip_id (String)

    id of the buckslip

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(BuckslipDeletion, Integer, Hash)>)

    BuckslipDeletion data, response status code and response headers



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/lob/api/buckslips_api.rb', line 108

def buckslip_delete_with_http_info(buckslip_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BuckslipsApi.buckslip_delete ...'
  end
  # verify the required parameter 'buckslip_id' is set
  if @api_client.config.client_side_validation && buckslip_id.nil?
    fail ArgumentError, "Missing the required parameter 'buckslip_id' when calling BuckslipsApi.buckslip_delete"
  end
  pattern = Regexp.new(/^bck_[a-zA-Z0-9]+$/)
  if @api_client.config.client_side_validation && buckslip_id !~ pattern
    fail ArgumentError, "invalid value for 'buckslip_id' when calling BuckslipsApi.buckslip_delete, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/buckslips/{buckslip_id}'.sub('{' + 'buckslip_id' + '}', CGI.escape(buckslip_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'BuckslipDeletion'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"BuckslipsApi.buckslip_delete",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BuckslipsApi#buckslip_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#buckslip_retrieve_with_http_info(buckslip_id, opts = {}) ⇒ Array<(Buckslip, Integer, Hash)>

get Retrieves the details of an existing buckslip. You need only supply the unique customer identifier that was returned upon buckslip creation.

Parameters:

  • buckslip_id (String)

    id of the buckslip

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Buckslip, Integer, Hash)>)

    Buckslip data, response status code and response headers



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/lob/api/buckslips_api.rb', line 176

def buckslip_retrieve_with_http_info(buckslip_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BuckslipsApi.buckslip_retrieve ...'
  end
  # verify the required parameter 'buckslip_id' is set
  if @api_client.config.client_side_validation && buckslip_id.nil?
    fail ArgumentError, "Missing the required parameter 'buckslip_id' when calling BuckslipsApi.buckslip_retrieve"
  end
  pattern = Regexp.new(/^bck_[a-zA-Z0-9]+$/)
  if @api_client.config.client_side_validation && buckslip_id !~ pattern
    fail ArgumentError, "invalid value for 'buckslip_id' when calling BuckslipsApi.buckslip_retrieve, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/buckslips/{buckslip_id}'.sub('{' + 'buckslip_id' + '}', CGI.escape(buckslip_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Buckslip'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"BuckslipsApi.buckslip_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BuckslipsApi#buckslip_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#buckslip_update_with_http_info(buckslip_id, buckslip_updatable, opts = {}) ⇒ Array<(Buckslip, Integer, Hash)>

update Update the details of an existing buckslip. You need only supply the unique identifier that was returned upon buckslip creation.

Parameters:

  • buckslip_id (String)

    id of the buckslip

  • buckslip_updatable (BuckslipUpdatable)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Buckslip, Integer, Hash)>)

    Buckslip data, response status code and response headers



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/lob/api/buckslips_api.rb', line 246

def buckslip_update_with_http_info(buckslip_id, buckslip_updatable, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BuckslipsApi.buckslip_update ...'
  end
  # verify the required parameter 'buckslip_id' is set
  if @api_client.config.client_side_validation && buckslip_id.nil?
    fail ArgumentError, "Missing the required parameter 'buckslip_id' when calling BuckslipsApi.buckslip_update"
  end
  pattern = Regexp.new(/^bck_[a-zA-Z0-9]+$/)
  if @api_client.config.client_side_validation && buckslip_id !~ pattern
    fail ArgumentError, "invalid value for 'buckslip_id' when calling BuckslipsApi.buckslip_update, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'buckslip_updatable' is set
  if @api_client.config.client_side_validation && buckslip_updatable.nil?
    fail ArgumentError, "Missing the required parameter 'buckslip_updatable' when calling BuckslipsApi.buckslip_update"
  end
  # resource path
  local_var_path = '/buckslips/{buckslip_id}'.sub('{' + 'buckslip_id' + '}', CGI.escape(buckslip_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(buckslip_updatable)

  # return_type
  return_type = opts[:debug_return_type] || 'Buckslip'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"BuckslipsApi.buckslip_update",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BuckslipsApi#buckslip_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#buckslips_list_with_http_info(opts = {}) ⇒ Array<(BuckslipsList, Integer, Hash)>

List Returns a list of your buckslips. The buckslips are returned sorted by creation date, with the most recently created buckslips appearing first.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    How many results to return. (default to 10)

  • :before (String)

    A reference to a list entry used for paginating to the previous set of entries. This field is pre-populated in the &#x60;previous_url&#x60; field in the return response.

  • :after (String)

    A reference to a list entry used for paginating to the next set of entries. This field is pre-populated in the &#x60;next_url&#x60; field in the return response.

  • :include (Array<String>)

    Request that the response include the total count by specifying &#x60;include[]&#x3D;total_count&#x60;.

Returns:

  • (Array<(BuckslipsList, Integer, Hash)>)

    BuckslipsList data, response status code and response headers



329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/lob/api/buckslips_api.rb', line 329

def buckslips_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BuckslipsApi.buckslips_list ...'
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling BuckslipsApi.buckslips_list, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling BuckslipsApi.buckslips_list, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/buckslips'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'before'] = opts[:'before'] if !opts[:'before'].nil?
  query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil?
  query_params[:'include'] = @api_client.build_collection_param(opts[:'include'], :multi) if !opts[:'include'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'BuckslipsList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"BuckslipsApi.buckslips_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BuckslipsApi#buckslips_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create(buckslip_editable, opts = {}) ⇒ Buckslip

create Creates a new buckslip given information

Parameters:

  • buckslip_editable (BuckslipEditable)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :front (Object)

    An optional file upload as either a byte array or file type.

Returns:



28
29
30
31
# File 'lib/lob/api/buckslips_api.rb', line 28

def create(buckslip_editable, opts = {})
  data, _status_code, _headers = buckslip_create_with_http_info(buckslip_editable, opts)
  data
end

#delete(buckslip_id, opts = {}) ⇒ BuckslipDeletion

delete Delete an existing buckslip. You need only supply the unique identifier that was returned upon buckslip creation.

Parameters:

  • buckslip_id (String)

    id of the buckslip

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



98
99
100
101
# File 'lib/lob/api/buckslips_api.rb', line 98

def delete(buckslip_id, opts = {})
  data, _status_code, _headers = buckslip_delete_with_http_info(buckslip_id, opts)
  data
end

#get(buckslip_id, opts = {}) ⇒ Buckslip

get Retrieves the details of an existing buckslip. You need only supply the unique customer identifier that was returned upon buckslip creation.

Parameters:

  • buckslip_id (String)

    id of the buckslip

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



166
167
168
169
# File 'lib/lob/api/buckslips_api.rb', line 166

def get(buckslip_id, opts = {})
  data, _status_code, _headers = buckslip_retrieve_with_http_info(buckslip_id, opts)
  data
end

#List(opts = {}) ⇒ BuckslipsList

List Returns a list of your buckslips. The buckslips are returned sorted by creation date, with the most recently created buckslips appearing first.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    How many results to return. (default to 10)

  • :before (String)

    A reference to a list entry used for paginating to the previous set of entries. This field is pre-populated in the &#x60;previous_url&#x60; field in the return response.

  • :after (String)

    A reference to a list entry used for paginating to the next set of entries. This field is pre-populated in the &#x60;next_url&#x60; field in the return response.

  • :include (Array<String>)

    Request that the response include the total count by specifying &#x60;include[]&#x3D;total_count&#x60;.

Returns:



316
317
318
319
# File 'lib/lob/api/buckslips_api.rb', line 316

def List(opts = {})
  data, _status_code, _headers = buckslips_list_with_http_info(opts)
  data
end

#update(buckslip_id, buckslip_updatable, opts = {}) ⇒ Buckslip

update Update the details of an existing buckslip. You need only supply the unique identifier that was returned upon buckslip creation.

Parameters:

  • buckslip_id (String)

    id of the buckslip

  • buckslip_updatable (BuckslipUpdatable)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



235
236
237
238
# File 'lib/lob/api/buckslips_api.rb', line 235

def update(buckslip_id, buckslip_updatable, opts = {})
  data, _status_code, _headers = buckslip_update_with_http_info(buckslip_id, buckslip_updatable, opts)
  data
end