Class: Lob::Campaign

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/campaign.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Campaign

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/lob/models/campaign.rb', line 159

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::Campaign` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::Campaign`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'billing_group_id')
    self.billing_group_id = attributes[:'billing_group_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'schedule_type')
    self.schedule_type = attributes[:'schedule_type']
  end

  if attributes.key?(:'target_delivery_date')
    self.target_delivery_date = attributes[:'target_delivery_date']
  end

  if attributes.key?(:'send_date')
    self.send_date = attributes[:'send_date']
  end

  if attributes.key?(:'cancel_window_campaign_minutes')
    self.cancel_window_campaign_minutes = attributes[:'cancel_window_campaign_minutes']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'use_type')
    self.use_type = attributes[:'use_type']
  end

  if attributes.key?(:'auto_cancel_if_ncoa')
    self.auto_cancel_if_ncoa = attributes[:'auto_cancel_if_ncoa']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'is_draft')
    self.is_draft = attributes[:'is_draft']
  else
    self.is_draft = true
  end

  if attributes.key?(:'creatives')
    if (value = attributes[:'creatives']).is_a?(Array)
      self.creatives = value
    end
  end

  if attributes.key?(:'date_created')
    self.date_created = attributes[:'date_created']
  end

  if attributes.key?(:'date_modified')
    self.date_modified = attributes[:'date_modified']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = 'campaign'
  end
end

Instance Attribute Details

#account_idObject

Account ID that this campaign is associated with.



50
51
52
# File 'lib/lob/models/campaign.rb', line 50

def 
  @account_id
end

#auto_cancel_if_ncoaObject

Whether or not a mail piece should be automatically canceled and not sent if the address is updated via NCOA.



44
45
46
# File 'lib/lob/models/campaign.rb', line 44

def auto_cancel_if_ncoa
  @auto_cancel_if_ncoa
end

#billing_group_idObject

Unique identifier prefixed with ‘bg_`.



19
20
21
# File 'lib/lob/models/campaign.rb', line 19

def billing_group_id
  @billing_group_id
end

#cancel_window_campaign_minutesObject

A window, in minutes, within which the campaign can be canceled.



36
37
38
# File 'lib/lob/models/campaign.rb', line 36

def cancel_window_campaign_minutes
  @cancel_window_campaign_minutes
end

#creativesObject

An array of creatives that have been associated with this campaign.



56
57
58
# File 'lib/lob/models/campaign.rb', line 56

def creatives
  @creatives
end

#date_createdObject

A timestamp in ISO 8601 format of the date the resource was created.



59
60
61
# File 'lib/lob/models/campaign.rb', line 59

def date_created
  @date_created
end

#date_modifiedObject

A timestamp in ISO 8601 format of the date the resource was last modified.



62
63
64
# File 'lib/lob/models/campaign.rb', line 62

def date_modified
  @date_modified
end

#deletedObject

Only returned if the resource has been successfully deleted.



65
66
67
# File 'lib/lob/models/campaign.rb', line 65

def deleted
  @deleted
end

#descriptionObject

An internal description that identifies this resource. Must be no longer than 255 characters.



25
26
27
# File 'lib/lob/models/campaign.rb', line 25

def description
  @description
end

#idObject

Unique identifier prefixed with ‘cmp_`.



47
48
49
# File 'lib/lob/models/campaign.rb', line 47

def id
  @id
end

#is_draftObject

Whether or not the campaign is still a draft.



53
54
55
# File 'lib/lob/models/campaign.rb', line 53

def is_draft
  @is_draft
end

#metadataObject

Use metadata to store custom information for tagging and labeling back to your internal systems. Must be an object with up to 20 key-value pairs. Keys must be at most 40 characters and values must be at most 500 characters. Neither can contain the characters ‘"` and `\`. i.e. ’: "NEWYORK2015"‘ Nested objects are not supported. See [Metadata](#section/Metadata) for more information.



39
40
41
# File 'lib/lob/models/campaign.rb', line 39

def 
  @metadata
end

#nameObject

Name of the campaign.



22
23
24
# File 'lib/lob/models/campaign.rb', line 22

def name
  @name
end

#objectObject

Value is resource type.



68
69
70
# File 'lib/lob/models/campaign.rb', line 68

def object
  @object
end

#schedule_typeObject

Returns the value of attribute schedule_type.



27
28
29
# File 'lib/lob/models/campaign.rb', line 27

def schedule_type
  @schedule_type
end

#send_dateObject

If ‘schedule_type` is `scheduled_send_date`, provide a date to send this campaign.



33
34
35
# File 'lib/lob/models/campaign.rb', line 33

def send_date
  @send_date
end

#target_delivery_dateObject

If ‘schedule_type` is `target_delivery_date`, provide a targeted delivery date for mail pieces in this campaign.



30
31
32
# File 'lib/lob/models/campaign.rb', line 30

def target_delivery_date
  @target_delivery_date
end

#use_typeObject

Returns the value of attribute use_type.



41
42
43
# File 'lib/lob/models/campaign.rb', line 41

def use_type
  @use_type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



117
118
119
# File 'lib/lob/models/campaign.rb', line 117

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/lob/models/campaign.rb', line 93

def self.attribute_map
  {
    :'billing_group_id' => :'billing_group_id',
    :'name' => :'name',
    :'description' => :'description',
    :'schedule_type' => :'schedule_type',
    :'target_delivery_date' => :'target_delivery_date',
    :'send_date' => :'send_date',
    :'cancel_window_campaign_minutes' => :'cancel_window_campaign_minutes',
    :'metadata' => :'metadata',
    :'use_type' => :'use_type',
    :'auto_cancel_if_ncoa' => :'auto_cancel_if_ncoa',
    :'id' => :'id',
    :'account_id' => :'account_id',
    :'is_draft' => :'is_draft',
    :'creatives' => :'creatives',
    :'date_created' => :'date_created',
    :'date_modified' => :'date_modified',
    :'deleted' => :'deleted',
    :'object' => :'object'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



423
424
425
# File 'lib/lob/models/campaign.rb', line 423

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



146
147
148
149
150
151
152
153
154
155
# File 'lib/lob/models/campaign.rb', line 146

def self.openapi_nullable
  Set.new([
    :'billing_group_id',
    :'description',
    :'target_delivery_date',
    :'send_date',
    :'cancel_window_campaign_minutes',
    :'use_type',
  ])
end

.openapi_typesObject

Attribute type mapping.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/lob/models/campaign.rb', line 122

def self.openapi_types
  {
    :'billing_group_id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'schedule_type' => :'CmpScheduleType',
    :'target_delivery_date' => :'Time',
    :'send_date' => :'Time',
    :'cancel_window_campaign_minutes' => :'Integer',
    :'metadata' => :'Hash<String, String>',
    :'use_type' => :'CmpUseType',
    :'auto_cancel_if_ncoa' => :'Boolean',
    :'id' => :'String',
    :'account_id' => :'String',
    :'is_draft' => :'Boolean',
    :'creatives' => :'Array<CampaignCreative>',
    :'date_created' => :'Time',
    :'date_modified' => :'Time',
    :'deleted' => :'Boolean',
    :'object' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/lob/models/campaign.rb', line 384

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      billing_group_id == o.billing_group_id &&
      name == o.name &&
      description == o.description &&
      schedule_type == o.schedule_type &&
      target_delivery_date == o.target_delivery_date &&
      send_date == o.send_date &&
      cancel_window_campaign_minutes == o.cancel_window_campaign_minutes &&
       == o. &&
      use_type == o.use_type &&
      auto_cancel_if_ncoa == o.auto_cancel_if_ncoa &&
      id == o.id &&
       == o. &&
      is_draft == o.is_draft &&
      creatives == o.creatives &&
      date_created == o.date_created &&
      date_modified == o.date_modified &&
      deleted == o.deleted &&
      object == o.object
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
# File 'lib/lob/models/campaign.rb', line 462

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



533
534
535
536
537
538
539
540
541
542
543
544
545
# File 'lib/lob/models/campaign.rb', line 533

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
# File 'lib/lob/models/campaign.rb', line 430

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


409
410
411
# File 'lib/lob/models/campaign.rb', line 409

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



415
416
417
# File 'lib/lob/models/campaign.rb', line 415

def hash
  [billing_group_id, name, description, schedule_type, target_delivery_date, send_date, cancel_window_campaign_minutes, , use_type, auto_cancel_if_ncoa, id, , is_draft, creatives, date_created, date_modified, deleted, object].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/lob/models/campaign.rb', line 255

def list_invalid_properties
  invalid_properties = Array.new
  pattern = Regexp.new(/^bg_[a-zA-Z0-9]+$/)
  if !@billing_group_id.nil? && @billing_group_id !~ pattern
    invalid_properties.push("invalid value for \"billing_group_id\", must conform to the pattern #{pattern}.")
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if !@description.nil? && @description.to_s.length > 255
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.')
  end

  if @schedule_type.nil?
    invalid_properties.push('invalid value for "schedule_type", schedule_type cannot be nil.')
  end

  if @auto_cancel_if_ncoa.nil?
    invalid_properties.push('invalid value for "auto_cancel_if_ncoa", auto_cancel_if_ncoa cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  pattern = Regexp.new(/^cmp_[a-zA-Z0-9]+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if @is_draft.nil?
    invalid_properties.push('invalid value for "is_draft", is_draft cannot be nil.')
  end

  if @creatives.nil?
    invalid_properties.push('invalid value for "creatives", creatives cannot be nil.')
  end

  if @date_created.nil?
    invalid_properties.push('invalid value for "date_created", date_created cannot be nil.')
  end

  if @date_modified.nil?
    invalid_properties.push('invalid value for "date_modified", date_modified cannot be nil.')
  end

  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



509
510
511
# File 'lib/lob/models/campaign.rb', line 509

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



515
516
517
518
519
520
521
522
523
524
525
526
527
# File 'lib/lob/models/campaign.rb', line 515

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



503
504
505
# File 'lib/lob/models/campaign.rb', line 503

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/lob/models/campaign.rb', line 312

def valid?
  return false if !@billing_group_id.nil? && @billing_group_id !~ Regexp.new(/^bg_[a-zA-Z0-9]+$/)
  return false if @name.nil?
  return false if !@description.nil? && @description.to_s.length > 255
  return false if @schedule_type.nil?
  return false if @auto_cancel_if_ncoa.nil?
  return false if @id.nil?
  return false if @id !~ Regexp.new(/^cmp_[a-zA-Z0-9]+$/)
  return false if @is_draft.nil?
  return false if @creatives.nil?
  return false if @date_created.nil?
  return false if @date_modified.nil?
  return false if @object.nil?
  object_validator = EnumAttributeValidator.new('String', ["campaign"])
  return false unless object_validator.valid?(@object)
  true
end