Class: Lob::CampaignCreative

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/campaign_creative.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CampaignCreative

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/lob/models/campaign_creative.rb', line 132

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::CampaignCreative` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::CampaignCreative`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'resource_type')
    self.resource_type = attributes[:'resource_type']
  end

  if attributes.key?(:'details')
    self.details = attributes[:'details']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'template_preview_urls')
    self.template_preview_urls = attributes[:'template_preview_urls']
  end

  if attributes.key?(:'template_previews')
    if (value = attributes[:'template_previews']).is_a?(Array)
      self.template_previews = value
    end
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end

  if attributes.key?(:'campaigns')
    if (value = attributes[:'campaigns']).is_a?(Array)
      self.campaigns = value
    end
  end

  if attributes.key?(:'date_created')
    self.date_created = attributes[:'date_created']
  end

  if attributes.key?(:'date_modified')
    self.date_modified = attributes[:'date_modified']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = 'creative'
  end
end

Instance Attribute Details

#campaignsObject

Returns the value of attribute campaigns.



45
46
47
# File 'lib/lob/models/campaign_creative.rb', line 45

def campaigns
  @campaigns
end

#date_createdObject

A timestamp in ISO 8601 format of the date the resource was created.



48
49
50
# File 'lib/lob/models/campaign_creative.rb', line 48

def date_created
  @date_created
end

#date_modifiedObject

A timestamp in ISO 8601 format of the date the resource was last modified.



51
52
53
# File 'lib/lob/models/campaign_creative.rb', line 51

def date_modified
  @date_modified
end

#deletedObject

Only returned if the resource has been successfully deleted.



43
44
45
# File 'lib/lob/models/campaign_creative.rb', line 43

def deleted
  @deleted
end

#descriptionObject

An internal description that identifies this resource. Must be no longer than 255 characters.



22
23
24
# File 'lib/lob/models/campaign_creative.rb', line 22

def description
  @description
end

#detailsObject

Either PostcardDetailsReturned or LetterDetailsReturned



31
32
33
# File 'lib/lob/models/campaign_creative.rb', line 31

def details
  @details
end

#fromObject

Must either be an address ID or an inline object with correct address parameters.



25
26
27
# File 'lib/lob/models/campaign_creative.rb', line 25

def from
  @from
end

#idObject

Unique identifier prefixed with ‘crv_`.



19
20
21
# File 'lib/lob/models/campaign_creative.rb', line 19

def id
  @id
end

#metadataObject

Use metadata to store custom information for tagging and labeling back to your internal systems. Must be an object with up to 20 key-value pairs. Keys must be at most 40 characters and values must be at most 500 characters. Neither can contain the characters ‘"` and `\`. i.e. ’: "NEWYORK2015"‘ Nested objects are not supported. See [Metadata](#section/Metadata) for more information.



34
35
36
# File 'lib/lob/models/campaign_creative.rb', line 34

def 
  @metadata
end

#objectObject

Value is resource type.



54
55
56
# File 'lib/lob/models/campaign_creative.rb', line 54

def object
  @object
end

#resource_typeObject

Mailpiece type for the creative



28
29
30
# File 'lib/lob/models/campaign_creative.rb', line 28

def resource_type
  @resource_type
end

#template_preview_urlsObject

Preview URLs associated with a creative’s artwork asset(s) if the creative uses HTML templates as assets.



37
38
39
# File 'lib/lob/models/campaign_creative.rb', line 37

def template_preview_urls
  @template_preview_urls
end

#template_previewsObject

A list of template preview objects if the creative uses HTML template(s) as artwork asset(s).



40
41
42
# File 'lib/lob/models/campaign_creative.rb', line 40

def template_previews
  @template_previews
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



98
99
100
# File 'lib/lob/models/campaign_creative.rb', line 98

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/lob/models/campaign_creative.rb', line 79

def self.attribute_map
  {
    :'id' => :'id',
    :'description' => :'description',
    :'from' => :'from',
    :'resource_type' => :'resource_type',
    :'details' => :'details',
    :'metadata' => :'metadata',
    :'template_preview_urls' => :'template_preview_urls',
    :'template_previews' => :'template_previews',
    :'deleted' => :'deleted',
    :'campaigns' => :'campaigns',
    :'date_created' => :'date_created',
    :'date_modified' => :'date_modified',
    :'object' => :'object'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



341
342
343
# File 'lib/lob/models/campaign_creative.rb', line 341

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



122
123
124
125
126
127
128
# File 'lib/lob/models/campaign_creative.rb', line 122

def self.openapi_nullable
  Set.new([
    :'description',
    :'from',
    :'details',
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/lob/models/campaign_creative.rb', line 103

def self.openapi_types
  {
    :'id' => :'String',
    :'description' => :'String',
    :'from' => Array[:'AddressEditable', :'String'],
    :'resource_type' => :'String',
    :'details' => Array[:'PostcardDetailsWritable', :'String'],
    :'metadata' => :'Hash<String, String>',
    :'template_preview_urls' => :'Object',
    :'template_previews' => :'Array<Object>',
    :'deleted' => :'Boolean',
    :'campaigns' => :'Array<Campaign>',
    :'date_created' => :'Time',
    :'date_modified' => :'Time',
    :'object' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/lob/models/campaign_creative.rb', line 307

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      description == o.description &&
      from == o.from &&
      resource_type == o.resource_type &&
      details == o.details &&
       == o. &&
      template_preview_urls == o.template_preview_urls &&
      template_previews == o.template_previews &&
      deleted == o.deleted &&
      campaigns == o.campaigns &&
      date_created == o.date_created &&
      date_modified == o.date_modified &&
      object == o.object
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/lob/models/campaign_creative.rb', line 380

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



451
452
453
454
455
456
457
458
459
460
461
462
463
# File 'lib/lob/models/campaign_creative.rb', line 451

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/lob/models/campaign_creative.rb', line 348

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


327
328
329
# File 'lib/lob/models/campaign_creative.rb', line 327

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



333
334
335
# File 'lib/lob/models/campaign_creative.rb', line 333

def hash
  [id, description, from, resource_type, details, , template_preview_urls, template_previews, deleted, campaigns, date_created, date_modified, object].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/lob/models/campaign_creative.rb', line 208

def list_invalid_properties
  invalid_properties = Array.new
  pattern = Regexp.new(/^crv_[a-zA-Z0-9]+$/)
  if !@id.nil? && @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if !@description.nil? && @description.to_s.length > 255
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.')
  end

  if !@campaigns.nil? && @campaigns.length > 0
    invalid_properties.push('invalid value for "campaigns", number of items must be less than or equal to 0.')
  end

  if !@campaigns.nil? && @campaigns.length < 0
    invalid_properties.push('invalid value for "campaigns", number of items must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



427
428
429
# File 'lib/lob/models/campaign_creative.rb', line 427

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/lob/models/campaign_creative.rb', line 433

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



421
422
423
# File 'lib/lob/models/campaign_creative.rb', line 421

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



232
233
234
235
236
237
238
239
240
241
242
# File 'lib/lob/models/campaign_creative.rb', line 232

def valid?
  return false if !@id.nil? && @id !~ Regexp.new(/^crv_[a-zA-Z0-9]+$/)
  return false if !@description.nil? && @description.to_s.length > 255
  resource_type_validator = EnumAttributeValidator.new('String', ["letter", "postcard"])
  return false unless resource_type_validator.valid?(@resource_type)
  return false if !@campaigns.nil? && @campaigns.length > 0
  return false if !@campaigns.nil? && @campaigns.length < 0
  object_validator = EnumAttributeValidator.new('String', ["creative"])
  return false unless object_validator.valid?(@object)
  true
end