Class: Lob::CampaignUpdatable
- Inherits:
-
Object
- Object
- Lob::CampaignUpdatable
- Defined in:
- lib/lob/models/campaign_updatable.rb
Instance Attribute Summary collapse
-
#auto_cancel_if_ncoa ⇒ Object
Whether or not a mail piece should be automatically canceled and not sent if the address is updated via NCOA.
-
#cancel_window_campaign_minutes ⇒ Object
A window, in minutes, within which the campaign can be canceled.
-
#description ⇒ Object
An internal description that identifies this resource.
-
#is_draft ⇒ Object
Whether or not the campaign is still a draft.
-
#metadata ⇒ Object
Use metadata to store custom information for tagging and labeling back to your internal systems.
-
#name ⇒ Object
Returns the value of attribute name.
-
#schedule_type ⇒ Object
Returns the value of attribute schedule_type.
-
#send_date ⇒ Object
If ‘schedule_type` is `scheduled_send_date`, provide a date to send this campaign.
-
#target_delivery_date ⇒ Object
If ‘schedule_type` is `target_delivery_date`, provide a targeted delivery date for mail pieces in this campaign.
-
#use_type ⇒ Object
Returns the value of attribute use_type.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CampaignUpdatable
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CampaignUpdatable
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/lob/models/campaign_updatable.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::CampaignUpdatable` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::CampaignUpdatable`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'schedule_type') self.schedule_type = attributes[:'schedule_type'] end if attributes.key?(:'target_delivery_date') self.target_delivery_date = attributes[:'target_delivery_date'] end if attributes.key?(:'send_date') self.send_date = attributes[:'send_date'] end if attributes.key?(:'cancel_window_campaign_minutes') self.cancel_window_campaign_minutes = attributes[:'cancel_window_campaign_minutes'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'is_draft') self.is_draft = attributes[:'is_draft'] end if attributes.key?(:'use_type') self.use_type = attributes[:'use_type'] end if attributes.key?(:'auto_cancel_if_ncoa') self.auto_cancel_if_ncoa = attributes[:'auto_cancel_if_ncoa'] end end |
Instance Attribute Details
#auto_cancel_if_ncoa ⇒ Object
Whether or not a mail piece should be automatically canceled and not sent if the address is updated via NCOA.
43 44 45 |
# File 'lib/lob/models/campaign_updatable.rb', line 43 def auto_cancel_if_ncoa @auto_cancel_if_ncoa end |
#cancel_window_campaign_minutes ⇒ Object
A window, in minutes, within which the campaign can be canceled.
32 33 34 |
# File 'lib/lob/models/campaign_updatable.rb', line 32 def cancel_window_campaign_minutes @cancel_window_campaign_minutes end |
#description ⇒ Object
An internal description that identifies this resource. Must be no longer than 255 characters.
21 22 23 |
# File 'lib/lob/models/campaign_updatable.rb', line 21 def description @description end |
#is_draft ⇒ Object
Whether or not the campaign is still a draft.
38 39 40 |
# File 'lib/lob/models/campaign_updatable.rb', line 38 def is_draft @is_draft end |
#metadata ⇒ Object
Use metadata to store custom information for tagging and labeling back to your internal systems. Must be an object with up to 20 key-value pairs. Keys must be at most 40 characters and values must be at most 500 characters. Neither can contain the characters ‘"` and `\`. i.e. ’: "NEWYORK2015"‘ Nested objects are not supported. See [Metadata](#section/Metadata) for more information.
35 36 37 |
# File 'lib/lob/models/campaign_updatable.rb', line 35 def @metadata end |
#name ⇒ Object
Returns the value of attribute name.
18 19 20 |
# File 'lib/lob/models/campaign_updatable.rb', line 18 def name @name end |
#schedule_type ⇒ Object
Returns the value of attribute schedule_type.
23 24 25 |
# File 'lib/lob/models/campaign_updatable.rb', line 23 def schedule_type @schedule_type end |
#send_date ⇒ Object
If ‘schedule_type` is `scheduled_send_date`, provide a date to send this campaign.
29 30 31 |
# File 'lib/lob/models/campaign_updatable.rb', line 29 def send_date @send_date end |
#target_delivery_date ⇒ Object
If ‘schedule_type` is `target_delivery_date`, provide a targeted delivery date for mail pieces in this campaign.
26 27 28 |
# File 'lib/lob/models/campaign_updatable.rb', line 26 def target_delivery_date @target_delivery_date end |
#use_type ⇒ Object
Returns the value of attribute use_type.
40 41 42 |
# File 'lib/lob/models/campaign_updatable.rb', line 40 def use_type @use_type end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/lob/models/campaign_updatable.rb', line 62 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/lob/models/campaign_updatable.rb', line 46 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'schedule_type' => :'schedule_type', :'target_delivery_date' => :'target_delivery_date', :'send_date' => :'send_date', :'cancel_window_campaign_minutes' => :'cancel_window_campaign_minutes', :'metadata' => :'metadata', :'is_draft' => :'is_draft', :'use_type' => :'use_type', :'auto_cancel_if_ncoa' => :'auto_cancel_if_ncoa' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
215 216 217 |
# File 'lib/lob/models/campaign_updatable.rb', line 215 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
83 84 85 86 87 88 |
# File 'lib/lob/models/campaign_updatable.rb', line 83 def self.openapi_nullable Set.new([ :'description', :'use_type', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/lob/models/campaign_updatable.rb', line 67 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'schedule_type' => :'CmpScheduleType', :'target_delivery_date' => :'Time', :'send_date' => :'Time', :'cancel_window_campaign_minutes' => :'Integer', :'metadata' => :'Hash<String, String>', :'is_draft' => :'Boolean', :'use_type' => :'CmpUseType', :'auto_cancel_if_ncoa' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/lob/models/campaign_updatable.rb', line 184 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && schedule_type == o.schedule_type && target_delivery_date == o.target_delivery_date && send_date == o.send_date && cancel_window_campaign_minutes == o.cancel_window_campaign_minutes && == o. && is_draft == o.is_draft && use_type == o.use_type && auto_cancel_if_ncoa == o.auto_cancel_if_ncoa end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/lob/models/campaign_updatable.rb', line 254 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Lob.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/lob/models/campaign_updatable.rb', line 325 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/lob/models/campaign_updatable.rb', line 222 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) # // guardrails-disable-line elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line end elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array) for base_type in type do res = _deserialize(base_type, attributes[self.class.attribute_map[key]]) if !res.nil? self.send("#{key}=", res) # // guardrails-disable-line break end end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line end end self end |
#eql?(o) ⇒ Boolean
201 202 203 |
# File 'lib/lob/models/campaign_updatable.rb', line 201 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/lob/models/campaign_updatable.rb', line 207 def hash [name, description, schedule_type, target_delivery_date, send_date, cancel_window_campaign_minutes, , is_draft, use_type, auto_cancel_if_ncoa].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
150 151 152 153 154 155 156 157 |
# File 'lib/lob/models/campaign_updatable.rb', line 150 def list_invalid_properties invalid_properties = Array.new if !@description.nil? && @description.to_s.length > 255 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
301 302 303 |
# File 'lib/lob/models/campaign_updatable.rb', line 301 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/lob/models/campaign_updatable.rb', line 307 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) # // guardrails-disable-line if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
295 296 297 |
# File 'lib/lob/models/campaign_updatable.rb', line 295 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
161 162 163 164 |
# File 'lib/lob/models/campaign_updatable.rb', line 161 def valid? return false if !@description.nil? && @description.to_s.length > 255 true end |