Class: Lob::Card

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/card.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Card

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/lob/models/card.rb', line 160

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::Card` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::Card`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'auto_reorder')
    self.auto_reorder = attributes[:'auto_reorder']
  else
    self.auto_reorder = false
  end

  if attributes.key?(:'reorder_quantity')
    self.reorder_quantity = attributes[:'reorder_quantity']
  end

  if attributes.key?(:'raw_url')
    self.raw_url = attributes[:'raw_url']
  end

  if attributes.key?(:'front_original_url')
    self.front_original_url = attributes[:'front_original_url']
  end

  if attributes.key?(:'back_original_url')
    self.back_original_url = attributes[:'back_original_url']
  end

  if attributes.key?(:'thumbnails')
    if (value = attributes[:'thumbnails']).is_a?(Array)
      self.thumbnails = value
    end
  end

  if attributes.key?(:'available_quantity')
    self.available_quantity = attributes[:'available_quantity']
  else
    self.available_quantity = 0
  end

  if attributes.key?(:'pending_quantity')
    self.pending_quantity = attributes[:'pending_quantity']
  else
    self.pending_quantity = 0
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'orientation')
    self.orientation = attributes[:'orientation']
  else
    self.orientation = 'horizontal'
  end

  if attributes.key?(:'threshold_amount')
    self.threshold_amount = attributes[:'threshold_amount']
  else
    self.threshold_amount = 0
  end

  if attributes.key?(:'date_created')
    self.date_created = attributes[:'date_created']
  end

  if attributes.key?(:'date_modified')
    self.date_modified = attributes[:'date_modified']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = 'card'
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  else
    self.size = '2.125x3.375'
  end
end

Instance Attribute Details

#auto_reorderObject

True if the cards should be auto-reordered.



25
26
27
# File 'lib/lob/models/card.rb', line 25

def auto_reorder
  @auto_reorder
end

#available_quantityObject

The available quantity of cards.



42
43
44
# File 'lib/lob/models/card.rb', line 42

def available_quantity
  @available_quantity
end

#back_original_urlObject

The original URL of the back template.



37
38
39
# File 'lib/lob/models/card.rb', line 37

def back_original_url
  @back_original_url
end

#date_createdObject

A timestamp in ISO 8601 format of the date the resource was created.



56
57
58
# File 'lib/lob/models/card.rb', line 56

def date_created
  @date_created
end

#date_modifiedObject

A timestamp in ISO 8601 format of the date the resource was last modified.



59
60
61
# File 'lib/lob/models/card.rb', line 59

def date_modified
  @date_modified
end

#deletedObject

Only returned if the resource has been successfully deleted.



62
63
64
# File 'lib/lob/models/card.rb', line 62

def deleted
  @deleted
end

#descriptionObject

Description of the card.



68
69
70
# File 'lib/lob/models/card.rb', line 68

def description
  @description
end

#front_original_urlObject

The original URL of the front template.



34
35
36
# File 'lib/lob/models/card.rb', line 34

def front_original_url
  @front_original_url
end

#idObject

Unique identifier prefixed with ‘card_`.



19
20
21
# File 'lib/lob/models/card.rb', line 19

def id
  @id
end

#objectObject

object



65
66
67
# File 'lib/lob/models/card.rb', line 65

def object
  @object
end

#orientationObject

The orientation of the card.



50
51
52
# File 'lib/lob/models/card.rb', line 50

def orientation
  @orientation
end

#pending_quantityObject

The pending quantity of cards.



45
46
47
# File 'lib/lob/models/card.rb', line 45

def pending_quantity
  @pending_quantity
end

#raw_urlObject

The raw URL of the card.



31
32
33
# File 'lib/lob/models/card.rb', line 31

def raw_url
  @raw_url
end

#reorder_quantityObject

The number of cards to be reordered. Only present when auto_reorder is True.



28
29
30
# File 'lib/lob/models/card.rb', line 28

def reorder_quantity
  @reorder_quantity
end

#sizeObject

The size of the card



71
72
73
# File 'lib/lob/models/card.rb', line 71

def size
  @size
end

#statusObject

Returns the value of attribute status.



47
48
49
# File 'lib/lob/models/card.rb', line 47

def status
  @status
end

#threshold_amountObject

The threshold amount of the card



53
54
55
# File 'lib/lob/models/card.rb', line 53

def threshold_amount
  @threshold_amount
end

#thumbnailsObject

Returns the value of attribute thumbnails.



39
40
41
# File 'lib/lob/models/card.rb', line 39

def thumbnails
  @thumbnails
end

#urlObject

The signed link for the card.



22
23
24
# File 'lib/lob/models/card.rb', line 22

def url
  @url
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



121
122
123
# File 'lib/lob/models/card.rb', line 121

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/lob/models/card.rb', line 96

def self.attribute_map
  {
    :'id' => :'id',
    :'url' => :'url',
    :'auto_reorder' => :'auto_reorder',
    :'reorder_quantity' => :'reorder_quantity',
    :'raw_url' => :'raw_url',
    :'front_original_url' => :'front_original_url',
    :'back_original_url' => :'back_original_url',
    :'thumbnails' => :'thumbnails',
    :'available_quantity' => :'available_quantity',
    :'pending_quantity' => :'pending_quantity',
    :'status' => :'status',
    :'orientation' => :'orientation',
    :'threshold_amount' => :'threshold_amount',
    :'date_created' => :'date_created',
    :'date_modified' => :'date_modified',
    :'deleted' => :'deleted',
    :'object' => :'object',
    :'description' => :'description',
    :'size' => :'size'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



555
556
557
# File 'lib/lob/models/card.rb', line 555

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



151
152
153
154
155
156
# File 'lib/lob/models/card.rb', line 151

def self.openapi_nullable
  Set.new([
    :'reorder_quantity',
    :'description',
  ])
end

.openapi_typesObject

Attribute type mapping.



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/lob/models/card.rb', line 126

def self.openapi_types
  {
    :'id' => :'String',
    :'url' => :'String',
    :'auto_reorder' => :'Boolean',
    :'reorder_quantity' => :'Integer',
    :'raw_url' => :'String',
    :'front_original_url' => :'String',
    :'back_original_url' => :'String',
    :'thumbnails' => :'Array<Thumbnail>',
    :'available_quantity' => :'Integer',
    :'pending_quantity' => :'Integer',
    :'status' => :'String',
    :'orientation' => :'String',
    :'threshold_amount' => :'Integer',
    :'date_created' => :'Time',
    :'date_modified' => :'Time',
    :'deleted' => :'Boolean',
    :'object' => :'String',
    :'description' => :'String',
    :'size' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
# File 'lib/lob/models/card.rb', line 515

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      url == o.url &&
      auto_reorder == o.auto_reorder &&
      reorder_quantity == o.reorder_quantity &&
      raw_url == o.raw_url &&
      front_original_url == o.front_original_url &&
      back_original_url == o.back_original_url &&
      thumbnails == o.thumbnails &&
      available_quantity == o.available_quantity &&
      pending_quantity == o.pending_quantity &&
      status == o.status &&
      orientation == o.orientation &&
      threshold_amount == o.threshold_amount &&
      date_created == o.date_created &&
      date_modified == o.date_modified &&
      deleted == o.deleted &&
      object == o.object &&
      description == o.description &&
      size == o.size
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
# File 'lib/lob/models/card.rb', line 594

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



665
666
667
668
669
670
671
672
673
674
675
676
677
# File 'lib/lob/models/card.rb', line 665

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
# File 'lib/lob/models/card.rb', line 562

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


541
542
543
# File 'lib/lob/models/card.rb', line 541

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



547
548
549
# File 'lib/lob/models/card.rb', line 547

def hash
  [id, url, auto_reorder, reorder_quantity, raw_url, front_original_url, back_original_url, thumbnails, available_quantity, pending_quantity, status, orientation, threshold_amount, date_created, date_modified, deleted, object, description, size].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/lob/models/card.rb', line 268

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  pattern = Regexp.new(/^card_[a-zA-Z0-9]+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @url.to_s.length > 2083
    invalid_properties.push('invalid value for "url", the character length must be smaller than or equal to 2083.')
  end

  if @url.to_s.length < 1
    invalid_properties.push('invalid value for "url", the character length must be great than or equal to 1.')
  end

  if @auto_reorder.nil?
    invalid_properties.push('invalid value for "auto_reorder", auto_reorder cannot be nil.')
  end

  if !@raw_url.nil? && @raw_url.to_s.length > 2083
    invalid_properties.push('invalid value for "raw_url", the character length must be smaller than or equal to 2083.')
  end

  if !@raw_url.nil? && @raw_url.to_s.length < 1
    invalid_properties.push('invalid value for "raw_url", the character length must be great than or equal to 1.')
  end

  if !@front_original_url.nil? && @front_original_url.to_s.length > 2083
    invalid_properties.push('invalid value for "front_original_url", the character length must be smaller than or equal to 2083.')
  end

  if !@front_original_url.nil? && @front_original_url.to_s.length < 1
    invalid_properties.push('invalid value for "front_original_url", the character length must be great than or equal to 1.')
  end

  if !@back_original_url.nil? && @back_original_url.to_s.length > 2083
    invalid_properties.push('invalid value for "back_original_url", the character length must be smaller than or equal to 2083.')
  end

  if !@back_original_url.nil? && @back_original_url.to_s.length < 1
    invalid_properties.push('invalid value for "back_original_url", the character length must be great than or equal to 1.')
  end

  if @thumbnails.nil?
    invalid_properties.push('invalid value for "thumbnails", thumbnails cannot be nil.')
  end

  if @available_quantity.nil?
    invalid_properties.push('invalid value for "available_quantity", available_quantity cannot be nil.')
  end

  if @pending_quantity.nil?
    invalid_properties.push('invalid value for "pending_quantity", pending_quantity cannot be nil.')
  end

  if @date_created.nil?
    invalid_properties.push('invalid value for "date_created", date_created cannot be nil.')
  end

  if @date_modified.nil?
    invalid_properties.push('invalid value for "date_modified", date_modified cannot be nil.')
  end

  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  if !@description.nil? && @description.to_s.length > 255
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.')
  end

  if @size.nil?
    invalid_properties.push('invalid value for "size", size cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



641
642
643
# File 'lib/lob/models/card.rb', line 641

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



647
648
649
650
651
652
653
654
655
656
657
658
659
# File 'lib/lob/models/card.rb', line 647

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



635
636
637
# File 'lib/lob/models/card.rb', line 635

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/lob/models/card.rb', line 356

def valid?
  return false if @id.nil?
  return false if @id !~ Regexp.new(/^card_[a-zA-Z0-9]+$/)
  return false if @url.nil?
  return false if @url.to_s.length > 2083
  return false if @url.to_s.length < 1
  return false if @auto_reorder.nil?
  return false if !@raw_url.nil? && @raw_url.to_s.length > 2083
  return false if !@raw_url.nil? && @raw_url.to_s.length < 1
  return false if !@front_original_url.nil? && @front_original_url.to_s.length > 2083
  return false if !@front_original_url.nil? && @front_original_url.to_s.length < 1
  return false if !@back_original_url.nil? && @back_original_url.to_s.length > 2083
  return false if !@back_original_url.nil? && @back_original_url.to_s.length < 1
  return false if @thumbnails.nil?
  return false if @available_quantity.nil?
  return false if @pending_quantity.nil?
  status_validator = EnumAttributeValidator.new('String', ["processed", "rendered"])
  return false unless status_validator.valid?(@status)
  orientation_validator = EnumAttributeValidator.new('String', ["horizontal", "vertical"])
  return false unless orientation_validator.valid?(@orientation)
  return false if @date_created.nil?
  return false if @date_modified.nil?
  return false if @object.nil?
  object_validator = EnumAttributeValidator.new('String', ["card"])
  return false unless object_validator.valid?(@object)
  return false if !@description.nil? && @description.to_s.length > 255
  return false if @size.nil?
  size_validator = EnumAttributeValidator.new('String', ["3.375x2.125", "2.125x3.375"])
  return false unless size_validator.valid?(@size)
  true
end