Class: Lob::CardOrdersApi

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/api/card_orders_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CardOrdersApi

Returns a new instance of CardOrdersApi.



19
20
21
# File 'lib/lob/api/card_orders_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/lob/api/card_orders_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#card_order_create_with_http_info(card_id, card_order_editable, opts = {}) ⇒ Array<(CardOrder, Integer, Hash)>

create Creates a new card order given information

Parameters:

  • card_id (String)

    The ID of the card to which the card orders belong.

  • card_order_editable (CardOrderEditable)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CardOrder, Integer, Hash)>)

    CardOrder data, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/lob/api/card_orders_api.rb', line 39

def card_order_create_with_http_info(card_id, card_order_editable, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CardOrdersApi.card_order_create ...'
  end
  # verify the required parameter 'card_id' is set
  if @api_client.config.client_side_validation && card_id.nil?
    fail ArgumentError, "Missing the required parameter 'card_id' when calling CardOrdersApi.card_order_create"
  end
  pattern = Regexp.new(/^card_[a-zA-Z0-9]+$/)
  if @api_client.config.client_side_validation && card_id !~ pattern
    fail ArgumentError, "invalid value for 'card_id' when calling CardOrdersApi.card_order_create, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'card_order_editable' is set
  if @api_client.config.client_side_validation && card_order_editable.nil?
    fail ArgumentError, "Missing the required parameter 'card_order_editable' when calling CardOrdersApi.card_order_create"
  end
  # resource path
  local_var_path = '/cards/{card_id}/orders'.sub('{' + 'card_id' + '}', CGI.escape(card_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(card_order_editable)

  # return_type
  return_type = opts[:debug_return_type] || 'CardOrder'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"CardOrdersApi.card_order_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CardOrdersApi#card_order_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#card_orders_retrieve_with_http_info(card_id, opts = {}) ⇒ Array<(CardOrderList, Integer, Hash)>

get Retrieves the card orders associated with the given card id.

Parameters:

  • card_id (String)

    The ID of the card to which the card orders belong.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    How many results to return. (default to 10)

  • :offset (Integer)

    An integer that designates the offset at which to begin returning results. Defaults to 0. (default to 0)

Returns:

  • (Array<(CardOrderList, Integer, Hash)>)

    CardOrderList data, response status code and response headers



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/lob/api/card_orders_api.rb', line 120

def card_orders_retrieve_with_http_info(card_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CardOrdersApi.card_orders_retrieve ...'
  end
  # verify the required parameter 'card_id' is set
  if @api_client.config.client_side_validation && card_id.nil?
    fail ArgumentError, "Missing the required parameter 'card_id' when calling CardOrdersApi.card_orders_retrieve"
  end
  pattern = Regexp.new(/^card_[a-zA-Z0-9]+$/)
  if @api_client.config.client_side_validation && card_id !~ pattern
    fail ArgumentError, "invalid value for 'card_id' when calling CardOrdersApi.card_orders_retrieve, must conform to the pattern #{pattern}."
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CardOrdersApi.card_orders_retrieve, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CardOrdersApi.card_orders_retrieve, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/cards/{card_id}/orders'.sub('{' + 'card_id' + '}', CGI.escape(card_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CardOrderList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"CardOrdersApi.card_orders_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CardOrdersApi#card_orders_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create(card_id, card_order_editable, opts = {}) ⇒ CardOrder

create Creates a new card order given information

Parameters:

  • card_id (String)

    The ID of the card to which the card orders belong.

  • card_order_editable (CardOrderEditable)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



28
29
30
31
# File 'lib/lob/api/card_orders_api.rb', line 28

def create(card_id, card_order_editable, opts = {})
  data, _status_code, _headers = card_order_create_with_http_info(card_id, card_order_editable, opts)
  data
end

#get(card_id, opts = {}) ⇒ CardOrderList

get Retrieves the card orders associated with the given card id.

Parameters:

  • card_id (String)

    The ID of the card to which the card orders belong.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    How many results to return. (default to 10)

  • :offset (Integer)

    An integer that designates the offset at which to begin returning results. Defaults to 0. (default to 0)

Returns:



108
109
110
111
# File 'lib/lob/api/card_orders_api.rb', line 108

def get(card_id, opts = {})
  data, _status_code, _headers = card_orders_retrieve_with_http_info(card_id, opts)
  data
end