Class: Lob::CardsApi
- Inherits:
-
Object
- Object
- Lob::CardsApi
- Defined in:
- lib/lob/api/cards_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#card_create_with_http_info(card_editable, opts = {}) ⇒ Array<(Card, Integer, Hash)>
create Creates a new card given information.
-
#card_delete_with_http_info(card_id, opts = {}) ⇒ Array<(CardDeletion, Integer, Hash)>
delete Delete an existing card.
-
#card_retrieve_with_http_info(card_id, opts = {}) ⇒ Array<(Card, Integer, Hash)>
get Retrieves the details of an existing card.
-
#card_update_with_http_info(card_id, card_updatable, opts = {}) ⇒ Array<(Card, Integer, Hash)>
update Update the details of an existing card.
-
#cards_list_with_http_info(opts = {}) ⇒ Array<(CardList, Integer, Hash)>
list Returns a list of your cards.
-
#create(card_editable, opts = {}) ⇒ Card
create Creates a new card given information.
-
#delete(card_id, opts = {}) ⇒ CardDeletion
delete Delete an existing card.
-
#get(card_id, opts = {}) ⇒ Card
get Retrieves the details of an existing card.
-
#initialize(api_client = ApiClient.default) ⇒ CardsApi
constructor
A new instance of CardsApi.
-
#list(opts = {}) ⇒ CardList
list Returns a list of your cards.
-
#update(card_id, card_updatable, opts = {}) ⇒ Card
update Update the details of an existing card.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/lob/api/cards_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#card_create_with_http_info(card_editable, opts = {}) ⇒ Array<(Card, Integer, Hash)>
create Creates a new card given information
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/lob/api/cards_api.rb', line 37 def card_create_with_http_info(card_editable, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CardsApi.card_create ...' end # verify the required parameter 'card_editable' is set if @api_client.config.client_side_validation && card_editable.nil? fail ArgumentError, "Missing the required parameter 'card_editable' when calling CardsApi.card_create" end # resource path local_var_path = '/cards' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(card_editable) # return_type return_type = opts[:debug_return_type] || 'Card' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"CardsApi.card_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CardsApi#card_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#card_delete_with_http_info(card_id, opts = {}) ⇒ Array<(CardDeletion, Integer, Hash)>
delete Delete an existing card. You need only supply the unique identifier that was returned upon card creation.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/lob/api/cards_api.rb', line 105 def card_delete_with_http_info(card_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CardsApi.card_delete ...' end # verify the required parameter 'card_id' is set if @api_client.config.client_side_validation && card_id.nil? fail ArgumentError, "Missing the required parameter 'card_id' when calling CardsApi.card_delete" end pattern = Regexp.new(/^card_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && card_id !~ pattern fail ArgumentError, "invalid value for 'card_id' when calling CardsApi.card_delete, must conform to the pattern #{pattern}." end # resource path local_var_path = '/cards/{card_id}'.sub('{' + 'card_id' + '}', CGI.escape(card_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CardDeletion' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"CardsApi.card_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CardsApi#card_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#card_retrieve_with_http_info(card_id, opts = {}) ⇒ Array<(Card, Integer, Hash)>
get Retrieves the details of an existing card. You need only supply the unique customer identifier that was returned upon card creation.
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/lob/api/cards_api.rb', line 173 def card_retrieve_with_http_info(card_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CardsApi.card_retrieve ...' end # verify the required parameter 'card_id' is set if @api_client.config.client_side_validation && card_id.nil? fail ArgumentError, "Missing the required parameter 'card_id' when calling CardsApi.card_retrieve" end pattern = Regexp.new(/^card_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && card_id !~ pattern fail ArgumentError, "invalid value for 'card_id' when calling CardsApi.card_retrieve, must conform to the pattern #{pattern}." end # resource path local_var_path = '/cards/{card_id}'.sub('{' + 'card_id' + '}', CGI.escape(card_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Card' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"CardsApi.card_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CardsApi#card_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#card_update_with_http_info(card_id, card_updatable, opts = {}) ⇒ Array<(Card, Integer, Hash)>
update Update the details of an existing card. You need only supply the unique identifier that was returned upon card creation.
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/lob/api/cards_api.rb', line 243 def card_update_with_http_info(card_id, card_updatable, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CardsApi.card_update ...' end # verify the required parameter 'card_id' is set if @api_client.config.client_side_validation && card_id.nil? fail ArgumentError, "Missing the required parameter 'card_id' when calling CardsApi.card_update" end pattern = Regexp.new(/^card_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && card_id !~ pattern fail ArgumentError, "invalid value for 'card_id' when calling CardsApi.card_update, must conform to the pattern #{pattern}." end # verify the required parameter 'card_updatable' is set if @api_client.config.client_side_validation && card_updatable.nil? fail ArgumentError, "Missing the required parameter 'card_updatable' when calling CardsApi.card_update" end # resource path local_var_path = '/cards/{card_id}'.sub('{' + 'card_id' + '}', CGI.escape(card_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(card_updatable) # return_type return_type = opts[:debug_return_type] || 'Card' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"CardsApi.card_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CardsApi#card_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#cards_list_with_http_info(opts = {}) ⇒ Array<(CardList, Integer, Hash)>
list Returns a list of your cards. The cards are returned sorted by creation date, with the most recently created addresses appearing first.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/lob/api/cards_api.rb', line 326 def cards_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CardsApi.cards_list ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CardsApi.cards_list, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CardsApi.cards_list, must be greater than or equal to 1.' end # resource path local_var_path = '/cards' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'before'] = opts[:'before'] if !opts[:'before'].nil? query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil? query_params[:'include'] = @api_client.build_collection_param(opts[:'include'], :multi) if !opts[:'include'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CardList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"CardsApi.cards_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CardsApi#cards_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create(card_editable, opts = {}) ⇒ Card
create Creates a new card given information
27 28 29 30 |
# File 'lib/lob/api/cards_api.rb', line 27 def create(card_editable, opts = {}) data, _status_code, _headers = card_create_with_http_info(card_editable, opts) data end |
#delete(card_id, opts = {}) ⇒ CardDeletion
delete Delete an existing card. You need only supply the unique identifier that was returned upon card creation.
95 96 97 98 |
# File 'lib/lob/api/cards_api.rb', line 95 def delete(card_id, opts = {}) data, _status_code, _headers = card_delete_with_http_info(card_id, opts) data end |
#get(card_id, opts = {}) ⇒ Card
get Retrieves the details of an existing card. You need only supply the unique customer identifier that was returned upon card creation.
163 164 165 166 |
# File 'lib/lob/api/cards_api.rb', line 163 def get(card_id, opts = {}) data, _status_code, _headers = card_retrieve_with_http_info(card_id, opts) data end |
#list(opts = {}) ⇒ CardList
list Returns a list of your cards. The cards are returned sorted by creation date, with the most recently created addresses appearing first.
313 314 315 316 |
# File 'lib/lob/api/cards_api.rb', line 313 def list(opts = {}) data, _status_code, _headers = cards_list_with_http_info(opts) data end |
#update(card_id, card_updatable, opts = {}) ⇒ Card
update Update the details of an existing card. You need only supply the unique identifier that was returned upon card creation.
232 233 234 235 |
# File 'lib/lob/api/cards_api.rb', line 232 def update(card_id, card_updatable, opts = {}) data, _status_code, _headers = card_update_with_http_info(card_id, card_updatable, opts) data end |