Class: Lob::Check

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/check.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Check

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/lob/models/check.rb', line 198

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::Check` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::Check`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'merge_variables')
    self.merge_variables = attributes[:'merge_variables']
  end

  if attributes.key?(:'send_date')
    self.send_date = attributes[:'send_date']
  end

  if attributes.key?(:'mail_type')
    self.mail_type = attributes[:'mail_type']
  else
    self.mail_type = 'usps_first_class'
  end

  if attributes.key?(:'memo')
    self.memo = attributes[:'memo']
  end

  if attributes.key?(:'check_number')
    self.check_number = attributes[:'check_number']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'bank_account')
    self. = attributes[:'bank_account']
  end

  if attributes.key?(:'check_bottom_template_id')
    self.check_bottom_template_id = attributes[:'check_bottom_template_id']
  end

  if attributes.key?(:'attachment_template_id')
    self.attachment_template_id = attributes[:'attachment_template_id']
  end

  if attributes.key?(:'check_bottom_template_version_id')
    self.check_bottom_template_version_id = attributes[:'check_bottom_template_version_id']
  end

  if attributes.key?(:'attachment_template_version_id')
    self.attachment_template_version_id = attributes[:'attachment_template_version_id']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'carrier')
    self.carrier = attributes[:'carrier']
  else
    self.carrier = 'USPS'
  end

  if attributes.key?(:'thumbnails')
    if (value = attributes[:'thumbnails']).is_a?(Array)
      self.thumbnails = value
    end
  end

  if attributes.key?(:'expected_delivery_date')
    self.expected_delivery_date = attributes[:'expected_delivery_date']
  end

  if attributes.key?(:'tracking_events')
    if (value = attributes[:'tracking_events']).is_a?(Array)
      self.tracking_events = value
    end
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = 'check'
  end

  if attributes.key?(:'date_created')
    self.date_created = attributes[:'date_created']
  end

  if attributes.key?(:'date_modified')
    self.date_modified = attributes[:'date_modified']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end

  if attributes.key?(:'use_type')
    self.use_type = attributes[:'use_type']
  end
end

Instance Attribute Details

#amountObject

The payment amount to be sent in US dollars.



50
51
52
# File 'lib/lob/models/check.rb', line 50

def amount
  @amount
end

#attachment_template_idObject

Unique identifier prefixed with ‘tmpl_`. ID of a saved [HTML template](#section/HTML-Templates).



58
59
60
# File 'lib/lob/models/check.rb', line 58

def attachment_template_id
  @attachment_template_id
end

#attachment_template_version_idObject

Unique identifier prefixed with ‘vrsn_`.



64
65
66
# File 'lib/lob/models/check.rb', line 64

def attachment_template_version_id
  @attachment_template_version_id
end

#bank_accountObject

Returns the value of attribute bank_account.



52
53
54
# File 'lib/lob/models/check.rb', line 52

def 
  @bank_account
end

#carrierObject

Returns the value of attribute carrier.



69
70
71
# File 'lib/lob/models/check.rb', line 69

def carrier
  @carrier
end

#check_bottom_template_idObject

Unique identifier prefixed with ‘tmpl_`. ID of a saved [HTML template](#section/HTML-Templates).



55
56
57
# File 'lib/lob/models/check.rb', line 55

def check_bottom_template_id
  @check_bottom_template_id
end

#check_bottom_template_version_idObject

Unique identifier prefixed with ‘vrsn_`.



61
62
63
# File 'lib/lob/models/check.rb', line 61

def check_bottom_template_version_id
  @check_bottom_template_version_id
end

#check_numberObject

An integer that designates the check number. If ‘check_number` is not provided, checks created from a new `bank_account` will start at `10000` and increment with each check created with the `bank_account`. A provided `check_number` overrides the defaults. Subsequent checks created with the same `bank_account` will increment from the provided check number.



44
45
46
# File 'lib/lob/models/check.rb', line 44

def check_number
  @check_number
end

#date_createdObject

A timestamp in ISO 8601 format of the date the resource was created.



82
83
84
# File 'lib/lob/models/check.rb', line 82

def date_created
  @date_created
end

#date_modifiedObject

A timestamp in ISO 8601 format of the date the resource was last modified.



85
86
87
# File 'lib/lob/models/check.rb', line 85

def date_modified
  @date_modified
end

#deletedObject

Only returned if the resource has been successfully deleted.



88
89
90
# File 'lib/lob/models/check.rb', line 88

def deleted
  @deleted
end

#descriptionObject

An internal description that identifies this resource. Must be no longer than 255 characters.



26
27
28
# File 'lib/lob/models/check.rb', line 26

def description
  @description
end

#expected_delivery_dateObject

A date in YYYY-MM-DD format of the mailpiece’s expected delivery date based on its ‘send_date`.



74
75
76
# File 'lib/lob/models/check.rb', line 74

def expected_delivery_date
  @expected_delivery_date
end

#fromObject

Returns the value of attribute from.



23
24
25
# File 'lib/lob/models/check.rb', line 23

def from
  @from
end

#idObject

Unique identifier prefixed with ‘chk_`.



19
20
21
# File 'lib/lob/models/check.rb', line 19

def id
  @id
end

#mail_typeObject

Checks must be sent ‘usps_first_class`



38
39
40
# File 'lib/lob/models/check.rb', line 38

def mail_type
  @mail_type
end

#memoObject

Text to include on the memo line of the check.



41
42
43
# File 'lib/lob/models/check.rb', line 41

def memo
  @memo
end

#merge_variablesObject

You can input a merge variable payload object to your template to render dynamic content. For example, if you have a template like: ‘{variable_name}`, pass in `"Harry"` to render `Harry`. `merge_variables` must be an object. Any type of value is accepted as long as the object is valid JSON; you can use `strings`, `numbers`, `booleans`, `arrays`, `objects`, or `null`. The max length of the object is 25,000 characters. If you call `JSON.stringify` on your object, it can be no longer than 25,000 characters. Your variable names cannot contain any whitespace or any of the following special characters: `!`, `"`, `#`, `%`, `&`, `’‘, `(`, `)`, `*`, `+`, `,`, `/`, `;`, `<`, `=`, `>`, `@`, `[`, `\`, `]`, `^`, “ ` “, ``|`, ``, `~`. More instructions can be found in [our guide to using html and merge variables](lob.com/resources/guides/general/using-html-and-merge-variables). Depending on your [Merge Variable strictness](dashboard.lob.com/#/settings/account) setting, if you define variables in your HTML but do not pass them here, you will either receive an error or the variable will render as an empty string.



32
33
34
# File 'lib/lob/models/check.rb', line 32

def merge_variables
  @merge_variables
end

#messageObject

Max of 400 characters to be included at the bottom of the check page.



47
48
49
# File 'lib/lob/models/check.rb', line 47

def message
  @message
end

#metadataObject

Use metadata to store custom information for tagging and labeling back to your internal systems. Must be an object with up to 20 key-value pairs. Keys must be at most 40 characters and values must be at most 500 characters. Neither can contain the characters ‘"` and `\`. i.e. ’: "NEWYORK2015"‘ Nested objects are not supported. See [Metadata](#section/Metadata) for more information.



29
30
31
# File 'lib/lob/models/check.rb', line 29

def 
  @metadata
end

#objectObject

Returns the value of attribute object.



79
80
81
# File 'lib/lob/models/check.rb', line 79

def object
  @object
end

#send_dateObject

A timestamp in ISO 8601 format which specifies a date after the current time and up to 180 days in the future to send the letter off for production. Setting a send date overrides the default [cancellation window](#section/Cancellation-Windows) applied to the mailpiece. Until the ‘send_date` has passed, the mailpiece can be canceled. If a date in the format `2017-11-01` is passed, it will evaluate to midnight UTC of that date (`2017-11-01T00:00:00.000Z`). If a datetime is passed, that exact time will be used. A `send_date` passed with no time zone will default to UTC, while a `send_date` passed with a time zone will be converted to UTC.



35
36
37
# File 'lib/lob/models/check.rb', line 35

def send_date
  @send_date
end

#thumbnailsObject

Returns the value of attribute thumbnails.



71
72
73
# File 'lib/lob/models/check.rb', line 71

def thumbnails
  @thumbnails
end

#toObject

Returns the value of attribute to.



21
22
23
# File 'lib/lob/models/check.rb', line 21

def to
  @to
end

#tracking_eventsObject

An array of tracking_event objects ordered by ascending ‘time`. Will not be populated for checks created in test mode.



77
78
79
# File 'lib/lob/models/check.rb', line 77

def tracking_events
  @tracking_events
end

#urlObject

A [signed link](#section/Asset-URLs) served over HTTPS. The link returned will expire in 30 days to prevent mis-sharing. Each time a GET request is initiated, a new signed URL will be generated.



67
68
69
# File 'lib/lob/models/check.rb', line 67

def url
  @url
end

#use_typeObject

Returns the value of attribute use_type.



90
91
92
# File 'lib/lob/models/check.rb', line 90

def use_type
  @use_type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



148
149
150
# File 'lib/lob/models/check.rb', line 148

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/lob/models/check.rb', line 115

def self.attribute_map
  {
    :'id' => :'id',
    :'to' => :'to',
    :'from' => :'from',
    :'description' => :'description',
    :'metadata' => :'metadata',
    :'merge_variables' => :'merge_variables',
    :'send_date' => :'send_date',
    :'mail_type' => :'mail_type',
    :'memo' => :'memo',
    :'check_number' => :'check_number',
    :'message' => :'message',
    :'amount' => :'amount',
    :'bank_account' => :'bank_account',
    :'check_bottom_template_id' => :'check_bottom_template_id',
    :'attachment_template_id' => :'attachment_template_id',
    :'check_bottom_template_version_id' => :'check_bottom_template_version_id',
    :'attachment_template_version_id' => :'attachment_template_version_id',
    :'url' => :'url',
    :'carrier' => :'carrier',
    :'thumbnails' => :'thumbnails',
    :'expected_delivery_date' => :'expected_delivery_date',
    :'tracking_events' => :'tracking_events',
    :'object' => :'object',
    :'date_created' => :'date_created',
    :'date_modified' => :'date_modified',
    :'deleted' => :'deleted',
    :'use_type' => :'use_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



686
687
688
# File 'lib/lob/models/check.rb', line 686

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



186
187
188
189
190
191
192
193
194
# File 'lib/lob/models/check.rb', line 186

def self.openapi_nullable
  Set.new([
    :'description',
    :'merge_variables',
    :'memo',
    :'tracking_events',
    :'use_type'
  ])
end

.openapi_typesObject

Attribute type mapping.



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/lob/models/check.rb', line 153

def self.openapi_types
  {
    :'id' => :'String',
    :'to' => :'Address',
    :'from' => :'Address',
    :'description' => :'String',
    :'metadata' => :'Hash<String, String>',
    :'merge_variables' => :'Object',
    :'send_date' => :'Time',
    :'mail_type' => :'String',
    :'memo' => :'String',
    :'check_number' => :'Integer',
    :'message' => :'String',
    :'amount' => :'Float',
    :'bank_account' => :'BankAccount',
    :'check_bottom_template_id' => :'String',
    :'attachment_template_id' => :'String',
    :'check_bottom_template_version_id' => :'String',
    :'attachment_template_version_id' => :'String',
    :'url' => :'String',
    :'carrier' => :'String',
    :'thumbnails' => :'Array<Thumbnail>',
    :'expected_delivery_date' => :'Date',
    :'tracking_events' => :'Array<TrackingEventNormal>',
    :'object' => :'String',
    :'date_created' => :'Time',
    :'date_modified' => :'Time',
    :'deleted' => :'Boolean',
    :'use_type' => :'ChkUseType'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
# File 'lib/lob/models/check.rb', line 638

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      to == o.to &&
      from == o.from &&
      description == o.description &&
       == o. &&
      merge_variables == o.merge_variables &&
      send_date == o.send_date &&
      mail_type == o.mail_type &&
      memo == o.memo &&
      check_number == o.check_number &&
      message == o.message &&
      amount == o.amount &&
       == o. &&
      check_bottom_template_id == o.check_bottom_template_id &&
      attachment_template_id == o.attachment_template_id &&
      check_bottom_template_version_id == o.check_bottom_template_version_id &&
      attachment_template_version_id == o.attachment_template_version_id &&
      url == o.url &&
      carrier == o.carrier &&
      thumbnails == o.thumbnails &&
      expected_delivery_date == o.expected_delivery_date &&
      tracking_events == o.tracking_events &&
      object == o.object &&
      date_created == o.date_created &&
      date_modified == o.date_modified &&
      deleted == o.deleted &&
      use_type == o.use_type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
# File 'lib/lob/models/check.rb', line 725

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



796
797
798
799
800
801
802
803
804
805
806
807
808
# File 'lib/lob/models/check.rb', line 796

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
# File 'lib/lob/models/check.rb', line 693

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


672
673
674
# File 'lib/lob/models/check.rb', line 672

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



678
679
680
# File 'lib/lob/models/check.rb', line 678

def hash
  [id, to, from, description, , merge_variables, send_date, mail_type, memo, check_number, message, amount, , check_bottom_template_id, attachment_template_id, check_bottom_template_version_id, attachment_template_version_id, url, carrier, thumbnails, expected_delivery_date, tracking_events, object, date_created, date_modified, deleted, use_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/lob/models/check.rb', line 334

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  pattern = Regexp.new(/^chk_[a-zA-Z0-9]+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if @to.nil?
    invalid_properties.push('invalid value for "to", to cannot be nil.')
  end

  if !@description.nil? && @description.to_s.length > 255
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.')
  end

  if !@memo.nil? && @memo.to_s.length > 40
    invalid_properties.push('invalid value for "memo", the character length must be smaller than or equal to 40.')
  end

  if !@check_number.nil? && @check_number > 500000000
    invalid_properties.push('invalid value for "check_number", must be smaller than or equal to 500000000.')
  end

  if !@check_number.nil? && @check_number < 1
    invalid_properties.push('invalid value for "check_number", must be greater than or equal to 1.')
  end

  if !@message.nil? && @message.to_s.length > 400
    invalid_properties.push('invalid value for "message", the character length must be smaller than or equal to 400.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @amount > 999999.99
    invalid_properties.push('invalid value for "amount", must be smaller than or equal to 999999.99.')
  end

  if @bank_account.nil?
    invalid_properties.push('invalid value for "bank_account", bank_account cannot be nil.')
  end

  pattern = Regexp.new(/^tmpl_[a-zA-Z0-9]+$/)
  if !@check_bottom_template_id.nil? && @check_bottom_template_id !~ pattern
    invalid_properties.push("invalid value for \"check_bottom_template_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^tmpl_[a-zA-Z0-9]+$/)
  if !@attachment_template_id.nil? && @attachment_template_id !~ pattern
    invalid_properties.push("invalid value for \"attachment_template_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^vrsn_[a-zA-Z0-9]+$/)
  if !@check_bottom_template_version_id.nil? && @check_bottom_template_version_id !~ pattern
    invalid_properties.push("invalid value for \"check_bottom_template_version_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^vrsn_[a-zA-Z0-9]+$/)
  if !@attachment_template_version_id.nil? && @attachment_template_version_id !~ pattern
    invalid_properties.push("invalid value for \"attachment_template_version_id\", must conform to the pattern #{pattern}.")
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  pattern = Regexp.new(/^https:\/\/lob-assets.com\/(letters|postcards|bank-accounts|checks|self-mailers|cards)\/[a-z]{3,4}_[a-z0-9]{15,16}(_signature)?(\.pdf|_thumb_[a-z]+_[0-9]+\.png|\.png)\?(version=[a-z0-9]*&)expires=[0-9]{10}&signature=[a-zA-Z0-9_-]+/)
  if @url !~ pattern
    invalid_properties.push("invalid value for \"url\", must conform to the pattern #{pattern}.")
  end

  if @carrier.nil?
    invalid_properties.push('invalid value for "carrier", carrier cannot be nil.')
  end

  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  if @date_created.nil?
    invalid_properties.push('invalid value for "date_created", date_created cannot be nil.')
  end

  if @date_modified.nil?
    invalid_properties.push('invalid value for "date_modified", date_modified cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



772
773
774
# File 'lib/lob/models/check.rb', line 772

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



778
779
780
781
782
783
784
785
786
787
788
789
790
# File 'lib/lob/models/check.rb', line 778

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



766
767
768
# File 'lib/lob/models/check.rb', line 766

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
# File 'lib/lob/models/check.rb', line 431

def valid?
  return false if @id.nil?
  return false if @id !~ Regexp.new(/^chk_[a-zA-Z0-9]+$/)
  return false if @to.nil?
  return false if !@description.nil? && @description.to_s.length > 255
  mail_type_validator = EnumAttributeValidator.new('String', ["usps_first_class"])
  return false unless mail_type_validator.valid?(@mail_type)
  return false if !@memo.nil? && @memo.to_s.length > 40
  return false if !@check_number.nil? && @check_number > 500000000
  return false if !@check_number.nil? && @check_number < 1
  return false if !@message.nil? && @message.to_s.length > 400
  return false if @amount.nil?
  return false if @amount > 999999.99
  return false if @bank_account.nil?
  return false if !@check_bottom_template_id.nil? && @check_bottom_template_id !~ Regexp.new(/^tmpl_[a-zA-Z0-9]+$/)
  return false if !@attachment_template_id.nil? && @attachment_template_id !~ Regexp.new(/^tmpl_[a-zA-Z0-9]+$/)
  return false if !@check_bottom_template_version_id.nil? && @check_bottom_template_version_id !~ Regexp.new(/^vrsn_[a-zA-Z0-9]+$/)
  return false if !@attachment_template_version_id.nil? && @attachment_template_version_id !~ Regexp.new(/^vrsn_[a-zA-Z0-9]+$/)
  return false if @url.nil?
  return false if @url !~ Regexp.new(/^https:\/\/lob-assets.com\/(letters|postcards|bank-accounts|checks|self-mailers|cards)\/[a-z]{3,4}_[a-z0-9]{15,16}(_signature)?(\.pdf|_thumb_[a-z]+_[0-9]+\.png|\.png)\?(version=[a-z0-9]*&)expires=[0-9]{10}&signature=[a-zA-Z0-9_-]+/)
  return false if @carrier.nil?
  carrier_validator = EnumAttributeValidator.new('String', ["USPS"])
  return false unless carrier_validator.valid?(@carrier)
  return false if @object.nil?
  object_validator = EnumAttributeValidator.new('String', ["check"])
  return false unless object_validator.valid?(@object)
  return false if @date_created.nil?
  return false if @date_modified.nil?
  true
end