Class: Lob::CheckEditable

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/check_editable.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CheckEditable

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/lob/models/check_editable.rb', line 155

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::CheckEditable` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::CheckEditable`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  end

  if attributes.key?(:'bank_account')
    self. = attributes[:'bank_account']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'logo')
    self. = attributes[:'logo']
  end

  if attributes.key?(:'check_bottom')
    self.check_bottom = attributes[:'check_bottom']
  end

  if attributes.key?(:'attachment')
    self.attachment = attributes[:'attachment']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'merge_variables')
    self.merge_variables = attributes[:'merge_variables']
  end

  if attributes.key?(:'send_date')
    self.send_date = attributes[:'send_date']
  end

  if attributes.key?(:'mail_type')
    self.mail_type = attributes[:'mail_type']
  else
    self.mail_type = 'usps_first_class'
  end

  if attributes.key?(:'memo')
    self.memo = attributes[:'memo']
  end

  if attributes.key?(:'check_number')
    self.check_number = attributes[:'check_number']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'billing_group_id')
    self.billing_group_id = attributes[:'billing_group_id']
  end

  if attributes.key?(:'use_type')
    self.use_type = attributes[:'use_type']
  end
end

Instance Attribute Details

#amountObject

The payment amount to be sent in US dollars.



27
28
29
# File 'lib/lob/models/check_editable.rb', line 27

def amount
  @amount
end

#attachmentObject

A document to include with the check.



36
37
38
# File 'lib/lob/models/check_editable.rb', line 36

def attachment
  @attachment
end

#bank_accountObject

Returns the value of attribute bank_account.



24
25
26
# File 'lib/lob/models/check_editable.rb', line 24

def 
  @bank_account
end

#billing_group_idObject

An optional string with the billing group ID to tag your usage with. Is used for billing purposes. Requires special activation to use. See [Billing Group API](lob.github.io/lob-openapi/#tag/Billing-Groups) for more information.



63
64
65
# File 'lib/lob/models/check_editable.rb', line 63

def billing_group_id
  @billing_group_id
end

#check_bottomObject

The artwork to use on the bottom of the check page. Notes: - HTML merge variables should not include delimiting whitespace. - PDF, PNG, and JPGs must be sized at 8.5"x11" at 300 DPI, while supplied HTML will be rendered and trimmed to fit on a 8.5"x11" page. - The check bottom will always be printed in black & white. - Must conform to [this template](s3-us-west-2.amazonaws.com/public.lob.com/assets/templates/check_bottom_template.pdf). Need more help? Consult our [HTML examples](#section/HTML-Examples).



33
34
35
# File 'lib/lob/models/check_editable.rb', line 33

def check_bottom
  @check_bottom
end

#check_numberObject

An integer that designates the check number.



57
58
59
# File 'lib/lob/models/check_editable.rb', line 57

def check_number
  @check_number
end

#descriptionObject

An internal description that identifies this resource. Must be no longer than 255 characters.



39
40
41
# File 'lib/lob/models/check_editable.rb', line 39

def description
  @description
end

#fromObject

Must either be an address ID or an inline object with correct address parameters.



19
20
21
# File 'lib/lob/models/check_editable.rb', line 19

def from
  @from
end

#logoObject

Accepts a remote URL or local file upload to an image to print (in grayscale) in the upper-left corner of your check.



30
31
32
# File 'lib/lob/models/check_editable.rb', line 30

def 
  @logo
end

#mail_typeObject

Checks must be sent ‘usps_first_class`



51
52
53
# File 'lib/lob/models/check_editable.rb', line 51

def mail_type
  @mail_type
end

#memoObject

Text to include on the memo line of the check.



54
55
56
# File 'lib/lob/models/check_editable.rb', line 54

def memo
  @memo
end

#merge_variablesObject

You can input a merge variable payload object to your template to render dynamic content. For example, if you have a template like: ‘{variable_name}`, pass in `"Harry"` to render `Harry`. `merge_variables` must be an object. Any type of value is accepted as long as the object is valid JSON; you can use `strings`, `numbers`, `booleans`, `arrays`, `objects`, or `null`. The max length of the object is 25,000 characters. If you call `JSON.stringify` on your object, it can be no longer than 25,000 characters. Your variable names cannot contain any whitespace or any of the following special characters: `!`, `"`, `#`, `%`, `&`, `’‘, `(`, `)`, `*`, `+`, `,`, `/`, `;`, `<`, `=`, `>`, `@`, `[`, `\`, `]`, `^`, “ ` “, ``|`, ``, `~`. More instructions can be found in [our guide to using html and merge variables](lob.com/resources/guides/general/using-html-and-merge-variables). Depending on your [Merge Variable strictness](dashboard.lob.com/#/settings/account) setting, if you define variables in your HTML but do not pass them here, you will either receive an error or the variable will render as an empty string.



45
46
47
# File 'lib/lob/models/check_editable.rb', line 45

def merge_variables
  @merge_variables
end

#messageObject

Max of 400 characters to be included at the bottom of the check page.



60
61
62
# File 'lib/lob/models/check_editable.rb', line 60

def message
  @message
end

#metadataObject

Use metadata to store custom information for tagging and labeling back to your internal systems. Must be an object with up to 20 key-value pairs. Keys must be at most 40 characters and values must be at most 500 characters. Neither can contain the characters ‘"` and `\`. i.e. ’: "NEWYORK2015"‘ Nested objects are not supported. See [Metadata](#section/Metadata) for more information.



42
43
44
# File 'lib/lob/models/check_editable.rb', line 42

def 
  @metadata
end

#send_dateObject

A timestamp in ISO 8601 format which specifies a date after the current time and up to 180 days in the future to send the letter off for production. Setting a send date overrides the default [cancellation window](#section/Cancellation-Windows) applied to the mailpiece. Until the ‘send_date` has passed, the mailpiece can be canceled. If a date in the format `2017-11-01` is passed, it will evaluate to midnight UTC of that date (`2017-11-01T00:00:00.000Z`). If a datetime is passed, that exact time will be used. A `send_date` passed with no time zone will default to UTC, while a `send_date` passed with a time zone will be converted to UTC.



48
49
50
# File 'lib/lob/models/check_editable.rb', line 48

def send_date
  @send_date
end

#toObject

Must either be an address ID or an inline object with correct address parameters.



22
23
24
# File 'lib/lob/models/check_editable.rb', line 22

def to
  @to
end

#use_typeObject

Returns the value of attribute use_type.



65
66
67
# File 'lib/lob/models/check_editable.rb', line 65

def use_type
  @use_type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



113
114
115
# File 'lib/lob/models/check_editable.rb', line 113

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/lob/models/check_editable.rb', line 90

def self.attribute_map
  {
    :'from' => :'from',
    :'to' => :'to',
    :'bank_account' => :'bank_account',
    :'amount' => :'amount',
    :'logo' => :'logo',
    :'check_bottom' => :'check_bottom',
    :'attachment' => :'attachment',
    :'description' => :'description',
    :'metadata' => :'metadata',
    :'merge_variables' => :'merge_variables',
    :'send_date' => :'send_date',
    :'mail_type' => :'mail_type',
    :'memo' => :'memo',
    :'check_number' => :'check_number',
    :'message' => :'message',
    :'billing_group_id' => :'billing_group_id',
    :'use_type' => :'use_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



411
412
413
# File 'lib/lob/models/check_editable.rb', line 411

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



141
142
143
144
145
146
147
148
149
150
151
# File 'lib/lob/models/check_editable.rb', line 141

def self.openapi_nullable
  Set.new([
    :'from',
    :'to',
    :'bank_account',
    :'description',
    :'merge_variables',
    :'memo',
    :'use_type'
  ])
end

.openapi_typesObject

Attribute type mapping.



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/lob/models/check_editable.rb', line 118

def self.openapi_types
  {
    :'from' => Array[:'AddressDomestic', :'String'],
    :'to' => Array[:'AddressDomestic', :'String'],
    :'bank_account' => :'String',
    :'amount' => :'Float',
    :'logo' => :'String',
    :'check_bottom' => :'String',
    :'attachment' => :'String',
    :'description' => :'String',
    :'metadata' => :'Hash<String, String>',
    :'merge_variables' => :'Object',
    :'send_date' => :'Time',
    :'mail_type' => :'String',
    :'memo' => :'String',
    :'check_number' => :'Integer',
    :'message' => :'String',
    :'billing_group_id' => :'String',
    :'use_type' => :'ChkUseType'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/lob/models/check_editable.rb', line 373

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      from == o.from &&
      to == o.to &&
       == o. &&
      amount == o.amount &&
       == o. &&
      check_bottom == o.check_bottom &&
      attachment == o.attachment &&
      description == o.description &&
       == o. &&
      merge_variables == o.merge_variables &&
      send_date == o.send_date &&
      mail_type == o.mail_type &&
      memo == o.memo &&
      check_number == o.check_number &&
      message == o.message &&
      billing_group_id == o.billing_group_id &&
      use_type == o.use_type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
# File 'lib/lob/models/check_editable.rb', line 450

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



521
522
523
524
525
526
527
528
529
530
531
532
533
# File 'lib/lob/models/check_editable.rb', line 521

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'lib/lob/models/check_editable.rb', line 418

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


397
398
399
# File 'lib/lob/models/check_editable.rb', line 397

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



403
404
405
# File 'lib/lob/models/check_editable.rb', line 403

def hash
  [from, to, , amount, , check_bottom, attachment, description, , merge_variables, send_date, mail_type, memo, check_number, message, billing_group_id, use_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/lob/models/check_editable.rb', line 243

def list_invalid_properties
  invalid_properties = Array.new
  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @amount > 999999.99
    invalid_properties.push('invalid value for "amount", must be smaller than or equal to 999999.99.')
  end

  if !@description.nil? && @description.to_s.length > 255
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.')
  end

  if !@memo.nil? && @memo.to_s.length > 40
    invalid_properties.push('invalid value for "memo", the character length must be smaller than or equal to 40.')
  end

  if !@check_number.nil? && @check_number > 500000000
    invalid_properties.push('invalid value for "check_number", must be smaller than or equal to 500000000.')
  end

  if !@check_number.nil? && @check_number < 1
    invalid_properties.push('invalid value for "check_number", must be greater than or equal to 1.')
  end

  if !@message.nil? && @message.to_s.length > 400
    invalid_properties.push('invalid value for "message", the character length must be smaller than or equal to 400.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



497
498
499
# File 'lib/lob/models/check_editable.rb', line 497

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'lib/lob/models/check_editable.rb', line 503

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



491
492
493
# File 'lib/lob/models/check_editable.rb', line 491

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/lob/models/check_editable.rb', line 278

def valid?
  return false if @amount.nil?
  return false if @amount > 999999.99
  return false if !@description.nil? && @description.to_s.length > 255
  mail_type_validator = EnumAttributeValidator.new('String', ["usps_first_class"])
  return false unless mail_type_validator.valid?(@mail_type)
  return false if !@memo.nil? && @memo.to_s.length > 40
  return false if !@check_number.nil? && @check_number > 500000000
  return false if !@check_number.nil? && @check_number < 1
  return false if !@message.nil? && @message.to_s.length > 400
  true
end