Class: Lob::ChecksApi

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/api/checks_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ChecksApi

Returns a new instance of ChecksApi.



19
20
21
# File 'lib/lob/api/checks_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/lob/api/checks_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#cancel(chk_id, opts = {}) ⇒ CheckDeletion

cancel Completely removes a check from production. This can only be done if the check has a ‘send_date` and the `send_date` has not yet passed. If the check is successfully canceled, you will not be charged for it. Read more on [cancellation windows](#section/Cancellation-Windows) and [scheduling](#section/Scheduled-Mailings). Scheduling and cancellation is a premium feature. Upgrade to the appropriate [Print & Mail Edition](dashboard.lob.com/#/settings/editions) to gain access.

Parameters:

  • chk_id (String)

    id of the check

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/lob/api/checks_api.rb', line 27

def cancel(chk_id, opts = {})
  data, _status_code, _headers = check_cancel_with_http_info(chk_id, opts)
  data
end

#check_cancel_with_http_info(chk_id, opts = {}) ⇒ Array<(CheckDeletion, Integer, Hash)>

cancel Completely removes a check from production. This can only be done if the check has a &#x60;send_date&#x60; and the &#x60;send_date&#x60; has not yet passed. If the check is successfully canceled, you will not be charged for it. Read more on [cancellation windows](#section/Cancellation-Windows) and [scheduling](#section/Scheduled-Mailings). Scheduling and cancellation is a premium feature. Upgrade to the appropriate [Print &amp; Mail Edition](dashboard.lob.com/#/settings/editions) to gain access.

Parameters:

  • chk_id (String)

    id of the check

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CheckDeletion, Integer, Hash)>)

    CheckDeletion data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/lob/api/checks_api.rb', line 37

def check_cancel_with_http_info(chk_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ChecksApi.check_cancel ...'
  end
  # verify the required parameter 'chk_id' is set
  if @api_client.config.client_side_validation && chk_id.nil?
    fail ArgumentError, "Missing the required parameter 'chk_id' when calling ChecksApi.check_cancel"
  end
  pattern = Regexp.new(/^chk_[a-zA-Z0-9]+$/)
  if @api_client.config.client_side_validation && chk_id !~ pattern
    fail ArgumentError, "invalid value for 'chk_id' when calling ChecksApi.check_cancel, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/checks/{chk_id}'.sub('{' + 'chk_id' + '}', CGI.escape(chk_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CheckDeletion'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"ChecksApi.check_cancel",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ChecksApi#check_cancel\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#check_create_with_http_info(check_editable, opts = {}) ⇒ Array<(Check, Integer, Hash)>

create Creates a new check with the provided properties.

Parameters:

  • check_editable (CheckEditable)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :idempotency_key (String)

    A string of no longer than 256 characters that uniquely identifies this resource. For more help integrating idempotency keys, refer to our [implementation guide](www.lob.com/guides#idempotent_request).

Returns:

  • (Array<(Check, Integer, Hash)>)

    Check data, response status code and response headers



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/lob/api/checks_api.rb', line 107

def check_create_with_http_info(check_editable, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ChecksApi.check_create ...'
  end
  # verify the required parameter 'check_editable' is set
  if @api_client.config.client_side_validation && check_editable.nil?
    fail ArgumentError, "Missing the required parameter 'check_editable' when calling ChecksApi.check_create"
  end
  if @api_client.config.client_side_validation && !opts[:'idempotency_key'].nil? && opts[:'idempotency_key'].to_s.length > 256
    fail ArgumentError, 'invalid value for "opts[:"idempotency_key"]" when calling ChecksApi.check_create, the character length must be smaller than or equal to 256.'
  end

  # resource path
  local_var_path = '/checks'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'Idempotency-Key'] = opts[:'idempotency_key'] if !opts[:'idempotency_key'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(check_editable)

  # return_type
  return_type = opts[:debug_return_type] || 'Check'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"ChecksApi.check_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ChecksApi#check_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#check_retrieve_with_http_info(chk_id, opts = {}) ⇒ Array<(Check, Integer, Hash)>

get Retrieves the details of an existing check. You need only supply the unique check identifier that was returned upon check creation.

Parameters:

  • chk_id (String)

    id of the check

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Check, Integer, Hash)>)

    Check data, response status code and response headers



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/lob/api/checks_api.rb', line 180

def check_retrieve_with_http_info(chk_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ChecksApi.check_retrieve ...'
  end
  # verify the required parameter 'chk_id' is set
  if @api_client.config.client_side_validation && chk_id.nil?
    fail ArgumentError, "Missing the required parameter 'chk_id' when calling ChecksApi.check_retrieve"
  end
  pattern = Regexp.new(/^chk_[a-zA-Z0-9]+$/)
  if @api_client.config.client_side_validation && chk_id !~ pattern
    fail ArgumentError, "invalid value for 'chk_id' when calling ChecksApi.check_retrieve, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/checks/{chk_id}'.sub('{' + 'chk_id' + '}', CGI.escape(chk_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Check'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"ChecksApi.check_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ChecksApi#check_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#checks_list_with_http_info(opts = {}) ⇒ Array<(CheckList, Integer, Hash)>

list Returns a list of your checks. The checks are returned sorted by creation date, with the most recently created checks appearing first.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    How many results to return. (default to 10)

  • :before (String)

    A reference to a list entry used for paginating to the previous set of entries. This field is pre-populated in the &#x60;previous_url&#x60; field in the return response.

  • :after (String)

    A reference to a list entry used for paginating to the next set of entries. This field is pre-populated in the &#x60;next_url&#x60; field in the return response.

  • :include (Array<String>)

    Request that the response include the total count by specifying &#x60;include[]&#x3D;total_count&#x60;.

  • :date_created (Hash<String, Time>)

    Filter by date created.

  • :metadata (Hash<String, String>)

    Filter by metadata key-value pair&#x60;.

  • :scheduled (Boolean)
    • &#x60;true&#x60; - only return orders (past or future) where &#x60;send_date&#x60; is greater than &#x60;date_created&#x60; * &#x60;false&#x60; - only return orders where &#x60;send_date&#x60; is equal to &#x60;date_created&#x60;

  • :send_date (Hash<String, String>)

    Filter by date sent.

  • :mail_type (MailType)

    A string designating the mail postage type: * &#x60;usps_first_class&#x60; - (default) * &#x60;usps_standard&#x60; - a [cheaper option](lob.com/pricing/print-mail#compare) which is less predictable and takes longer to deliver. &#x60;usps_standard&#x60; cannot be used with &#x60;4x6&#x60; postcards or for any postcards sent outside of the United States. (default to ‘usps_first_class’)

  • :sort_by (SortBy4)

    Sorts items by ascending or descending dates. Use either &#x60;date_created&#x60; or &#x60;send_date&#x60;, not both.

Returns:

  • (Array<(CheckList, Integer, Hash)>)

    CheckList data, response status code and response headers



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/lob/api/checks_api.rb', line 266

def checks_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ChecksApi.checks_list ...'
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling ChecksApi.checks_list, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling ChecksApi.checks_list, must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'metadata'].nil? && opts[:'metadata'].to_s.length > 500
    fail ArgumentError, 'invalid value for "opts[:"metadata"]" when calling ChecksApi.checks_list, the character length must be smaller than or equal to 500.'
  end

  pattern = Regexp.new(/[^"\\]{0,500}/)
  if @api_client.config.client_side_validation && !opts[:'metadata'].nil? && opts[:'metadata'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"metadata\"]' when calling ChecksApi.checks_list, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/checks'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'before'] = opts[:'before'] if !opts[:'before'].nil?
  query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil?
  query_params[:'include'] = @api_client.build_collection_param(opts[:'include'], :multi) if !opts[:'include'].nil?
  query_params[:'date_created'] = opts[:'date_created'] if !opts[:'date_created'].nil?
  query_params[:'metadata'] = opts[:'metadata'] if !opts[:'metadata'].nil?
  query_params[:'scheduled'] = opts[:'scheduled'] if !opts[:'scheduled'].nil?
  query_params[:'send_date'] = opts[:'send_date'] if !opts[:'send_date'].nil?
  query_params[:'mail_type'] = opts[:'mail_type'] if !opts[:'mail_type'].nil?
  query_params[:'sort_by'] = opts[:'sort_by'] if !opts[:'sort_by'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CheckList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"ChecksApi.checks_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ChecksApi#checks_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create(check_editable, opts = {}) ⇒ Check

create Creates a new check with the provided properties.

Parameters:

  • check_editable (CheckEditable)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :idempotency_key (String)

    A string of no longer than 256 characters that uniquely identifies this resource. For more help integrating idempotency keys, refer to our [implementation guide](www.lob.com/guides#idempotent_request).

Returns:



96
97
98
99
# File 'lib/lob/api/checks_api.rb', line 96

def create(check_editable, opts = {})
  data, _status_code, _headers = check_create_with_http_info(check_editable, opts)
  data
end

#get(chk_id, opts = {}) ⇒ Check

get Retrieves the details of an existing check. You need only supply the unique check identifier that was returned upon check creation.

Parameters:

  • chk_id (String)

    id of the check

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



170
171
172
173
# File 'lib/lob/api/checks_api.rb', line 170

def get(chk_id, opts = {})
  data, _status_code, _headers = check_retrieve_with_http_info(chk_id, opts)
  data
end

#list(opts = {}) ⇒ CheckList

list Returns a list of your checks. The checks are returned sorted by creation date, with the most recently created checks appearing first.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    How many results to return. (default to 10)

  • :before (String)

    A reference to a list entry used for paginating to the previous set of entries. This field is pre-populated in the &#x60;previous_url&#x60; field in the return response.

  • :after (String)

    A reference to a list entry used for paginating to the next set of entries. This field is pre-populated in the &#x60;next_url&#x60; field in the return response.

  • :include (Array<String>)

    Request that the response include the total count by specifying &#x60;include[]&#x3D;total_count&#x60;.

  • :date_created (Hash<String, Time>)

    Filter by date created.

  • :metadata (Hash<String, String>)

    Filter by metadata key-value pair&#x60;.

  • :scheduled (Boolean)
    • &#x60;true&#x60; - only return orders (past or future) where &#x60;send_date&#x60; is greater than &#x60;date_created&#x60; * &#x60;false&#x60; - only return orders where &#x60;send_date&#x60; is equal to &#x60;date_created&#x60;

  • :send_date (Hash<String, String>)

    Filter by date sent.

  • :mail_type (MailType)

    A string designating the mail postage type: * &#x60;usps_first_class&#x60; - (default) * &#x60;usps_standard&#x60; - a [cheaper option](lob.com/pricing/print-mail#compare) which is less predictable and takes longer to deliver. &#x60;usps_standard&#x60; cannot be used with &#x60;4x6&#x60; postcards or for any postcards sent outside of the United States. (default to ‘usps_first_class’)

  • :sort_by (SortBy4)

    Sorts items by ascending or descending dates. Use either &#x60;date_created&#x60; or &#x60;send_date&#x60;, not both.

Returns:



247
248
249
250
# File 'lib/lob/api/checks_api.rb', line 247

def list(opts = {})
  data, _status_code, _headers = checks_list_with_http_info(opts)
  data
end