Class: Lob::CreativeWritable

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/creative_writable.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreativeWritable

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/lob/models/creative_writable.rb', line 113

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::CreativeWritable` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::CreativeWritable`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'resource_type')
    self.resource_type = attributes[:'resource_type']
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  end

  if attributes.key?(:'details')
    self.details = attributes[:'details']
  end

  if attributes.key?(:'file')
    self.file = attributes[:'file']
  end

  if attributes.key?(:'front')
    self.front = attributes[:'front']
  end

  if attributes.key?(:'back')
    self.back = attributes[:'back']
  end
end

Instance Attribute Details

#backObject

The artwork to use as the back of your postcard. Do not include for resource_type = letter.



43
44
45
# File 'lib/lob/models/creative_writable.rb', line 43

def back
  @back
end

#campaign_idObject

Unique identifier prefixed with ‘cmp_`.



31
32
33
# File 'lib/lob/models/creative_writable.rb', line 31

def campaign_id
  @campaign_id
end

#descriptionObject

An internal description that identifies this resource. Must be no longer than 255 characters.



22
23
24
# File 'lib/lob/models/creative_writable.rb', line 22

def description
  @description
end

#detailsObject

Either PostcardDetailsWritable or LetterDetailsWritable



34
35
36
# File 'lib/lob/models/creative_writable.rb', line 34

def details
  @details
end

#fileObject

PDF file containing the letter’s formatting. Do not include for resource_type = postcard.



37
38
39
# File 'lib/lob/models/creative_writable.rb', line 37

def file
  @file
end

#fromObject

Must either be an address ID or an inline object with correct address parameters.



19
20
21
# File 'lib/lob/models/creative_writable.rb', line 19

def from
  @from
end

#frontObject

The artwork to use as the front of your postcard. Do not include for resource_type = letter.



40
41
42
# File 'lib/lob/models/creative_writable.rb', line 40

def front
  @front
end

#metadataObject

Use metadata to store custom information for tagging and labeling back to your internal systems. Must be an object with up to 20 key-value pairs. Keys must be at most 40 characters and values must be at most 500 characters. Neither can contain the characters ‘"` and `\`. i.e. ’: "NEWYORK2015"‘ Nested objects are not supported. See [Metadata](#section/Metadata) for more information.



25
26
27
# File 'lib/lob/models/creative_writable.rb', line 25

def 
  @metadata
end

#resource_typeObject

Mailpiece type for the creative



28
29
30
# File 'lib/lob/models/creative_writable.rb', line 28

def resource_type
  @resource_type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/lob/models/creative_writable.rb', line 83

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/lob/models/creative_writable.rb', line 68

def self.attribute_map
  {
    :'from' => :'from',
    :'description' => :'description',
    :'metadata' => :'metadata',
    :'resource_type' => :'resource_type',
    :'campaign_id' => :'campaign_id',
    :'details' => :'details',
    :'file' => :'file',
    :'front' => :'front',
    :'back' => :'back'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



274
275
276
# File 'lib/lob/models/creative_writable.rb', line 274

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
107
108
109
# File 'lib/lob/models/creative_writable.rb', line 103

def self.openapi_nullable
  Set.new([
    :'from',
    :'description',
    :'details',
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/lob/models/creative_writable.rb', line 88

def self.openapi_types
  {
    :'from' => Array[:'AddressEditable', :'String'],
    :'description' => :'String',
    :'metadata' => :'Hash<String, String>',
    :'resource_type' => :'String',
    :'campaign_id' => :'String',
    :'details' => Array[:'PostcardDetailsWritable', :'String'],
    :'file' => :'String',
    :'front' => :'String',
    :'back' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/lob/models/creative_writable.rb', line 244

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      from == o.from &&
      description == o.description &&
       == o. &&
      resource_type == o.resource_type &&
      campaign_id == o.campaign_id &&
      details == o.details &&
      file == o.file &&
      front == o.front &&
      back == o.back
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/lob/models/creative_writable.rb', line 313

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/lob/models/creative_writable.rb', line 384

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/lob/models/creative_writable.rb', line 281

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


260
261
262
# File 'lib/lob/models/creative_writable.rb', line 260

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



266
267
268
# File 'lib/lob/models/creative_writable.rb', line 266

def hash
  [from, description, , resource_type, campaign_id, details, file, front, back].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/lob/models/creative_writable.rb', line 167

def list_invalid_properties
  invalid_properties = Array.new
  if !@description.nil? && @description.to_s.length > 255
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.')
  end

  if @resource_type.nil?
    invalid_properties.push('invalid value for "resource_type", resource_type cannot be nil.')
  end

  if @campaign_id.nil?
    invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.')
  end

  pattern = Regexp.new(/^cmp_[a-zA-Z0-9]+$/)
  if @campaign_id !~ pattern
    invalid_properties.push("invalid value for \"campaign_id\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



360
361
362
# File 'lib/lob/models/creative_writable.rb', line 360

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/lob/models/creative_writable.rb', line 366

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



354
355
356
# File 'lib/lob/models/creative_writable.rb', line 354

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



191
192
193
194
195
196
197
198
199
# File 'lib/lob/models/creative_writable.rb', line 191

def valid?
  return false if !@description.nil? && @description.to_s.length > 255
  return false if @resource_type.nil?
  resource_type_validator = EnumAttributeValidator.new('String', ["letter", "postcard"])
  return false unless resource_type_validator.valid?(@resource_type)
  return false if @campaign_id.nil?
  return false if @campaign_id !~ Regexp.new(/^cmp_[a-zA-Z0-9]+$/)
  true
end