Class: Lob::DefaultApi
- Inherits:
-
Object
- Object
- Lob::DefaultApi
- Defined in:
- lib/lob/api/default_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ DefaultApi
constructor
A new instance of DefaultApi.
-
#placeholder_no_call(opts = {}) ⇒ PlaceholderModel
placeholder_no_call Don’t call this.
-
#placeholder_with_http_info(opts = {}) ⇒ Array<(PlaceholderModel, Integer, Hash)>
placeholder_no_call Don't call this.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ DefaultApi
Returns a new instance of DefaultApi.
19 20 21 |
# File 'lib/lob/api/default_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/lob/api/default_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#placeholder_no_call(opts = {}) ⇒ PlaceholderModel
placeholder_no_call Don’t call this. It’s so that the right models can be generated.
26 27 28 29 |
# File 'lib/lob/api/default_api.rb', line 26 def placeholder_no_call(opts = {}) data, _status_code, _headers = placeholder_with_http_info(opts) data end |
#placeholder_with_http_info(opts = {}) ⇒ Array<(PlaceholderModel, Integer, Hash)>
placeholder_no_call Don't call this. It's so that the right models can be generated.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/lob/api/default_api.rb', line 35 def placeholder_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.placeholder ...' end # resource path local_var_path = '/shared_dont_call' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PlaceholderModel' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"DefaultApi.placeholder", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#placeholder\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |