Class: Lob::Events

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/events.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Events

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/lob/models/events.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::Events` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::Events`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  end

  if attributes.key?(:'reference_id')
    self.reference_id = attributes[:'reference_id']
  end

  if attributes.key?(:'event_type')
    self.event_type = attributes[:'event_type']
  end

  if attributes.key?(:'date_created')
    self.date_created = attributes[:'date_created']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = 'event'
  end
end

Instance Attribute Details

#bodyObject

The body of the associated resource as they were at the time of the event, i.e. the [postcard object](docs.lob.com/#tag/Postcards/operation/postcard_retrieve), [the letter object](docs.lob.com/#tag/Letters/operation/letter_retrieve), [the check object](docs.lob.com/#tag/Checks/operation/check_retrieve), [the address object](docs.lob.com/#tag/Addresses/operation/address_retrieve), or [the bank account object](docs.lob.com/#tag/Bank-Accounts/operation/bank_account_retrieve). For ‘.deleted` events, the body matches the response for the corresponding delete endpoint for that resource (e.g. the [postcard cancel response](docs.lob.com/#tag/Postcards/operation/postcard_delete)).



22
23
24
# File 'lib/lob/models/events.rb', line 22

def body
  @body
end

#date_createdObject

A timestamp in ISO 8601 format of the date the resource was created.



30
31
32
# File 'lib/lob/models/events.rb', line 30

def date_created
  @date_created
end

#event_typeObject

Returns the value of attribute event_type.



27
28
29
# File 'lib/lob/models/events.rb', line 27

def event_type
  @event_type
end

#idObject

Unique identifier prefixed with ‘evt_`.



19
20
21
# File 'lib/lob/models/events.rb', line 19

def id
  @id
end

#objectObject

Value is resource type.



33
34
35
# File 'lib/lob/models/events.rb', line 33

def object
  @object
end

#reference_idObject

Unique identifier of the related resource for the event.



25
26
27
# File 'lib/lob/models/events.rb', line 25

def reference_id
  @reference_id
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/lob/models/events.rb', line 70

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/lob/models/events.rb', line 58

def self.attribute_map
  {
    :'id' => :'id',
    :'body' => :'body',
    :'reference_id' => :'reference_id',
    :'event_type' => :'event_type',
    :'date_created' => :'date_created',
    :'object' => :'object'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



239
240
241
# File 'lib/lob/models/events.rb', line 239

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
# File 'lib/lob/models/events.rb', line 87

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
# File 'lib/lob/models/events.rb', line 75

def self.openapi_types
  {
    :'id' => :'String',
    :'body' => :'Object',
    :'reference_id' => :'String',
    :'event_type' => :'EventType',
    :'date_created' => :'Time',
    :'object' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



212
213
214
215
216
217
218
219
220
221
# File 'lib/lob/models/events.rb', line 212

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      body == o.body &&
      reference_id == o.reference_id &&
      event_type == o.event_type &&
      date_created == o.date_created &&
      object == o.object
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/lob/models/events.rb', line 278

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/lob/models/events.rb', line 349

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/lob/models/events.rb', line 246

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


225
226
227
# File 'lib/lob/models/events.rb', line 225

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



231
232
233
# File 'lib/lob/models/events.rb', line 231

def hash
  [id, body, reference_id, event_type, date_created, object].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/lob/models/events.rb', line 136

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  pattern = Regexp.new(/^evt_[a-zA-Z0-9_]+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if @body.nil?
    invalid_properties.push('invalid value for "body", body cannot be nil.')
  end

  if @reference_id.nil?
    invalid_properties.push('invalid value for "reference_id", reference_id cannot be nil.')
  end

  if @event_type.nil?
    invalid_properties.push('invalid value for "event_type", event_type cannot be nil.')
  end

  if @date_created.nil?
    invalid_properties.push('invalid value for "date_created", date_created cannot be nil.')
  end

  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



325
326
327
# File 'lib/lob/models/events.rb', line 325

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/lob/models/events.rb', line 331

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



319
320
321
# File 'lib/lob/models/events.rb', line 319

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/lob/models/events.rb', line 172

def valid?
  return false if @id.nil?
  return false if @id !~ Regexp.new(/^evt_[a-zA-Z0-9_]+$/)
  return false if @body.nil?
  return false if @reference_id.nil?
  return false if @event_type.nil?
  return false if @date_created.nil?
  return false if @object.nil?
  object_validator = EnumAttributeValidator.new('String', ["event"])
  return false unless object_validator.valid?(@object)
  true
end