Class: Lob::IdentityValidationApi
- Inherits:
-
Object
- Object
- Lob::IdentityValidationApi
- Defined in:
- lib/lob/api/identity_validation_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#identity_validation_with_http_info(multi_line_address, opts = {}) ⇒ Array<(IdentityValidation, Integer, Hash)>
validate Validates whether a given name is associated with an address.
-
#initialize(api_client = ApiClient.default) ⇒ IdentityValidationApi
constructor
A new instance of IdentityValidationApi.
-
#validate(multi_line_address, opts = {}) ⇒ IdentityValidation
validate Validates whether a given name is associated with an address.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ IdentityValidationApi
Returns a new instance of IdentityValidationApi.
19 20 21 |
# File 'lib/lob/api/identity_validation_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/lob/api/identity_validation_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#identity_validation_with_http_info(multi_line_address, opts = {}) ⇒ Array<(IdentityValidation, Integer, Hash)>
validate Validates whether a given name is associated with an address.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/lob/api/identity_validation_api.rb', line 37 def identity_validation_with_http_info(multi_line_address, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IdentityValidationApi.identity_validation ...' end # verify the required parameter 'multi_line_address' is set if @api_client.config.client_side_validation && multi_line_address.nil? fail ArgumentError, "Missing the required parameter 'multi_line_address' when calling IdentityValidationApi.identity_validation" end # resource path local_var_path = '/identity_validation' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(multi_line_address) # return_type return_type = opts[:debug_return_type] || 'IdentityValidation' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"IdentityValidationApi.identity_validation", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IdentityValidationApi#identity_validation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#validate(multi_line_address, opts = {}) ⇒ IdentityValidation
validate Validates whether a given name is associated with an address.
27 28 29 30 |
# File 'lib/lob/api/identity_validation_api.rb', line 27 def validate(multi_line_address, opts = {}) data, _status_code, _headers = identity_validation_with_http_info(multi_line_address, opts) data end |