Class: Lob::IntlComponents

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/intl_components.rb

Overview

A nested object containing a breakdown of each component of an address.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IntlComponents

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/lob/models/intl_components.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::IntlComponents` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::IntlComponents`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'primary_number')
    self.primary_number = attributes[:'primary_number']
  end

  if attributes.key?(:'street_name')
    self.street_name = attributes[:'street_name']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end
end

Instance Attribute Details

#cityObject

Returns the value of attribute city.



25
26
27
# File 'lib/lob/models/intl_components.rb', line 25

def city
  @city
end

#postal_codeObject

The postal code.



31
32
33
# File 'lib/lob/models/intl_components.rb', line 31

def postal_code
  @postal_code
end

#primary_numberObject

The numeric or alphanumeric part of an address preceding the street name. Often the house, building, or PO Box number.



20
21
22
# File 'lib/lob/models/intl_components.rb', line 20

def primary_number
  @primary_number
end

#stateObject

The [ISO 3166-2](en.wikipedia.org/wiki/ISO_3166-2) two letter code for the state.



28
29
30
# File 'lib/lob/models/intl_components.rb', line 28

def state
  @state
end

#street_nameObject

The name of the street.



23
24
25
# File 'lib/lob/models/intl_components.rb', line 23

def street_name
  @street_name
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/lob/models/intl_components.rb', line 45

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/lob/models/intl_components.rb', line 34

def self.attribute_map
  {
    :'primary_number' => :'primary_number',
    :'street_name' => :'street_name',
    :'city' => :'city',
    :'state' => :'state',
    :'postal_code' => :'postal_code'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



188
189
190
# File 'lib/lob/models/intl_components.rb', line 188

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/lob/models/intl_components.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
# File 'lib/lob/models/intl_components.rb', line 50

def self.openapi_types
  {
    :'primary_number' => :'String',
    :'street_name' => :'String',
    :'city' => :'String',
    :'state' => :'String',
    :'postal_code' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
168
169
170
# File 'lib/lob/models/intl_components.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      primary_number == o.primary_number &&
      street_name == o.street_name &&
      city == o.city &&
      state == o.state &&
      postal_code == o.postal_code
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/lob/models/intl_components.rb', line 227

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/lob/models/intl_components.rb', line 298

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/lob/models/intl_components.rb', line 195

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


174
175
176
# File 'lib/lob/models/intl_components.rb', line 174

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



180
181
182
# File 'lib/lob/models/intl_components.rb', line 180

def hash
  [primary_number, street_name, city, state, postal_code].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/lob/models/intl_components.rb', line 104

def list_invalid_properties
  invalid_properties = Array.new
  if !@city.nil? && @city.to_s.length > 200
    invalid_properties.push('invalid value for "city", the character length must be smaller than or equal to 200.')
  end

  if !@state.nil? && @state.to_s.length > 2
    invalid_properties.push('invalid value for "state", the character length must be smaller than or equal to 2.')
  end

  if !@postal_code.nil? && @postal_code.to_s.length > 12
    invalid_properties.push('invalid value for "postal_code", the character length must be smaller than or equal to 12.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



274
275
276
# File 'lib/lob/models/intl_components.rb', line 274

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/lob/models/intl_components.rb', line 280

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



268
269
270
# File 'lib/lob/models/intl_components.rb', line 268

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



123
124
125
126
127
128
# File 'lib/lob/models/intl_components.rb', line 123

def valid?
  return false if !@city.nil? && @city.to_s.length > 200
  return false if !@state.nil? && @state.to_s.length > 2
  return false if !@postal_code.nil? && @postal_code.to_s.length > 12
  true
end