Class: Lob::IntlVerificationOrError

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/intl_verification_or_error.rb

Overview

A model used to represent an entry in a result list where the entry can either be a intl_verification or an Error. The SDK will perform necessary casting into the correct corresponding type.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IntlVerificationOrError

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/lob/models/intl_verification_or_error.rb', line 118

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::IntlVerificationOrError` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::IntlVerificationOrError`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'recipient')
    self.recipient = attributes[:'recipient']
  end

  if attributes.key?(:'primary_line')
    self.primary_line = attributes[:'primary_line']
  end

  if attributes.key?(:'secondary_line')
    self.secondary_line = attributes[:'secondary_line']
  end

  if attributes.key?(:'last_line')
    self.last_line = attributes[:'last_line']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'coverage')
    self.coverage = attributes[:'coverage']
  end

  if attributes.key?(:'deliverability')
    self.deliverability = attributes[:'deliverability']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'components')
    self.components = attributes[:'components']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = 'intl_verification'
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end
end

Instance Attribute Details

#componentsObject

Returns the value of attribute components.



40
41
42
# File 'lib/lob/models/intl_verification_or_error.rb', line 40

def components
  @components
end

#countryObject

Returns the value of attribute country.



32
33
34
# File 'lib/lob/models/intl_verification_or_error.rb', line 32

def country
  @country
end

#coverageObject

Returns the value of attribute coverage.



34
35
36
# File 'lib/lob/models/intl_verification_or_error.rb', line 34

def coverage
  @coverage
end

#deliverabilityObject

Returns the value of attribute deliverability.



36
37
38
# File 'lib/lob/models/intl_verification_or_error.rb', line 36

def deliverability
  @deliverability
end

#errorObject

Returns the value of attribute error.



44
45
46
# File 'lib/lob/models/intl_verification_or_error.rb', line 44

def error
  @error
end

#idObject

Unique identifier prefixed with ‘intl_ver_`.



20
21
22
# File 'lib/lob/models/intl_verification_or_error.rb', line 20

def id
  @id
end

#last_lineObject

Returns the value of attribute last_line.



30
31
32
# File 'lib/lob/models/intl_verification_or_error.rb', line 30

def last_line
  @last_line
end

#objectObject

Returns the value of attribute object.



42
43
44
# File 'lib/lob/models/intl_verification_or_error.rb', line 42

def object
  @object
end

#primary_lineObject

Returns the value of attribute primary_line.



25
26
27
# File 'lib/lob/models/intl_verification_or_error.rb', line 25

def primary_line
  @primary_line
end

#recipientObject

The intended recipient, typically a person’s or firm’s name.



23
24
25
# File 'lib/lob/models/intl_verification_or_error.rb', line 23

def recipient
  @recipient
end

#secondary_lineObject

The secondary delivery line of the address. This field is typically empty but may contain information if ‘primary_line` is too long.



28
29
30
# File 'lib/lob/models/intl_verification_or_error.rb', line 28

def secondary_line
  @secondary_line
end

#statusObject

Returns the value of attribute status.



38
39
40
# File 'lib/lob/models/intl_verification_or_error.rb', line 38

def status
  @status
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/lob/models/intl_verification_or_error.rb', line 87

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/lob/models/intl_verification_or_error.rb', line 69

def self.attribute_map
  {
    :'id' => :'id',
    :'recipient' => :'recipient',
    :'primary_line' => :'primary_line',
    :'secondary_line' => :'secondary_line',
    :'last_line' => :'last_line',
    :'country' => :'country',
    :'coverage' => :'coverage',
    :'deliverability' => :'deliverability',
    :'status' => :'status',
    :'components' => :'components',
    :'object' => :'object',
    :'error' => :'error'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



340
341
342
# File 'lib/lob/models/intl_verification_or_error.rb', line 340

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



110
111
112
113
114
# File 'lib/lob/models/intl_verification_or_error.rb', line 110

def self.openapi_nullable
  Set.new([
    :'recipient',
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/lob/models/intl_verification_or_error.rb', line 92

def self.openapi_types
  {
    :'id' => :'String',
    :'recipient' => :'String',
    :'primary_line' => :'String',
    :'secondary_line' => :'String',
    :'last_line' => :'String',
    :'country' => :'String',
    :'coverage' => :'String',
    :'deliverability' => :'String',
    :'status' => :'String',
    :'components' => :'IntlComponents',
    :'object' => :'String',
    :'error' => :'BulkError'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/lob/models/intl_verification_or_error.rb', line 307

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      recipient == o.recipient &&
      primary_line == o.primary_line &&
      secondary_line == o.secondary_line &&
      last_line == o.last_line &&
      country == o.country &&
      coverage == o.coverage &&
      deliverability == o.deliverability &&
      status == o.status &&
      components == o.components &&
      object == o.object &&
      error == o.error
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
# File 'lib/lob/models/intl_verification_or_error.rb', line 379

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



450
451
452
453
454
455
456
457
458
459
460
461
462
# File 'lib/lob/models/intl_verification_or_error.rb', line 450

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/lob/models/intl_verification_or_error.rb', line 347

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


326
327
328
# File 'lib/lob/models/intl_verification_or_error.rb', line 326

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



332
333
334
# File 'lib/lob/models/intl_verification_or_error.rb', line 332

def hash
  [id, recipient, primary_line, secondary_line, last_line, country, coverage, deliverability, status, components, object, error].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/lob/models/intl_verification_or_error.rb', line 184

def list_invalid_properties
  invalid_properties = Array.new
  pattern = Regexp.new(/^intl_ver_[a-zA-Z0-9]+$/)
  if !@id.nil? && @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if !@recipient.nil? && @recipient.to_s.length > 500
    invalid_properties.push('invalid value for "recipient", the character length must be smaller than or equal to 500.')
  end

  if !@primary_line.nil? && @primary_line.to_s.length > 200
    invalid_properties.push('invalid value for "primary_line", the character length must be smaller than or equal to 200.')
  end

  if !@secondary_line.nil? && @secondary_line.to_s.length > 500
    invalid_properties.push('invalid value for "secondary_line", the character length must be smaller than or equal to 500.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



426
427
428
# File 'lib/lob/models/intl_verification_or_error.rb', line 426

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'lib/lob/models/intl_verification_or_error.rb', line 432

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



420
421
422
# File 'lib/lob/models/intl_verification_or_error.rb', line 420

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/lob/models/intl_verification_or_error.rb', line 208

def valid?
  return false if !@id.nil? && @id !~ Regexp.new(/^intl_ver_[a-zA-Z0-9]+$/)
  return false if !@recipient.nil? && @recipient.to_s.length > 500
  return false if !@primary_line.nil? && @primary_line.to_s.length > 200
  return false if !@secondary_line.nil? && @secondary_line.to_s.length > 500
  coverage_validator = EnumAttributeValidator.new('String', ["SUBBUILDING", "HOUSENUMBER/BUILDING", "STREET", "LOCALITY", "SPARSE"])
  return false unless coverage_validator.valid?(@coverage)
  deliverability_validator = EnumAttributeValidator.new('String', ["deliverable", "deliverable_missing_info", "undeliverable", "no_match"])
  return false unless deliverability_validator.valid?(@deliverability)
  status_validator = EnumAttributeValidator.new('String', ["LV4", "LV3", "LV2", "LV1", "LF4", "LF3", "LF2", "LF1", "LM4", "LM3", "LM2", "LU1"])
  return false unless status_validator.valid?(@status)
  object_validator = EnumAttributeValidator.new('String', ["intl_verification"])
  return false unless object_validator.valid?(@object)
  true
end