Class: Lob::IntlVerificationsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/api/intl_verifications_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ IntlVerificationsApi

Returns a new instance of IntlVerificationsApi.



19
20
21
# File 'lib/lob/api/intl_verifications_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/lob/api/intl_verifications_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#bulk_intl_verifications_with_http_info(intl_verifications_payload, opts = {}) ⇒ Array<(IntlVerifications, Integer, Hash)>

verifyBulk Verify a list of international (except US or US territories) address with a live API key.

Parameters:

Returns:

  • (Array<(IntlVerifications, Integer, Hash)>)

    IntlVerifications data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/lob/api/intl_verifications_api.rb', line 37

def bulk_intl_verifications_with_http_info(intl_verifications_payload, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IntlVerificationsApi.bulk_intl_verifications ...'
  end
  # verify the required parameter 'intl_verifications_payload' is set
  if @api_client.config.client_side_validation && intl_verifications_payload.nil?
    fail ArgumentError, "Missing the required parameter 'intl_verifications_payload' when calling IntlVerificationsApi.bulk_intl_verifications"
  end
  # resource path
  local_var_path = '/bulk/intl_verifications'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(intl_verifications_payload)

  # return_type
  return_type = opts[:debug_return_type] || 'IntlVerifications'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"IntlVerificationsApi.bulk_intl_verifications",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IntlVerificationsApi#bulk_intl_verifications\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#intl_verification_with_http_info(intl_verification_writable, opts = {}) ⇒ Array<(IntlVerification, Integer, Hash)>

verifySingle Verify an international (except US or US territories) address with a live API key.

Parameters:

Options Hash (opts):

  • :x_lang_output (String)
    • &#x60;native&#x60; - Translate response to the native language of the country in the request * &#x60;match&#x60; - match the response to the language in the request Default response is in English.

Returns:

  • (Array<(IntlVerification, Integer, Hash)>)

    IntlVerification data, response status code and response headers



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/lob/api/intl_verifications_api.rb', line 107

def intl_verification_with_http_info(intl_verification_writable, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IntlVerificationsApi.intl_verification ...'
  end
  # verify the required parameter 'intl_verification_writable' is set
  if @api_client.config.client_side_validation && intl_verification_writable.nil?
    fail ArgumentError, "Missing the required parameter 'intl_verification_writable' when calling IntlVerificationsApi.intl_verification"
  end
  allowable_values = ["native", "match"]
  if @api_client.config.client_side_validation && opts[:'x_lang_output'] && !allowable_values.include?(opts[:'x_lang_output'])
    fail ArgumentError, "invalid value for \"x_lang_output\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/intl_verifications'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'x-lang-output'] = opts[:'x_lang_output'] if !opts[:'x_lang_output'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(intl_verification_writable)

  # return_type
  return_type = opts[:debug_return_type] || 'IntlVerification'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"IntlVerificationsApi.intl_verification",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IntlVerificationsApi#intl_verification\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#verifyBulk(intl_verifications_payload, opts = {}) ⇒ IntlVerifications

verifyBulk Verify a list of international (except US or US territories) address with a live API key.

Parameters:

Returns:



27
28
29
30
# File 'lib/lob/api/intl_verifications_api.rb', line 27

def verifyBulk(intl_verifications_payload, opts = {})
  data, _status_code, _headers = bulk_intl_verifications_with_http_info(intl_verifications_payload, opts)
  data
end

#verifySingle(intl_verification_writable, opts = {}) ⇒ IntlVerification

verifySingle Verify an international (except US or US territories) address with a live API key.

Parameters:

Options Hash (opts):

  • :x_lang_output (String)
    • &#x60;native&#x60; - Translate response to the native language of the country in the request * &#x60;match&#x60; - match the response to the language in the request Default response is in English.

Returns:



96
97
98
99
# File 'lib/lob/api/intl_verifications_api.rb', line 96

def verifySingle(intl_verification_writable, opts = {})
  data, _status_code, _headers = intl_verification_with_http_info(intl_verification_writable, opts)
  data
end