Class: Lob::Letter

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/letter.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Letter

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/lob/models/letter.rb', line 215

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::Letter` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::Letter`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'carrier')
    self.carrier = attributes[:'carrier']
  else
    self.carrier = 'USPS'
  end

  if attributes.key?(:'thumbnails')
    if (value = attributes[:'thumbnails']).is_a?(Array)
      self.thumbnails = value
    end
  end

  if attributes.key?(:'expected_delivery_date')
    self.expected_delivery_date = attributes[:'expected_delivery_date']
  end

  if attributes.key?(:'date_created')
    self.date_created = attributes[:'date_created']
  end

  if attributes.key?(:'date_modified')
    self.date_modified = attributes[:'date_modified']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  end

  if attributes.key?(:'template_version_id')
    self.template_version_id = attributes[:'template_version_id']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = 'letter'
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'merge_variables')
    self.merge_variables = attributes[:'merge_variables']
  end

  if attributes.key?(:'send_date')
    self.send_date = attributes[:'send_date']
  end

  if attributes.key?(:'extra_service')
    self.extra_service = attributes[:'extra_service']
  end

  if attributes.key?(:'tracking_number')
    self.tracking_number = attributes[:'tracking_number']
  end

  if attributes.key?(:'tracking_events')
    if (value = attributes[:'tracking_events']).is_a?(Array)
      self.tracking_events = value
    end
  end

  if attributes.key?(:'return_address')
    self.return_address = attributes[:'return_address']
  end

  if attributes.key?(:'mail_type')
    self.mail_type = attributes[:'mail_type']
  else
    self.mail_type = 'usps_first_class'
  end

  if attributes.key?(:'color')
    self.color = attributes[:'color']
  end

  if attributes.key?(:'double_sided')
    self.double_sided = attributes[:'double_sided']
  else
    self.double_sided = true
  end

  if attributes.key?(:'address_placement')
    self.address_placement = attributes[:'address_placement']
  else
    self.address_placement = 'top_first_page'
  end

  if attributes.key?(:'return_envelope')
    self.return_envelope = attributes[:'return_envelope']
  end

  if attributes.key?(:'perforated_page')
    self.perforated_page = attributes[:'perforated_page']
  end

  if attributes.key?(:'custom_envelope')
    self.custom_envelope = attributes[:'custom_envelope']
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  end

  if attributes.key?(:'use_type')
    self.use_type = attributes[:'use_type']
  end
end

Instance Attribute Details

#address_placementObject

Specifies the location of the address information that will show through the double-window envelope.



85
86
87
# File 'lib/lob/models/letter.rb', line 85

def address_placement
  @address_placement
end

#campaign_idObject

The unique ID of the associated campaign if the resource was generated from a campaign.



95
96
97
# File 'lib/lob/models/letter.rb', line 95

def campaign_id
  @campaign_id
end

#carrierObject

Returns the value of attribute carrier.



22
23
24
# File 'lib/lob/models/letter.rb', line 22

def carrier
  @carrier
end

#colorObject

Set this key to ‘true` if you would like to print in color. Set to `false` if you would like to print in black and white.



79
80
81
# File 'lib/lob/models/letter.rb', line 79

def color
  @color
end

#custom_envelopeObject

Returns the value of attribute custom_envelope.



92
93
94
# File 'lib/lob/models/letter.rb', line 92

def custom_envelope
  @custom_envelope
end

#date_createdObject

A timestamp in ISO 8601 format of the date the resource was created.



30
31
32
# File 'lib/lob/models/letter.rb', line 30

def date_created
  @date_created
end

#date_modifiedObject

A timestamp in ISO 8601 format of the date the resource was last modified.



33
34
35
# File 'lib/lob/models/letter.rb', line 33

def date_modified
  @date_modified
end

#deletedObject

Only returned if the resource has been successfully deleted.



36
37
38
# File 'lib/lob/models/letter.rb', line 36

def deleted
  @deleted
end

#descriptionObject

An internal description that identifies this resource. Must be no longer than 255 characters.



53
54
55
# File 'lib/lob/models/letter.rb', line 53

def description
  @description
end

#double_sidedObject

Set this attribute to ‘true` for double sided printing, or `false` for for single sided printing. Defaults to `true`.



82
83
84
# File 'lib/lob/models/letter.rb', line 82

def double_sided
  @double_sided
end

#expected_delivery_dateObject

A date in YYYY-MM-DD format of the mailpiece’s expected delivery date based on its ‘send_date`.



27
28
29
# File 'lib/lob/models/letter.rb', line 27

def expected_delivery_date
  @expected_delivery_date
end

#extra_serviceObject

Add an extra service to your letter. See [pricing](www.lob.com/pricing/print-mail#compare) for extra costs incurred.



65
66
67
# File 'lib/lob/models/letter.rb', line 65

def extra_service
  @extra_service
end

#fromObject

Returns the value of attribute from.



20
21
22
# File 'lib/lob/models/letter.rb', line 20

def from
  @from
end

#idObject

Unique identifier prefixed with ‘ltr_`.



39
40
41
# File 'lib/lob/models/letter.rb', line 39

def id
  @id
end

#mail_typeObject

Returns the value of attribute mail_type.



76
77
78
# File 'lib/lob/models/letter.rb', line 76

def mail_type
  @mail_type
end

#merge_variablesObject

You can input a merge variable payload object to your template to render dynamic content. For example, if you have a template like: ‘{variable_name}`, pass in `"Harry"` to render `Harry`. `merge_variables` must be an object. Any type of value is accepted as long as the object is valid JSON; you can use `strings`, `numbers`, `booleans`, `arrays`, `objects`, or `null`. The max length of the object is 25,000 characters. If you call `JSON.stringify` on your object, it can be no longer than 25,000 characters. Your variable names cannot contain any whitespace or any of the following special characters: `!`, `"`, `#`, `%`, `&`, `’‘, `(`, `)`, `*`, `+`, `,`, `/`, `;`, `<`, `=`, `>`, `@`, `[`, `\`, `]`, `^`, “ ` “, ``|`, ``, `~`. More instructions can be found in [our guide to using html and merge variables](lob.com/resources/guides/general/using-html-and-merge-variables). Depending on your [Merge Variable strictness](dashboard.lob.com/#/settings/account) setting, if you define variables in your HTML but do not pass them here, you will either receive an error or the variable will render as an empty string.



59
60
61
# File 'lib/lob/models/letter.rb', line 59

def merge_variables
  @merge_variables
end

#metadataObject

Use metadata to store custom information for tagging and labeling back to your internal systems. Must be an object with up to 20 key-value pairs. Keys must be at most 40 characters and values must be at most 500 characters. Neither can contain the characters ‘"` and `\`. i.e. ’: "NEWYORK2015"‘ Nested objects are not supported. See [Metadata](#section/Metadata) for more information.



56
57
58
# File 'lib/lob/models/letter.rb', line 56

def 
  @metadata
end

#objectObject

Returns the value of attribute object.



50
51
52
# File 'lib/lob/models/letter.rb', line 50

def object
  @object
end

#perforated_pageObject

Required if ‘return_envelope` is `true`. The number of the page that should be perforated for use with the return envelope. Must be greater than or equal to `1`. The blank page added by `address_placement=insert_blank_page` will be ignored when considering the perforated page number. To see how perforation will impact your letter design, view our [perforation guide](s3-us-west-2.amazonaws.com/public.lob.com/assets/templates/letter_perf_template.pdf).



90
91
92
# File 'lib/lob/models/letter.rb', line 90

def perforated_page
  @perforated_page
end

#return_addressObject

Specifies the address the return envelope will be sent back to. This is an optional argument that is available if an account is signed up for the return envelope tracking beta, and has ‘return_envelope`, and `perforated_page` fields populated in the API request.



74
75
76
# File 'lib/lob/models/letter.rb', line 74

def return_address
  @return_address
end

#return_envelopeObject

Returns the value of attribute return_envelope.



87
88
89
# File 'lib/lob/models/letter.rb', line 87

def return_envelope
  @return_envelope
end

#send_dateObject

A timestamp in ISO 8601 format which specifies a date after the current time and up to 180 days in the future to send the letter off for production. Setting a send date overrides the default [cancellation window](#section/Cancellation-Windows) applied to the mailpiece. Until the ‘send_date` has passed, the mailpiece can be canceled. If a date in the format `2017-11-01` is passed, it will evaluate to midnight UTC of that date (`2017-11-01T00:00:00.000Z`). If a datetime is passed, that exact time will be used. A `send_date` passed with no time zone will default to UTC, while a `send_date` passed with a time zone will be converted to UTC.



62
63
64
# File 'lib/lob/models/letter.rb', line 62

def send_date
  @send_date
end

#template_idObject

Unique identifier prefixed with ‘tmpl_`. ID of a saved [HTML template](#section/HTML-Templates).



42
43
44
# File 'lib/lob/models/letter.rb', line 42

def template_id
  @template_id
end

#template_version_idObject

Unique identifier prefixed with ‘vrsn_`.



45
46
47
# File 'lib/lob/models/letter.rb', line 45

def template_version_id
  @template_version_id
end

#thumbnailsObject

Returns the value of attribute thumbnails.



24
25
26
# File 'lib/lob/models/letter.rb', line 24

def thumbnails
  @thumbnails
end

#toObject

Returns the value of attribute to.



18
19
20
# File 'lib/lob/models/letter.rb', line 18

def to
  @to
end

#tracking_eventsObject

An array of tracking_event objects ordered by ascending ‘time`. Will not be populated for letters created in test mode.



71
72
73
# File 'lib/lob/models/letter.rb', line 71

def tracking_events
  @tracking_events
end

#tracking_numberObject

The tracking number, if applicable, will appear here when it becomes available. Dummy tracking numbers are not created in test mode.



68
69
70
# File 'lib/lob/models/letter.rb', line 68

def tracking_number
  @tracking_number
end

#urlObject

A [signed link](#section/Asset-URLs) served over HTTPS. The link returned will expire in 30 days to prevent mis-sharing. Each time a GET request is initiated, a new signed URL will be generated.



48
49
50
# File 'lib/lob/models/letter.rb', line 48

def url
  @url
end

#use_typeObject

Returns the value of attribute use_type.



97
98
99
# File 'lib/lob/models/letter.rb', line 97

def use_type
  @use_type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



158
159
160
# File 'lib/lob/models/letter.rb', line 158

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/lob/models/letter.rb', line 122

def self.attribute_map
  {
    :'to' => :'to',
    :'from' => :'from',
    :'carrier' => :'carrier',
    :'thumbnails' => :'thumbnails',
    :'expected_delivery_date' => :'expected_delivery_date',
    :'date_created' => :'date_created',
    :'date_modified' => :'date_modified',
    :'deleted' => :'deleted',
    :'id' => :'id',
    :'template_id' => :'template_id',
    :'template_version_id' => :'template_version_id',
    :'url' => :'url',
    :'object' => :'object',
    :'description' => :'description',
    :'metadata' => :'metadata',
    :'merge_variables' => :'merge_variables',
    :'send_date' => :'send_date',
    :'extra_service' => :'extra_service',
    :'tracking_number' => :'tracking_number',
    :'tracking_events' => :'tracking_events',
    :'return_address' => :'return_address',
    :'mail_type' => :'mail_type',
    :'color' => :'color',
    :'double_sided' => :'double_sided',
    :'address_placement' => :'address_placement',
    :'return_envelope' => :'return_envelope',
    :'perforated_page' => :'perforated_page',
    :'custom_envelope' => :'custom_envelope',
    :'campaign_id' => :'campaign_id',
    :'use_type' => :'use_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



596
597
598
# File 'lib/lob/models/letter.rb', line 596

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/lob/models/letter.rb', line 199

def self.openapi_nullable
  Set.new([
    :'description',
    :'merge_variables',
    :'tracking_number',
    :'return_address',
    :'return_envelope',
    :'perforated_page',
    :'custom_envelope',
    :'campaign_id',
    :'use_type'
  ])
end

.openapi_typesObject

Attribute type mapping.



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/lob/models/letter.rb', line 163

def self.openapi_types
  {
    :'to' => :'Address',
    :'from' => :'Address',
    :'carrier' => :'String',
    :'thumbnails' => :'Array<Thumbnail>',
    :'expected_delivery_date' => :'Date',
    :'date_created' => :'Time',
    :'date_modified' => :'Time',
    :'deleted' => :'Boolean',
    :'id' => :'String',
    :'template_id' => :'String',
    :'template_version_id' => :'String',
    :'url' => :'String',
    :'object' => :'String',
    :'description' => :'String',
    :'metadata' => :'Hash<String, String>',
    :'merge_variables' => :'Object',
    :'send_date' => :'Time',
    :'extra_service' => :'String',
    :'tracking_number' => :'String',
    :'tracking_events' => :'Array<TrackingEventNormal>',
    :'return_address' => Array[:'AddressEditable', :'String'],
    :'mail_type' => :'MailType',
    :'color' => :'Boolean',
    :'double_sided' => :'Boolean',
    :'address_placement' => :'String',
    :'return_envelope' => Array[:'ReturnEnvelope', :'Boolean'],
    :'perforated_page' => :'Integer',
    :'custom_envelope' => :'LetterCustomEnvelope',
    :'campaign_id' => :'String',
    :'use_type' => :'LtrUseType'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
# File 'lib/lob/models/letter.rb', line 545

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      to == o.to &&
      from == o.from &&
      carrier == o.carrier &&
      thumbnails == o.thumbnails &&
      expected_delivery_date == o.expected_delivery_date &&
      date_created == o.date_created &&
      date_modified == o.date_modified &&
      deleted == o.deleted &&
      id == o.id &&
      template_id == o.template_id &&
      template_version_id == o.template_version_id &&
      url == o.url &&
      object == o.object &&
      description == o.description &&
       == o. &&
      merge_variables == o.merge_variables &&
      send_date == o.send_date &&
      extra_service == o.extra_service &&
      tracking_number == o.tracking_number &&
      tracking_events == o.tracking_events &&
      return_address == o.return_address &&
      mail_type == o.mail_type &&
      color == o.color &&
      double_sided == o.double_sided &&
      address_placement == o.address_placement &&
      return_envelope == o.return_envelope &&
      perforated_page == o.perforated_page &&
      custom_envelope == o.custom_envelope &&
      campaign_id == o.campaign_id &&
      use_type == o.use_type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
# File 'lib/lob/models/letter.rb', line 635

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



706
707
708
709
710
711
712
713
714
715
716
717
718
# File 'lib/lob/models/letter.rb', line 706

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
# File 'lib/lob/models/letter.rb', line 603

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


582
583
584
# File 'lib/lob/models/letter.rb', line 582

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



588
589
590
# File 'lib/lob/models/letter.rb', line 588

def hash
  [to, from, carrier, thumbnails, expected_delivery_date, date_created, date_modified, deleted, id, template_id, template_version_id, url, object, description, , merge_variables, send_date, extra_service, tracking_number, tracking_events, return_address, mail_type, color, double_sided, address_placement, return_envelope, perforated_page, custom_envelope, campaign_id, use_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'lib/lob/models/letter.rb', line 367

def list_invalid_properties
  invalid_properties = Array.new
  if @to.nil?
    invalid_properties.push('invalid value for "to", to cannot be nil.')
  end

  if @from.nil?
    invalid_properties.push('invalid value for "from", from cannot be nil.')
  end

  if @date_created.nil?
    invalid_properties.push('invalid value for "date_created", date_created cannot be nil.')
  end

  if @date_modified.nil?
    invalid_properties.push('invalid value for "date_modified", date_modified cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  pattern = Regexp.new(/^ltr_[a-zA-Z0-9]+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^tmpl_[a-zA-Z0-9]+$/)
  if !@template_id.nil? && @template_id !~ pattern
    invalid_properties.push("invalid value for \"template_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^vrsn_[a-zA-Z0-9]+$/)
  if !@template_version_id.nil? && @template_version_id !~ pattern
    invalid_properties.push("invalid value for \"template_version_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^https:\/\/lob-assets.com\/(letters|postcards|bank-accounts|checks|self-mailers|cards)\/[a-z]{3,4}_[a-z0-9]{15,16}(_signature)?(\.pdf|_thumb_[a-z]+_[0-9]+\.png|\.png)\?(version=[a-z0-9]*&)expires=[0-9]{10}&signature=[a-zA-Z0-9_-]+/)
  if !@url.nil? && @url !~ pattern
    invalid_properties.push("invalid value for \"url\", must conform to the pattern #{pattern}.")
  end

  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  if !@description.nil? && @description.to_s.length > 255
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



682
683
684
# File 'lib/lob/models/letter.rb', line 682

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



688
689
690
691
692
693
694
695
696
697
698
699
700
# File 'lib/lob/models/letter.rb', line 688

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



676
677
678
# File 'lib/lob/models/letter.rb', line 676

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
# File 'lib/lob/models/letter.rb', line 422

def valid?
  return false if @to.nil?
  return false if @from.nil?
  carrier_validator = EnumAttributeValidator.new('String', ["USPS"])
  return false unless carrier_validator.valid?(@carrier)
  return false if @date_created.nil?
  return false if @date_modified.nil?
  return false if @id.nil?
  return false if @id !~ Regexp.new(/^ltr_[a-zA-Z0-9]+$/)
  return false if !@template_id.nil? && @template_id !~ Regexp.new(/^tmpl_[a-zA-Z0-9]+$/)
  return false if !@template_version_id.nil? && @template_version_id !~ Regexp.new(/^vrsn_[a-zA-Z0-9]+$/)
  return false if !@url.nil? && @url !~ Regexp.new(/^https:\/\/lob-assets.com\/(letters|postcards|bank-accounts|checks|self-mailers|cards)\/[a-z]{3,4}_[a-z0-9]{15,16}(_signature)?(\.pdf|_thumb_[a-z]+_[0-9]+\.png|\.png)\?(version=[a-z0-9]*&)expires=[0-9]{10}&signature=[a-zA-Z0-9_-]+/)
  return false if @object.nil?
  object_validator = EnumAttributeValidator.new('String', ["letter"])
  return false unless object_validator.valid?(@object)
  return false if !@description.nil? && @description.to_s.length > 255
  address_placement_validator = EnumAttributeValidator.new('String', ["top_first_page", "insert_blank_page", "bottom_first_page_center", "bottom_first_page"])
  return false unless address_placement_validator.valid?(@address_placement)
  true
end