Class: Lob::LetterEditable

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/letter_editable.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LetterEditable

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/lob/models/letter_editable.rb', line 166

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::LetterEditable` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::LetterEditable`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'mail_type')
    self.mail_type = attributes[:'mail_type']
  else
    self.mail_type = 'usps_first_class'
  end

  if attributes.key?(:'merge_variables')
    self.merge_variables = attributes[:'merge_variables']
  end

  if attributes.key?(:'send_date')
    self.send_date = attributes[:'send_date']
  end

  if attributes.key?(:'color')
    self.color = attributes[:'color']
  end

  if attributes.key?(:'double_sided')
    self.double_sided = attributes[:'double_sided']
  else
    self.double_sided = true
  end

  if attributes.key?(:'address_placement')
    self.address_placement = attributes[:'address_placement']
  else
    self.address_placement = 'top_first_page'
  end

  if attributes.key?(:'return_envelope')
    self.return_envelope = attributes[:'return_envelope']
  end

  if attributes.key?(:'perforated_page')
    self.perforated_page = attributes[:'perforated_page']
  end

  if attributes.key?(:'custom_envelope')
    self.custom_envelope = attributes[:'custom_envelope']
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'file')
    self.file = attributes[:'file']
  end

  if attributes.key?(:'extra_service')
    self.extra_service = attributes[:'extra_service']
  end

  if attributes.key?(:'cards')
    if (value = attributes[:'cards']).is_a?(Array)
      self.cards = value
    end
  end

  if attributes.key?(:'billing_group_id')
    self.billing_group_id = attributes[:'billing_group_id']
  end

  if attributes.key?(:'qr_code')
    self.qr_code = attributes[:'qr_code']
  end

  if attributes.key?(:'use_type')
    self.use_type = attributes[:'use_type']
  end
end

Instance Attribute Details

#address_placementObject

Specifies the location of the address information that will show through the double-window envelope. To see how this will impact your letter design, view our letter template. * ‘top_first_page` - (default) print address information at the top of your provided first page * `insert_blank_page` - insert a blank address page at the beginning of your file (you will be charged for the extra page) * `bottom_first_page_center` - **(deprecation planned within a few months)** print address information at the bottom center of your provided first page * `bottom_first_page` - print address information at the bottom of your provided first page



39
40
41
# File 'lib/lob/models/letter_editable.rb', line 39

def address_placement
  @address_placement
end

#billing_group_idObject

An optional string with the billing group ID to tag your usage with. Is used for billing purposes. Requires special activation to use. See [Billing Group API](lob.github.io/lob-openapi/#tag/Billing-Groups) for more information.



65
66
67
# File 'lib/lob/models/letter_editable.rb', line 65

def billing_group_id
  @billing_group_id
end

#cardsObject

A single-element array containing an existing card id in a string format. See [cards](#tag/Cards) for more information.



62
63
64
# File 'lib/lob/models/letter_editable.rb', line 62

def cards
  @cards
end

#colorObject

Set this key to ‘true` if you would like to print in color. Set to `false` if you would like to print in black and white.



33
34
35
# File 'lib/lob/models/letter_editable.rb', line 33

def color
  @color
end

#custom_envelopeObject

Returns the value of attribute custom_envelope.



47
48
49
# File 'lib/lob/models/letter_editable.rb', line 47

def custom_envelope
  @custom_envelope
end

#descriptionObject

An internal description that identifies this resource. Must be no longer than 255 characters.



19
20
21
# File 'lib/lob/models/letter_editable.rb', line 19

def description
  @description
end

#double_sidedObject

Set this attribute to ‘true` for double sided printing, or `false` for for single sided printing. Defaults to `true`.



36
37
38
# File 'lib/lob/models/letter_editable.rb', line 36

def double_sided
  @double_sided
end

#extra_serviceObject

Add an extra service to your letter: * ‘certified` - track and confirm delivery for domestic destinations. An extra sheet (1 PDF page single-sided or 2 PDF pages double-sided) is added to the beginning of your letter for address and barcode information. See here for templates: [#10 envelope](s3-us-west-2.amazonaws.com/public.lob.com/assets/templates/letter_certified_template.pdf) and [flat envelope](s3-us-west-2.amazonaws.com/public.lob.com/assets/templates/letter_certified_flat_template.pdf) (used for letters over 6 pages single-sided or 12 pages double-sided). You will not be charged for this extra sheet. * `certified_return_receipt` - request an electronic copy of the recipient’s signature to prove delivery of your certified letter * ‘registered` - provides tracking and confirmation for international addresses



59
60
61
# File 'lib/lob/models/letter_editable.rb', line 59

def extra_service
  @extra_service
end

#fileObject

PDF file containing the letter’s formatting.



56
57
58
# File 'lib/lob/models/letter_editable.rb', line 56

def file
  @file
end

#fromObject

Must either be an address ID or an inline object with correct address parameters.



53
54
55
# File 'lib/lob/models/letter_editable.rb', line 53

def from
  @from
end

#mail_typeObject

Returns the value of attribute mail_type.



24
25
26
# File 'lib/lob/models/letter_editable.rb', line 24

def mail_type
  @mail_type
end

#merge_variablesObject

You can input a merge variable payload object to your template to render dynamic content. For example, if you have a template like: ‘{variable_name}`, pass in `"Harry"` to render `Harry`. `merge_variables` must be an object. Any type of value is accepted as long as the object is valid JSON; you can use `strings`, `numbers`, `booleans`, `arrays`, `objects`, or `null`. The max length of the object is 25,000 characters. If you call `JSON.stringify` on your object, it can be no longer than 25,000 characters. Your variable names cannot contain any whitespace or any of the following special characters: `!`, `"`, `#`, `%`, `&`, `’‘, `(`, `)`, `*`, `+`, `,`, `/`, `;`, `<`, `=`, `>`, `@`, `[`, `\`, `]`, `^`, “ ` “, ``|`, ``, `~`. More instructions can be found in [our guide to using html and merge variables](lob.com/resources/guides/general/using-html-and-merge-variables). Depending on your [Merge Variable strictness](dashboard.lob.com/#/settings/account) setting, if you define variables in your HTML but do not pass them here, you will either receive an error or the variable will render as an empty string.



27
28
29
# File 'lib/lob/models/letter_editable.rb', line 27

def merge_variables
  @merge_variables
end

#metadataObject

Use metadata to store custom information for tagging and labeling back to your internal systems. Must be an object with up to 20 key-value pairs. Keys must be at most 40 characters and values must be at most 500 characters. Neither can contain the characters ‘"` and `\`. i.e. ’: "NEWYORK2015"‘ Nested objects are not supported. See [Metadata](#section/Metadata) for more information.



22
23
24
# File 'lib/lob/models/letter_editable.rb', line 22

def 
  @metadata
end

#perforated_pageObject

Required if ‘return_envelope` is `true`. The number of the page that should be perforated for use with the return envelope. Must be greater than or equal to `1`. The blank page added by `address_placement=insert_blank_page` will be ignored when considering the perforated page number. To see how perforation will impact your letter design, view our [perforation guide](s3-us-west-2.amazonaws.com/public.lob.com/assets/templates/letter_perf_template.pdf).



45
46
47
# File 'lib/lob/models/letter_editable.rb', line 45

def perforated_page
  @perforated_page
end

#qr_codeObject

Returns the value of attribute qr_code.



67
68
69
# File 'lib/lob/models/letter_editable.rb', line 67

def qr_code
  @qr_code
end

#return_envelopeObject

indicates if a return envelope is requested for the letter. The value corresponding to this field is by default a boolean. But if the account is signed up for custom return envelopes, the value is of type string and is ‘no_9_single_window` for a standard return envelope and a custom `return_envelope_id` for non-standard return envelopes. To include a return envelope with your letter, set to `true` and specify the `perforated_page`. See [pricing](www.lob.com/pricing/print-mail#compare) for extra costs incurred.



42
43
44
# File 'lib/lob/models/letter_editable.rb', line 42

def return_envelope
  @return_envelope
end

#send_dateObject

A timestamp in ISO 8601 format which specifies a date after the current time and up to 180 days in the future to send the letter off for production. Setting a send date overrides the default [cancellation window](#section/Cancellation-Windows) applied to the mailpiece. Until the ‘send_date` has passed, the mailpiece can be canceled. If a date in the format `2017-11-01` is passed, it will evaluate to midnight UTC of that date (`2017-11-01T00:00:00.000Z`). If a datetime is passed, that exact time will be used. A `send_date` passed with no time zone will default to UTC, while a `send_date` passed with a time zone will be converted to UTC.



30
31
32
# File 'lib/lob/models/letter_editable.rb', line 30

def send_date
  @send_date
end

#toObject

Must either be an address ID or an inline object with correct address parameters.



50
51
52
# File 'lib/lob/models/letter_editable.rb', line 50

def to
  @to
end

#use_typeObject

Returns the value of attribute use_type.



69
70
71
# File 'lib/lob/models/letter_editable.rb', line 69

def use_type
  @use_type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



119
120
121
# File 'lib/lob/models/letter_editable.rb', line 119

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/lob/models/letter_editable.rb', line 94

def self.attribute_map
  {
    :'description' => :'description',
    :'metadata' => :'metadata',
    :'mail_type' => :'mail_type',
    :'merge_variables' => :'merge_variables',
    :'send_date' => :'send_date',
    :'color' => :'color',
    :'double_sided' => :'double_sided',
    :'address_placement' => :'address_placement',
    :'return_envelope' => :'return_envelope',
    :'perforated_page' => :'perforated_page',
    :'custom_envelope' => :'custom_envelope',
    :'to' => :'to',
    :'from' => :'from',
    :'file' => :'file',
    :'extra_service' => :'extra_service',
    :'cards' => :'cards',
    :'billing_group_id' => :'billing_group_id',
    :'qr_code' => :'qr_code',
    :'use_type' => :'use_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



406
407
408
# File 'lib/lob/models/letter_editable.rb', line 406

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/lob/models/letter_editable.rb', line 149

def self.openapi_nullable
  Set.new([
    :'description',
    :'merge_variables',
    :'return_envelope',
    :'perforated_page',
    :'custom_envelope',
    :'to',
    :'from',
    :'extra_service',
    :'cards',
    :'use_type'
  ])
end

.openapi_typesObject

Attribute type mapping.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/lob/models/letter_editable.rb', line 124

def self.openapi_types
  {
    :'description' => :'String',
    :'metadata' => :'Hash<String, String>',
    :'mail_type' => :'MailType',
    :'merge_variables' => :'Object',
    :'send_date' => :'Time',
    :'color' => :'Boolean',
    :'double_sided' => :'Boolean',
    :'address_placement' => :'String',
    :'return_envelope' => Array[:'Boolean', :'String'],
    :'perforated_page' => :'Integer',
    :'custom_envelope' => :'String',
    :'to' => Array[:'AddressEditable', :'String'],
    :'from' => Array[:'AddressEditable', :'String'],
    :'file' => :'String',
    :'extra_service' => :'String',
    :'cards' => :'Array<String>',
    :'billing_group_id' => :'String',
    :'qr_code' => :'QrCode',
    :'use_type' => :'LtrUseType'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
# File 'lib/lob/models/letter_editable.rb', line 366

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      description == o.description &&
       == o. &&
      mail_type == o.mail_type &&
      merge_variables == o.merge_variables &&
      send_date == o.send_date &&
      color == o.color &&
      double_sided == o.double_sided &&
      address_placement == o.address_placement &&
      return_envelope == o.return_envelope &&
      perforated_page == o.perforated_page &&
      custom_envelope == o.custom_envelope &&
      to == o.to &&
      from == o.from &&
      file == o.file &&
      extra_service == o.extra_service &&
      cards == o.cards &&
      billing_group_id == o.billing_group_id &&
      qr_code == o.qr_code &&
      use_type == o.use_type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'lib/lob/models/letter_editable.rb', line 445

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



516
517
518
519
520
521
522
523
524
525
526
527
528
# File 'lib/lob/models/letter_editable.rb', line 516

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
# File 'lib/lob/models/letter_editable.rb', line 413

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


392
393
394
# File 'lib/lob/models/letter_editable.rb', line 392

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



398
399
400
# File 'lib/lob/models/letter_editable.rb', line 398

def hash
  [description, , mail_type, merge_variables, send_date, color, double_sided, address_placement, return_envelope, perforated_page, custom_envelope, to, from, file, extra_service, cards, billing_group_id, qr_code, use_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/lob/models/letter_editable.rb', line 268

def list_invalid_properties
  invalid_properties = Array.new
  if !@description.nil? && @description.to_s.length > 255
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.')
  end

  if @color.nil?
    invalid_properties.push('invalid value for "color", color cannot be nil.')
  end

  if @file.nil?
    invalid_properties.push('invalid value for "file", file cannot be nil.')
  end

  if !@cards.nil? && @cards.length > 1
    invalid_properties.push('invalid value for "cards", number of items must be less than or equal to 1.')
  end

  if !@cards.nil? && @cards.length < 0
    invalid_properties.push('invalid value for "cards", number of items must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



492
493
494
# File 'lib/lob/models/letter_editable.rb', line 492

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



498
499
500
501
502
503
504
505
506
507
508
509
510
# File 'lib/lob/models/letter_editable.rb', line 498

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



486
487
488
# File 'lib/lob/models/letter_editable.rb', line 486

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/lob/models/letter_editable.rb', line 295

def valid?
  return false if !@description.nil? && @description.to_s.length > 255
  return false if @color.nil?
  address_placement_validator = EnumAttributeValidator.new('String', ["top_first_page", "insert_blank_page", "bottom_first_page_center", "bottom_first_page"])
  return false unless address_placement_validator.valid?(@address_placement)
  return false if @file.nil?
  extra_service_validator = EnumAttributeValidator.new('String', ["certified", "certified_return_receipt", "registered", "null"])
  return false unless extra_service_validator.valid?(@extra_service)
  return false if !@cards.nil? && @cards.length > 1
  return false if !@cards.nil? && @cards.length < 0
  true
end