Class: Lob::LocationAnalysis

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/location_analysis.rb

Overview

A nested object containing a breakdown of the analysis of a reverse geocoded location.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LocationAnalysis

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/lob/models/location_analysis.rb', line 61

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::LocationAnalysis` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::LocationAnalysis`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'latitude')
    self.latitude = attributes[:'latitude']
  end

  if attributes.key?(:'longitude')
    self.longitude = attributes[:'longitude']
  end

  if attributes.key?(:'distance')
    self.distance = attributes[:'distance']
  end
end

Instance Attribute Details

#distanceObject

The distance from the input location to this exact zip code in miles.



26
27
28
# File 'lib/lob/models/location_analysis.rb', line 26

def distance
  @distance
end

#latitudeObject

A positive or negative decimal indicating the geographic latitude of the address.



20
21
22
# File 'lib/lob/models/location_analysis.rb', line 20

def latitude
  @latitude
end

#longitudeObject

A positive or negative decimal indicating the geographic longitude of the address.



23
24
25
# File 'lib/lob/models/location_analysis.rb', line 23

def longitude
  @longitude
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



38
39
40
# File 'lib/lob/models/location_analysis.rb', line 38

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/lob/models/location_analysis.rb', line 29

def self.attribute_map
  {
    :'latitude' => :'latitude',
    :'longitude' => :'longitude',
    :'distance' => :'distance'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



179
180
181
# File 'lib/lob/models/location_analysis.rb', line 179

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



52
53
54
55
56
57
# File 'lib/lob/models/location_analysis.rb', line 52

def self.openapi_nullable
  Set.new([
    :'latitude',
    :'longitude',
  ])
end

.openapi_typesObject

Attribute type mapping.



43
44
45
46
47
48
49
# File 'lib/lob/models/location_analysis.rb', line 43

def self.openapi_types
  {
    :'latitude' => :'Float',
    :'longitude' => :'Float',
    :'distance' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



155
156
157
158
159
160
161
# File 'lib/lob/models/location_analysis.rb', line 155

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      latitude == o.latitude &&
      longitude == o.longitude &&
      distance == o.distance
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/lob/models/location_analysis.rb', line 218

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/lob/models/location_analysis.rb', line 289

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/lob/models/location_analysis.rb', line 186

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


165
166
167
# File 'lib/lob/models/location_analysis.rb', line 165

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



171
172
173
# File 'lib/lob/models/location_analysis.rb', line 171

def hash
  [latitude, longitude, distance].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/lob/models/location_analysis.rb', line 89

def list_invalid_properties
  invalid_properties = Array.new
  if @latitude > 90
    invalid_properties.push('invalid value for "latitude", must be smaller than or equal to 90.')
  end

  if @latitude < -90
    invalid_properties.push('invalid value for "latitude", must be greater than or equal to -90.')
  end

  if @longitude > 180
    invalid_properties.push('invalid value for "longitude", must be smaller than or equal to 180.')
  end

  if @longitude < -180
    invalid_properties.push('invalid value for "longitude", must be greater than or equal to -180.')
  end

  if @distance.nil?
    invalid_properties.push('invalid value for "distance", distance cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



265
266
267
# File 'lib/lob/models/location_analysis.rb', line 265

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/lob/models/location_analysis.rb', line 271

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



259
260
261
# File 'lib/lob/models/location_analysis.rb', line 259

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



116
117
118
119
120
121
122
123
# File 'lib/lob/models/location_analysis.rb', line 116

def valid?
  return false if @latitude > 90
  return false if @latitude < -90
  return false if @longitude > 180
  return false if @longitude < -180
  return false if @distance.nil?
  true
end