Class: Lob::MultipleComponentsIntl

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/multiple_components_intl.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MultipleComponentsIntl

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/lob/models/multiple_components_intl.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::MultipleComponentsIntl` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::MultipleComponentsIntl`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'recipient')
    self.recipient = attributes[:'recipient']
  end

  if attributes.key?(:'primary_line')
    self.primary_line = attributes[:'primary_line']
  end

  if attributes.key?(:'secondary_line')
    self.secondary_line = attributes[:'secondary_line']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end
end

Instance Attribute Details

#cityObject

Returns the value of attribute city.



27
28
29
# File 'lib/lob/models/multiple_components_intl.rb', line 27

def city
  @city
end

#countryObject

Returns the value of attribute country.



35
36
37
# File 'lib/lob/models/multiple_components_intl.rb', line 35

def country
  @country
end

#postal_codeObject

The postal code.



33
34
35
# File 'lib/lob/models/multiple_components_intl.rb', line 33

def postal_code
  @postal_code
end

#primary_lineObject

The primary delivery line (usually the street address) of the address.



22
23
24
# File 'lib/lob/models/multiple_components_intl.rb', line 22

def primary_line
  @primary_line
end

#recipientObject

The intended recipient, typically a person’s or firm’s name.



19
20
21
# File 'lib/lob/models/multiple_components_intl.rb', line 19

def recipient
  @recipient
end

#secondary_lineObject

The secondary delivery line of the address. This field is typically empty but may contain information if ‘primary_line` is too long.



25
26
27
# File 'lib/lob/models/multiple_components_intl.rb', line 25

def secondary_line
  @secondary_line
end

#stateObject

The name of the state.



30
31
32
# File 'lib/lob/models/multiple_components_intl.rb', line 30

def state
  @state
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/lob/models/multiple_components_intl.rb', line 51

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
# File 'lib/lob/models/multiple_components_intl.rb', line 38

def self.attribute_map
  {
    :'recipient' => :'recipient',
    :'primary_line' => :'primary_line',
    :'secondary_line' => :'secondary_line',
    :'city' => :'city',
    :'state' => :'state',
    :'postal_code' => :'postal_code',
    :'country' => :'country'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



251
252
253
# File 'lib/lob/models/multiple_components_intl.rb', line 251

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



69
70
71
72
73
# File 'lib/lob/models/multiple_components_intl.rb', line 69

def self.openapi_nullable
  Set.new([
    :'recipient',
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/lob/models/multiple_components_intl.rb', line 56

def self.openapi_types
  {
    :'recipient' => :'String',
    :'primary_line' => :'String',
    :'secondary_line' => :'String',
    :'city' => :'String',
    :'state' => :'String',
    :'postal_code' => :'String',
    :'country' => :'CountryExtended'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



223
224
225
226
227
228
229
230
231
232
233
# File 'lib/lob/models/multiple_components_intl.rb', line 223

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      recipient == o.recipient &&
      primary_line == o.primary_line &&
      secondary_line == o.secondary_line &&
      city == o.city &&
      state == o.state &&
      postal_code == o.postal_code &&
      country == o.country
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/lob/models/multiple_components_intl.rb', line 290

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/lob/models/multiple_components_intl.rb', line 361

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/lob/models/multiple_components_intl.rb', line 258

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


237
238
239
# File 'lib/lob/models/multiple_components_intl.rb', line 237

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



243
244
245
# File 'lib/lob/models/multiple_components_intl.rb', line 243

def hash
  [recipient, primary_line, secondary_line, city, state, postal_code, country].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/lob/models/multiple_components_intl.rb', line 121

def list_invalid_properties
  invalid_properties = Array.new
  if !@recipient.nil? && @recipient.to_s.length > 500
    invalid_properties.push('invalid value for "recipient", the character length must be smaller than or equal to 500.')
  end

  if @primary_line.nil?
    invalid_properties.push('invalid value for "primary_line", primary_line cannot be nil.')
  end

  if @primary_line.to_s.length > 200
    invalid_properties.push('invalid value for "primary_line", the character length must be smaller than or equal to 200.')
  end

  if !@secondary_line.nil? && @secondary_line.to_s.length > 500
    invalid_properties.push('invalid value for "secondary_line", the character length must be smaller than or equal to 500.')
  end

  if !@city.nil? && @city.to_s.length > 200
    invalid_properties.push('invalid value for "city", the character length must be smaller than or equal to 200.')
  end

  if !@postal_code.nil? && @postal_code.to_s.length > 12
    invalid_properties.push('invalid value for "postal_code", the character length must be smaller than or equal to 12.')
  end

  if @country.nil?
    invalid_properties.push('invalid value for "country", country cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



337
338
339
# File 'lib/lob/models/multiple_components_intl.rb', line 337

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/lob/models/multiple_components_intl.rb', line 343

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



331
332
333
# File 'lib/lob/models/multiple_components_intl.rb', line 331

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



156
157
158
159
160
161
162
163
164
165
# File 'lib/lob/models/multiple_components_intl.rb', line 156

def valid?
  return false if !@recipient.nil? && @recipient.to_s.length > 500
  return false if @primary_line.nil?
  return false if @primary_line.to_s.length > 200
  return false if !@secondary_line.nil? && @secondary_line.to_s.length > 500
  return false if !@city.nil? && @city.to_s.length > 200
  return false if !@postal_code.nil? && @postal_code.to_s.length > 12
  return false if @country.nil?
  true
end