Class: Lob::PlaceholderModel

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/placeholder_model.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PlaceholderModel

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/lob/models/placeholder_model.rb', line 67

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::PlaceholderModel` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::PlaceholderModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'return_envelope')
    self.return_envelope = attributes[:'return_envelope']
  end

  if attributes.key?(:'address_domestic')
    self.address_domestic = attributes[:'address_domestic']
  end

  if attributes.key?(:'letter_details_writable')
    self.letter_details_writable = attributes[:'letter_details_writable']
  end

  if attributes.key?(:'postcard_details_writable')
    self.postcard_details_writable = attributes[:'postcard_details_writable']
  end

  if attributes.key?(:'letter_details_returned')
    self.letter_details_returned = attributes[:'letter_details_returned']
  end

  if attributes.key?(:'postcard_details_returned')
    self.postcard_details_returned = attributes[:'postcard_details_returned']
  end
end

Instance Attribute Details

#address_domesticObject

Returns the value of attribute address_domestic.



20
21
22
# File 'lib/lob/models/placeholder_model.rb', line 20

def address_domestic
  @address_domestic
end

#letter_details_returnedObject

Returns the value of attribute letter_details_returned.



26
27
28
# File 'lib/lob/models/placeholder_model.rb', line 26

def letter_details_returned
  @letter_details_returned
end

#letter_details_writableObject

Returns the value of attribute letter_details_writable.



22
23
24
# File 'lib/lob/models/placeholder_model.rb', line 22

def letter_details_writable
  @letter_details_writable
end

#postcard_details_returnedObject

Returns the value of attribute postcard_details_returned.



28
29
30
# File 'lib/lob/models/placeholder_model.rb', line 28

def postcard_details_returned
  @postcard_details_returned
end

#postcard_details_writableObject

Returns the value of attribute postcard_details_writable.



24
25
26
# File 'lib/lob/models/placeholder_model.rb', line 24

def postcard_details_writable
  @postcard_details_writable
end

#return_envelopeObject

Returns the value of attribute return_envelope.



18
19
20
# File 'lib/lob/models/placeholder_model.rb', line 18

def return_envelope
  @return_envelope
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/lob/models/placeholder_model.rb', line 43

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/lob/models/placeholder_model.rb', line 31

def self.attribute_map
  {
    :'return_envelope' => :'return_envelope',
    :'address_domestic' => :'address_domestic',
    :'letter_details_writable' => :'letter_details_writable',
    :'postcard_details_writable' => :'postcard_details_writable',
    :'letter_details_returned' => :'letter_details_returned',
    :'postcard_details_returned' => :'postcard_details_returned'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



147
148
149
# File 'lib/lob/models/placeholder_model.rb', line 147

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



60
61
62
63
# File 'lib/lob/models/placeholder_model.rb', line 60

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
55
56
57
# File 'lib/lob/models/placeholder_model.rb', line 48

def self.openapi_types
  {
    :'return_envelope' => :'ReturnEnvelope',
    :'address_domestic' => :'AddressDomestic',
    :'letter_details_writable' => :'LetterDetailsWritable',
    :'postcard_details_writable' => :'PostcardDetailsWritable',
    :'letter_details_returned' => :'LetterDetailsReturned',
    :'postcard_details_returned' => :'PostcardDetailsReturned'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



120
121
122
123
124
125
126
127
128
129
# File 'lib/lob/models/placeholder_model.rb', line 120

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      return_envelope == o.return_envelope &&
      address_domestic == o.address_domestic &&
      letter_details_writable == o.letter_details_writable &&
      postcard_details_writable == o.postcard_details_writable &&
      letter_details_returned == o.letter_details_returned &&
      postcard_details_returned == o.postcard_details_returned
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/lob/models/placeholder_model.rb', line 186

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/lob/models/placeholder_model.rb', line 257

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/lob/models/placeholder_model.rb', line 154

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


133
134
135
# File 'lib/lob/models/placeholder_model.rb', line 133

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



139
140
141
# File 'lib/lob/models/placeholder_model.rb', line 139

def hash
  [return_envelope, address_domestic, letter_details_writable, postcard_details_writable, letter_details_returned, postcard_details_returned].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



107
108
109
110
# File 'lib/lob/models/placeholder_model.rb', line 107

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



233
234
235
# File 'lib/lob/models/placeholder_model.rb', line 233

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/lob/models/placeholder_model.rb', line 239

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



227
228
229
# File 'lib/lob/models/placeholder_model.rb', line 227

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



114
115
116
# File 'lib/lob/models/placeholder_model.rb', line 114

def valid?
  true
end