Class: Lob::PostcardEditable

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/postcard_editable.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PostcardEditable

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/lob/models/postcard_editable.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::PostcardEditable` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::PostcardEditable`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  else
    self.size = '4x6'
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'mail_type')
    self.mail_type = attributes[:'mail_type']
  else
    self.mail_type = 'usps_first_class'
  end

  if attributes.key?(:'merge_variables')
    self.merge_variables = attributes[:'merge_variables']
  end

  if attributes.key?(:'send_date')
    self.send_date = attributes[:'send_date']
  end

  if attributes.key?(:'front')
    self.front = attributes[:'front']
  end

  if attributes.key?(:'back')
    self.back = attributes[:'back']
  end

  if attributes.key?(:'billing_group_id')
    self.billing_group_id = attributes[:'billing_group_id']
  end

  if attributes.key?(:'qr_code')
    self.qr_code = attributes[:'qr_code']
  end

  if attributes.key?(:'use_type')
    self.use_type = attributes[:'use_type']
  end
end

Instance Attribute Details

#backObject

The artwork to use as the back of your postcard.



44
45
46
# File 'lib/lob/models/postcard_editable.rb', line 44

def back
  @back
end

#billing_group_idObject

An optional string with the billing group ID to tag your usage with. Is used for billing purposes. Requires special activation to use. See [Billing Group API](lob.github.io/lob-openapi/#tag/Billing-Groups) for more information.



47
48
49
# File 'lib/lob/models/postcard_editable.rb', line 47

def billing_group_id
  @billing_group_id
end

#descriptionObject

An internal description that identifies this resource. Must be no longer than 255 characters.



27
28
29
# File 'lib/lob/models/postcard_editable.rb', line 27

def description
  @description
end

#fromObject

Required if ‘to` address is international. Must either be an address ID or an inline object with correct address parameters.



22
23
24
# File 'lib/lob/models/postcard_editable.rb', line 22

def from
  @from
end

#frontObject

The artwork to use as the front of your postcard.



41
42
43
# File 'lib/lob/models/postcard_editable.rb', line 41

def front
  @front
end

#mail_typeObject

Returns the value of attribute mail_type.



32
33
34
# File 'lib/lob/models/postcard_editable.rb', line 32

def mail_type
  @mail_type
end

#merge_variablesObject

You can input a merge variable payload object to your template to render dynamic content. For example, if you have a template like: ‘{variable_name}`, pass in `"Harry"` to render `Harry`. `merge_variables` must be an object. Any type of value is accepted as long as the object is valid JSON; you can use `strings`, `numbers`, `booleans`, `arrays`, `objects`, or `null`. The max length of the object is 25,000 characters. If you call `JSON.stringify` on your object, it can be no longer than 25,000 characters. Your variable names cannot contain any whitespace or any of the following special characters: `!`, `"`, `#`, `%`, `&`, `’‘, `(`, `)`, `*`, `+`, `,`, `/`, `;`, `<`, `=`, `>`, `@`, `[`, `\`, `]`, `^`, “ ` “, ``|`, ``, `~`. More instructions can be found in [our guide to using html and merge variables](lob.com/resources/guides/general/using-html-and-merge-variables). Depending on your [Merge Variable strictness](dashboard.lob.com/#/settings/account) setting, if you define variables in your HTML but do not pass them here, you will either receive an error or the variable will render as an empty string.



35
36
37
# File 'lib/lob/models/postcard_editable.rb', line 35

def merge_variables
  @merge_variables
end

#metadataObject

Use metadata to store custom information for tagging and labeling back to your internal systems. Must be an object with up to 20 key-value pairs. Keys must be at most 40 characters and values must be at most 500 characters. Neither can contain the characters ‘"` and `\`. i.e. ’: "NEWYORK2015"‘ Nested objects are not supported. See [Metadata](#section/Metadata) for more information.



30
31
32
# File 'lib/lob/models/postcard_editable.rb', line 30

def 
  @metadata
end

#qr_codeObject

Returns the value of attribute qr_code.



49
50
51
# File 'lib/lob/models/postcard_editable.rb', line 49

def qr_code
  @qr_code
end

#send_dateObject

A timestamp in ISO 8601 format which specifies a date after the current time and up to 180 days in the future to send the letter off for production. Setting a send date overrides the default [cancellation window](#section/Cancellation-Windows) applied to the mailpiece. Until the ‘send_date` has passed, the mailpiece can be canceled. If a date in the format `2017-11-01` is passed, it will evaluate to midnight UTC of that date (`2017-11-01T00:00:00.000Z`). If a datetime is passed, that exact time will be used. A `send_date` passed with no time zone will default to UTC, while a `send_date` passed with a time zone will be converted to UTC.



38
39
40
# File 'lib/lob/models/postcard_editable.rb', line 38

def send_date
  @send_date
end

#sizeObject

Returns the value of attribute size.



24
25
26
# File 'lib/lob/models/postcard_editable.rb', line 24

def size
  @size
end

#toObject

Must either be an address ID or an inline object with correct address parameters.



19
20
21
# File 'lib/lob/models/postcard_editable.rb', line 19

def to
  @to
end

#use_typeObject

Returns the value of attribute use_type.



51
52
53
# File 'lib/lob/models/postcard_editable.rb', line 51

def use_type
  @use_type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/lob/models/postcard_editable.rb', line 73

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/lob/models/postcard_editable.rb', line 54

def self.attribute_map
  {
    :'to' => :'to',
    :'from' => :'from',
    :'size' => :'size',
    :'description' => :'description',
    :'metadata' => :'metadata',
    :'mail_type' => :'mail_type',
    :'merge_variables' => :'merge_variables',
    :'send_date' => :'send_date',
    :'front' => :'front',
    :'back' => :'back',
    :'billing_group_id' => :'billing_group_id',
    :'qr_code' => :'qr_code',
    :'use_type' => :'use_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



267
268
269
# File 'lib/lob/models/postcard_editable.rb', line 267

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
101
102
103
104
105
# File 'lib/lob/models/postcard_editable.rb', line 97

def self.openapi_nullable
  Set.new([
    :'to',
    :'from',
    :'description',
    :'merge_variables',
    :'use_type'
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/lob/models/postcard_editable.rb', line 78

def self.openapi_types
  {
    :'to' => Array[:'AddressEditable', :'String'],
    :'from' => Array[:'AddressEditable', :'String'],
    :'size' => :'PostcardSize',
    :'description' => :'String',
    :'metadata' => :'Hash<String, String>',
    :'mail_type' => :'MailType',
    :'merge_variables' => :'Object',
    :'send_date' => :'Time',
    :'front' => :'String',
    :'back' => :'String',
    :'billing_group_id' => :'String',
    :'qr_code' => :'QrCode',
    :'use_type' => :'PscUseType'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/lob/models/postcard_editable.rb', line 233

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      to == o.to &&
      from == o.from &&
      size == o.size &&
      description == o.description &&
       == o. &&
      mail_type == o.mail_type &&
      merge_variables == o.merge_variables &&
      send_date == o.send_date &&
      front == o.front &&
      back == o.back &&
      billing_group_id == o.billing_group_id &&
      qr_code == o.qr_code &&
      use_type == o.use_type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/lob/models/postcard_editable.rb', line 306

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/lob/models/postcard_editable.rb', line 377

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/lob/models/postcard_editable.rb', line 274

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


253
254
255
# File 'lib/lob/models/postcard_editable.rb', line 253

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



259
260
261
# File 'lib/lob/models/postcard_editable.rb', line 259

def hash
  [to, from, size, description, , mail_type, merge_variables, send_date, front, back, billing_group_id, qr_code, use_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/lob/models/postcard_editable.rb', line 183

def list_invalid_properties
  invalid_properties = Array.new
  if !@description.nil? && @description.to_s.length > 255
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.')
  end

  if @front.nil?
    invalid_properties.push('invalid value for "front", front cannot be nil.')
  end

  if @back.nil?
    invalid_properties.push('invalid value for "back", back cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



353
354
355
# File 'lib/lob/models/postcard_editable.rb', line 353

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/lob/models/postcard_editable.rb', line 359

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



347
348
349
# File 'lib/lob/models/postcard_editable.rb', line 347

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



202
203
204
205
206
207
# File 'lib/lob/models/postcard_editable.rb', line 202

def valid?
  return false if !@description.nil? && @description.to_s.length > 255
  return false if @front.nil?
  return false if @back.nil?
  true
end