Class: Lob::RequiredAddressColumnMapping

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/required_address_column_mapping.rb

Overview

The mapping of column headers in your file to Lob-required fields for the resource created. See our <a href="help.lob.com/print-and-mail/building-a-mail-strategy/campaign-or-triggered-sends/campaign-audience-guide#required-columns-2" target="_blank">Campaign Audience Guide</a> for additional details.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RequiredAddressColumnMapping

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/lob/models/required_address_column_mapping.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::RequiredAddressColumnMapping` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::RequiredAddressColumnMapping`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = 'null'
  end

  if attributes.key?(:'address_line1')
    self.address_line1 = attributes[:'address_line1']
  else
    self.address_line1 = 'null'
  end

  if attributes.key?(:'address_city')
    self.address_city = attributes[:'address_city']
  else
    self.address_city = 'null'
  end

  if attributes.key?(:'address_state')
    self.address_state = attributes[:'address_state']
  else
    self.address_state = 'null'
  end

  if attributes.key?(:'address_zip')
    self.address_zip = attributes[:'address_zip']
  else
    self.address_zip = 'null'
  end
end

Instance Attribute Details

#address_cityObject

The column header from the csv file that should be mapped to the required field ‘address_city`



26
27
28
# File 'lib/lob/models/required_address_column_mapping.rb', line 26

def address_city
  @address_city
end

#address_line1Object

The column header from the csv file that should be mapped to the required field ‘address_line1`



23
24
25
# File 'lib/lob/models/required_address_column_mapping.rb', line 23

def address_line1
  @address_line1
end

#address_stateObject

The column header from the csv file that should be mapped to the required field ‘address_state`



29
30
31
# File 'lib/lob/models/required_address_column_mapping.rb', line 29

def address_state
  @address_state
end

#address_zipObject

The column header from the csv file that should be mapped to the required field ‘address_zip`



32
33
34
# File 'lib/lob/models/required_address_column_mapping.rb', line 32

def address_zip
  @address_zip
end

#nameObject

The column header from the csv file that should be mapped to the required field ‘name`



20
21
22
# File 'lib/lob/models/required_address_column_mapping.rb', line 20

def name
  @name
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/lob/models/required_address_column_mapping.rb', line 46

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
# File 'lib/lob/models/required_address_column_mapping.rb', line 35

def self.attribute_map
  {
    :'name' => :'name',
    :'address_line1' => :'address_line1',
    :'address_city' => :'address_city',
    :'address_state' => :'address_state',
    :'address_zip' => :'address_zip'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



159
160
161
# File 'lib/lob/models/required_address_column_mapping.rb', line 159

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



62
63
64
65
66
67
68
69
70
# File 'lib/lob/models/required_address_column_mapping.rb', line 62

def self.openapi_nullable
  Set.new([
    :'name',
    :'address_line1',
    :'address_city',
    :'address_state',
    :'address_zip'
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
59
# File 'lib/lob/models/required_address_column_mapping.rb', line 51

def self.openapi_types
  {
    :'name' => :'String',
    :'address_line1' => :'String',
    :'address_city' => :'String',
    :'address_state' => :'String',
    :'address_zip' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



133
134
135
136
137
138
139
140
141
# File 'lib/lob/models/required_address_column_mapping.rb', line 133

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      address_line1 == o.address_line1 &&
      address_city == o.address_city &&
      address_state == o.address_state &&
      address_zip == o.address_zip
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/lob/models/required_address_column_mapping.rb', line 198

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/lob/models/required_address_column_mapping.rb', line 269

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/lob/models/required_address_column_mapping.rb', line 166

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


145
146
147
# File 'lib/lob/models/required_address_column_mapping.rb', line 145

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



151
152
153
# File 'lib/lob/models/required_address_column_mapping.rb', line 151

def hash
  [name, address_line1, address_city, address_state, address_zip].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
# File 'lib/lob/models/required_address_column_mapping.rb', line 120

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



245
246
247
# File 'lib/lob/models/required_address_column_mapping.rb', line 245

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/lob/models/required_address_column_mapping.rb', line 251

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



239
240
241
# File 'lib/lob/models/required_address_column_mapping.rb', line 239

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



127
128
129
# File 'lib/lob/models/required_address_column_mapping.rb', line 127

def valid?
  true
end