Class: Lob::SelfMailer

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/self_mailer.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SelfMailer

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/lob/models/self_mailer.rb', line 154

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::SelfMailer` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::SelfMailer`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  else
    self.size = '6x18_bifold'
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'mail_type')
    self.mail_type = attributes[:'mail_type']
  else
    self.mail_type = 'usps_first_class'
  end

  if attributes.key?(:'merge_variables')
    self.merge_variables = attributes[:'merge_variables']
  end

  if attributes.key?(:'send_date')
    self.send_date = attributes[:'send_date']
  end

  if attributes.key?(:'outside_template_id')
    self.outside_template_id = attributes[:'outside_template_id']
  end

  if attributes.key?(:'inside_template_id')
    self.inside_template_id = attributes[:'inside_template_id']
  end

  if attributes.key?(:'outside_template_version_id')
    self.outside_template_version_id = attributes[:'outside_template_version_id']
  end

  if attributes.key?(:'inside_template_version_id')
    self.inside_template_version_id = attributes[:'inside_template_version_id']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = 'self_mailer'
  end

  if attributes.key?(:'tracking_events')
    if (value = attributes[:'tracking_events']).is_a?(Array)
      self.tracking_events = value
    end
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'use_type')
    self.use_type = attributes[:'use_type']
  end
end

Instance Attribute Details

#descriptionObject

An internal description that identifies this resource. Must be no longer than 255 characters.



28
29
30
# File 'lib/lob/models/self_mailer.rb', line 28

def description
  @description
end

#fromObject

Returns the value of attribute from.



23
24
25
# File 'lib/lob/models/self_mailer.rb', line 23

def from
  @from
end

#idObject

Unique identifier prefixed with ‘sfm_`.



19
20
21
# File 'lib/lob/models/self_mailer.rb', line 19

def id
  @id
end

#inside_template_idObject

The unique ID of the HTML template used for the inside of the self mailer.



45
46
47
# File 'lib/lob/models/self_mailer.rb', line 45

def inside_template_id
  @inside_template_id
end

#inside_template_version_idObject

The unique ID of the specific version of the HTML template used for the inside of the self mailer.



51
52
53
# File 'lib/lob/models/self_mailer.rb', line 51

def inside_template_version_id
  @inside_template_version_id
end

#mail_typeObject

Returns the value of attribute mail_type.



33
34
35
# File 'lib/lob/models/self_mailer.rb', line 33

def mail_type
  @mail_type
end

#merge_variablesObject

You can input a merge variable payload object to your template to render dynamic content. For example, if you have a template like: ‘{variable_name}`, pass in `"Harry"` to render `Harry`. `merge_variables` must be an object. Any type of value is accepted as long as the object is valid JSON; you can use `strings`, `numbers`, `booleans`, `arrays`, `objects`, or `null`. The max length of the object is 25,000 characters. If you call `JSON.stringify` on your object, it can be no longer than 25,000 characters. Your variable names cannot contain any whitespace or any of the following special characters: `!`, `"`, `#`, `%`, `&`, `’‘, `(`, `)`, `*`, `+`, `,`, `/`, `;`, `<`, `=`, `>`, `@`, `[`, `\`, `]`, `^`, “ ` “, ``|`, ``, `~`. More instructions can be found in [our guide to using html and merge variables](lob.com/resources/guides/general/using-html-and-merge-variables). Depending on your [Merge Variable strictness](dashboard.lob.com/#/settings/account) setting, if you define variables in your HTML but do not pass them here, you will either receive an error or the variable will render as an empty string.



36
37
38
# File 'lib/lob/models/self_mailer.rb', line 36

def merge_variables
  @merge_variables
end

#metadataObject

Use metadata to store custom information for tagging and labeling back to your internal systems. Must be an object with up to 20 key-value pairs. Keys must be at most 40 characters and values must be at most 500 characters. Neither can contain the characters ‘"` and `\`. i.e. ’: "NEWYORK2015"‘ Nested objects are not supported. See [Metadata](#section/Metadata) for more information.



31
32
33
# File 'lib/lob/models/self_mailer.rb', line 31

def 
  @metadata
end

#objectObject

Value is resource type.



54
55
56
# File 'lib/lob/models/self_mailer.rb', line 54

def object
  @object
end

#outside_template_idObject

The unique ID of the HTML template used for the outside of the self mailer.



42
43
44
# File 'lib/lob/models/self_mailer.rb', line 42

def outside_template_id
  @outside_template_id
end

#outside_template_version_idObject

The unique ID of the specific version of the HTML template used for the outside of the self mailer.



48
49
50
# File 'lib/lob/models/self_mailer.rb', line 48

def outside_template_version_id
  @outside_template_version_id
end

#send_dateObject

A timestamp in ISO 8601 format which specifies a date after the current time and up to 180 days in the future to send the letter off for production. Setting a send date overrides the default [cancellation window](#section/Cancellation-Windows) applied to the mailpiece. Until the ‘send_date` has passed, the mailpiece can be canceled. If a date in the format `2017-11-01` is passed, it will evaluate to midnight UTC of that date (`2017-11-01T00:00:00.000Z`). If a datetime is passed, that exact time will be used. A `send_date` passed with no time zone will default to UTC, while a `send_date` passed with a time zone will be converted to UTC.



39
40
41
# File 'lib/lob/models/self_mailer.rb', line 39

def send_date
  @send_date
end

#sizeObject

Returns the value of attribute size.



25
26
27
# File 'lib/lob/models/self_mailer.rb', line 25

def size
  @size
end

#toObject

Returns the value of attribute to.



21
22
23
# File 'lib/lob/models/self_mailer.rb', line 21

def to
  @to
end

#tracking_eventsObject

An array of certified tracking events ordered by ascending ‘time`. Not populated in test mode.



57
58
59
# File 'lib/lob/models/self_mailer.rb', line 57

def tracking_events
  @tracking_events
end

#urlObject

A [signed link](#section/Asset-URLs) served over HTTPS. The link returned will expire in 30 days to prevent mis-sharing. Each time a GET request is initiated, a new signed URL will be generated.



60
61
62
# File 'lib/lob/models/self_mailer.rb', line 60

def url
  @url
end

#use_typeObject

Returns the value of attribute use_type.



62
63
64
# File 'lib/lob/models/self_mailer.rb', line 62

def use_type
  @use_type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



110
111
112
# File 'lib/lob/models/self_mailer.rb', line 110

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/lob/models/self_mailer.rb', line 87

def self.attribute_map
  {
    :'id' => :'id',
    :'to' => :'to',
    :'from' => :'from',
    :'size' => :'size',
    :'description' => :'description',
    :'metadata' => :'metadata',
    :'mail_type' => :'mail_type',
    :'merge_variables' => :'merge_variables',
    :'send_date' => :'send_date',
    :'outside_template_id' => :'outside_template_id',
    :'inside_template_id' => :'inside_template_id',
    :'outside_template_version_id' => :'outside_template_version_id',
    :'inside_template_version_id' => :'inside_template_version_id',
    :'object' => :'object',
    :'tracking_events' => :'tracking_events',
    :'url' => :'url',
    :'use_type' => :'use_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



458
459
460
# File 'lib/lob/models/self_mailer.rb', line 458

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/lob/models/self_mailer.rb', line 138

def self.openapi_nullable
  Set.new([
    :'to',
    :'from',
    :'description',
    :'merge_variables',
    :'outside_template_id',
    :'inside_template_id',
    :'outside_template_version_id',
    :'inside_template_version_id',
    :'use_type'
  ])
end

.openapi_typesObject

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/lob/models/self_mailer.rb', line 115

def self.openapi_types
  {
    :'id' => :'String',
    :'to' => Array[:'Address', :'String'],
    :'from' => Array[:'AddressDomesticExpanded', :'String'],
    :'size' => :'SelfMailerSize',
    :'description' => :'String',
    :'metadata' => :'Hash<String, String>',
    :'mail_type' => :'MailType',
    :'merge_variables' => :'Object',
    :'send_date' => :'Time',
    :'outside_template_id' => :'String',
    :'inside_template_id' => :'String',
    :'outside_template_version_id' => :'String',
    :'inside_template_version_id' => :'String',
    :'object' => :'String',
    :'tracking_events' => :'Array<TrackingEventCertified>',
    :'url' => :'String',
    :'use_type' => :'SfmUseType'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
# File 'lib/lob/models/self_mailer.rb', line 420

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      to == o.to &&
      from == o.from &&
      size == o.size &&
      description == o.description &&
       == o. &&
      mail_type == o.mail_type &&
      merge_variables == o.merge_variables &&
      send_date == o.send_date &&
      outside_template_id == o.outside_template_id &&
      inside_template_id == o.inside_template_id &&
      outside_template_version_id == o.outside_template_version_id &&
      inside_template_version_id == o.inside_template_version_id &&
      object == o.object &&
      tracking_events == o.tracking_events &&
      url == o.url &&
      use_type == o.use_type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'lib/lob/models/self_mailer.rb', line 497

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



568
569
570
571
572
573
574
575
576
577
578
579
580
# File 'lib/lob/models/self_mailer.rb', line 568

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
# File 'lib/lob/models/self_mailer.rb', line 465

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


444
445
446
# File 'lib/lob/models/self_mailer.rb', line 444

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



450
451
452
# File 'lib/lob/models/self_mailer.rb', line 450

def hash
  [id, to, from, size, description, , mail_type, merge_variables, send_date, outside_template_id, inside_template_id, outside_template_version_id, inside_template_version_id, object, tracking_events, url, use_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/lob/models/self_mailer.rb', line 248

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  pattern = Regexp.new(/^sfm_[a-zA-Z0-9]+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if !@description.nil? && @description.to_s.length > 255
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.')
  end

  pattern = Regexp.new(/^tmpl_[a-zA-Z0-9]+$/)
  if !@outside_template_id.nil? && @outside_template_id !~ pattern
    invalid_properties.push("invalid value for \"outside_template_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^tmpl_[a-zA-Z0-9]+$/)
  if !@inside_template_id.nil? && @inside_template_id !~ pattern
    invalid_properties.push("invalid value for \"inside_template_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^vrsn_[a-zA-Z0-9]+$/)
  if !@outside_template_version_id.nil? && @outside_template_version_id !~ pattern
    invalid_properties.push("invalid value for \"outside_template_version_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^vrsn_[a-zA-Z0-9]+$/)
  if !@inside_template_version_id.nil? && @inside_template_version_id !~ pattern
    invalid_properties.push("invalid value for \"inside_template_version_id\", must conform to the pattern #{pattern}.")
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  pattern = Regexp.new(/^https:\/\/lob-assets.com\/(letters|postcards|bank-accounts|checks|self-mailers|cards)\/[a-z]{3,4}_[a-z0-9]{15,16}(_signature)?(\.pdf|_thumb_[a-z]+_[0-9]+\.png|\.png)\?(version=[a-z0-9]*&)expires=[0-9]{10}&signature=[a-zA-Z0-9_-]+/)
  if @url !~ pattern
    invalid_properties.push("invalid value for \"url\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



544
545
546
# File 'lib/lob/models/self_mailer.rb', line 544

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



550
551
552
553
554
555
556
557
558
559
560
561
562
# File 'lib/lob/models/self_mailer.rb', line 550

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



538
539
540
# File 'lib/lob/models/self_mailer.rb', line 538

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/lob/models/self_mailer.rb', line 297

def valid?
  return false if @id.nil?
  return false if @id !~ Regexp.new(/^sfm_[a-zA-Z0-9]+$/)
  return false if !@description.nil? && @description.to_s.length > 255
  return false if !@outside_template_id.nil? && @outside_template_id !~ Regexp.new(/^tmpl_[a-zA-Z0-9]+$/)
  return false if !@inside_template_id.nil? && @inside_template_id !~ Regexp.new(/^tmpl_[a-zA-Z0-9]+$/)
  return false if !@outside_template_version_id.nil? && @outside_template_version_id !~ Regexp.new(/^vrsn_[a-zA-Z0-9]+$/)
  return false if !@inside_template_version_id.nil? && @inside_template_version_id !~ Regexp.new(/^vrsn_[a-zA-Z0-9]+$/)
  object_validator = EnumAttributeValidator.new('String', ["self_mailer"])
  return false unless object_validator.valid?(@object)
  return false if @url.nil?
  return false if @url !~ Regexp.new(/^https:\/\/lob-assets.com\/(letters|postcards|bank-accounts|checks|self-mailers|cards)\/[a-z]{3,4}_[a-z0-9]{15,16}(_signature)?(\.pdf|_thumb_[a-z]+_[0-9]+\.png|\.png)\?(version=[a-z0-9]*&)expires=[0-9]{10}&signature=[a-zA-Z0-9_-]+/)
  true
end