Class: Lob::TemplateVersion
- Inherits:
-
Object
- Object
- Lob::TemplateVersion
- Defined in:
- lib/lob/models/template_version.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#date_created ⇒ Object
A timestamp in ISO 8601 format of the date the resource was created.
-
#date_modified ⇒ Object
A timestamp in ISO 8601 format of the date the resource was last modified.
-
#deleted ⇒ Object
Only returned if the resource has been successfully deleted.
-
#description ⇒ Object
An internal description that identifies this resource.
-
#engine ⇒ Object
Returns the value of attribute engine.
-
#html ⇒ Object
An HTML string of less than 100,000 characters to be used as the ‘published_version` of this template.
-
#id ⇒ Object
Unique identifier prefixed with ‘vrsn_`.
-
#merge_variables ⇒ Object
Used by frontend, an object representing the keys of every merge variable present in the template.
-
#object ⇒ Object
Value is resource type.
-
#suggest_json_editor ⇒ Object
Used by frontend, true if the template uses advanced features.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TemplateVersion
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ TemplateVersion
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/lob/models/template_version.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::TemplateVersion` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::TemplateVersion`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'html') self.html = attributes[:'html'] end if attributes.key?(:'engine') self.engine = attributes[:'engine'] else self.engine = 'legacy' end if attributes.key?(:'suggest_json_editor') self.suggest_json_editor = attributes[:'suggest_json_editor'] end if attributes.key?(:'merge_variables') self.merge_variables = attributes[:'merge_variables'] end if attributes.key?(:'date_created') self.date_created = attributes[:'date_created'] end if attributes.key?(:'date_modified') self.date_modified = attributes[:'date_modified'] end if attributes.key?(:'deleted') self.deleted = attributes[:'deleted'] end if attributes.key?(:'object') self.object = attributes[:'object'] else self.object = 'version' end end |
Instance Attribute Details
#date_created ⇒ Object
A timestamp in ISO 8601 format of the date the resource was created.
36 37 38 |
# File 'lib/lob/models/template_version.rb', line 36 def date_created @date_created end |
#date_modified ⇒ Object
A timestamp in ISO 8601 format of the date the resource was last modified.
39 40 41 |
# File 'lib/lob/models/template_version.rb', line 39 def date_modified @date_modified end |
#deleted ⇒ Object
Only returned if the resource has been successfully deleted.
42 43 44 |
# File 'lib/lob/models/template_version.rb', line 42 def deleted @deleted end |
#description ⇒ Object
An internal description that identifies this resource. Must be no longer than 255 characters.
22 23 24 |
# File 'lib/lob/models/template_version.rb', line 22 def description @description end |
#engine ⇒ Object
Returns the value of attribute engine.
27 28 29 |
# File 'lib/lob/models/template_version.rb', line 27 def engine @engine end |
#html ⇒ Object
An HTML string of less than 100,000 characters to be used as the ‘published_version` of this template. See [here](#section/HTML-Examples) for guidance on designing HTML templates. Please see endpoint specific documentation for any other product-specific HTML details: - [Postcards](docs.lob.com/#tag/Postcards/operation/postcard_create) - `front` and `back` - [Self Mailers](docs.lob.com/#tag/Self-Mailers/operation/self_mailer_create) - `inside` and `outside` - [Letters](docs.lob.com/#tag/Letters/operation/letter_create) - `file` - [Checks](docs.lob.com/#tag/Checks/operation/check_create) - `check_bottom` and `attachment` - [Cards](docs.lob.com/#tag/Cards/operation/card_create) - `front` and `back` If there is a syntax error with your variable names within your HTML, then an error will be thrown, e.g. using a `Lob::TemplateVersion.{{#users}` opening tag without the corresponding closing tag `{/users}`.
25 26 27 |
# File 'lib/lob/models/template_version.rb', line 25 def html @html end |
#id ⇒ Object
Unique identifier prefixed with ‘vrsn_`.
19 20 21 |
# File 'lib/lob/models/template_version.rb', line 19 def id @id end |
#merge_variables ⇒ Object
Used by frontend, an object representing the keys of every merge variable present in the template. It has one key named ‘keys’, and its value is an array of strings.
33 34 35 |
# File 'lib/lob/models/template_version.rb', line 33 def merge_variables @merge_variables end |
#object ⇒ Object
Value is resource type.
45 46 47 |
# File 'lib/lob/models/template_version.rb', line 45 def object @object end |
#suggest_json_editor ⇒ Object
Used by frontend, true if the template uses advanced features.
30 31 32 |
# File 'lib/lob/models/template_version.rb', line 30 def suggest_json_editor @suggest_json_editor end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
86 87 88 |
# File 'lib/lob/models/template_version.rb', line 86 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/lob/models/template_version.rb', line 70 def self.attribute_map { :'id' => :'id', :'description' => :'description', :'html' => :'html', :'engine' => :'engine', :'suggest_json_editor' => :'suggest_json_editor', :'merge_variables' => :'merge_variables', :'date_created' => :'date_created', :'date_modified' => :'date_modified', :'deleted' => :'deleted', :'object' => :'object' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
297 298 299 |
# File 'lib/lob/models/template_version.rb', line 297 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
107 108 109 110 111 112 |
# File 'lib/lob/models/template_version.rb', line 107 def self.openapi_nullable Set.new([ :'description', :'engine', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/lob/models/template_version.rb', line 91 def self.openapi_types { :'id' => :'String', :'description' => :'String', :'html' => :'String', :'engine' => :'EngineHtml', :'suggest_json_editor' => :'Boolean', :'merge_variables' => :'Object', :'date_created' => :'Time', :'date_modified' => :'Time', :'deleted' => :'Boolean', :'object' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/lob/models/template_version.rb', line 266 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && description == o.description && html == o.html && engine == o.engine && suggest_json_editor == o.suggest_json_editor && merge_variables == o.merge_variables && date_created == o.date_created && date_modified == o.date_modified && deleted == o.deleted && object == o.object end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/lob/models/template_version.rb', line 336 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Lob.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/lob/models/template_version.rb', line 407 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/lob/models/template_version.rb', line 304 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) # // guardrails-disable-line elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line end elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array) for base_type in type do res = _deserialize(base_type, attributes[self.class.attribute_map[key]]) if !res.nil? self.send("#{key}=", res) # // guardrails-disable-line break end end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line end end self end |
#eql?(o) ⇒ Boolean
283 284 285 |
# File 'lib/lob/models/template_version.rb', line 283 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
289 290 291 |
# File 'lib/lob/models/template_version.rb', line 289 def hash [id, description, html, engine, suggest_json_editor, merge_variables, date_created, date_modified, deleted, object].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/lob/models/template_version.rb', line 176 def list_invalid_properties invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end pattern = Regexp.new(/^vrsn_[a-zA-Z0-9]+$/) if @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end if !@description.nil? && @description.to_s.length > 255 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.') end if @html.nil? invalid_properties.push('invalid value for "html", html cannot be nil.') end if @html.to_s.length > 100000 invalid_properties.push('invalid value for "html", the character length must be smaller than or equal to 100000.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
383 384 385 |
# File 'lib/lob/models/template_version.rb', line 383 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/lob/models/template_version.rb', line 389 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) # // guardrails-disable-line if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
377 378 379 |
# File 'lib/lob/models/template_version.rb', line 377 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
204 205 206 207 208 209 210 211 212 213 |
# File 'lib/lob/models/template_version.rb', line 204 def valid? return false if @id.nil? return false if @id !~ Regexp.new(/^vrsn_[a-zA-Z0-9]+$/) return false if !@description.nil? && @description.to_s.length > 255 return false if @html.nil? return false if @html.to_s.length > 100000 object_validator = EnumAttributeValidator.new('String', ["version"]) return false unless object_validator.valid?(@object) true end |