Class: Lob::TemplateVersionsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/api/template_versions_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ TemplateVersionsApi

Returns a new instance of TemplateVersionsApi.



19
20
21
# File 'lib/lob/api/template_versions_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/lob/api/template_versions_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create(tmpl_id, template_version_writable, opts = {}) ⇒ TemplateVersion

create Creates a new template version attached to the specified template.

Parameters:

  • tmpl_id (String)

    The ID of the template the new version will be attached to

  • template_version_writable (TemplateVersionWritable)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



28
29
30
31
# File 'lib/lob/api/template_versions_api.rb', line 28

def create(tmpl_id, template_version_writable, opts = {})
  data, _status_code, _headers = create_template_version_with_http_info(tmpl_id, template_version_writable, opts)
  data
end

#create_template_version_with_http_info(tmpl_id, template_version_writable, opts = {}) ⇒ Array<(TemplateVersion, Integer, Hash)>

create Creates a new template version attached to the specified template.

Parameters:

  • tmpl_id (String)

    The ID of the template the new version will be attached to

  • template_version_writable (TemplateVersionWritable)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(TemplateVersion, Integer, Hash)>)

    TemplateVersion data, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/lob/api/template_versions_api.rb', line 39

def create_template_version_with_http_info(tmpl_id, template_version_writable, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TemplateVersionsApi.create_template_version ...'
  end
  # verify the required parameter 'tmpl_id' is set
  if @api_client.config.client_side_validation && tmpl_id.nil?
    fail ArgumentError, "Missing the required parameter 'tmpl_id' when calling TemplateVersionsApi.create_template_version"
  end
  pattern = Regexp.new(/^tmpl_[a-zA-Z0-9]+$/)
  if @api_client.config.client_side_validation && tmpl_id !~ pattern
    fail ArgumentError, "invalid value for 'tmpl_id' when calling TemplateVersionsApi.create_template_version, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'template_version_writable' is set
  if @api_client.config.client_side_validation && template_version_writable.nil?
    fail ArgumentError, "Missing the required parameter 'template_version_writable' when calling TemplateVersionsApi.create_template_version"
  end
  # resource path
  local_var_path = '/templates/{tmpl_id}/versions'.sub('{' + 'tmpl_id' + '}', CGI.escape(tmpl_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(template_version_writable)

  # return_type
  return_type = opts[:debug_return_type] || 'TemplateVersion'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"TemplateVersionsApi.create_template_version",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TemplateVersionsApi#create_template_version\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete(tmpl_id, vrsn_id, opts = {}) ⇒ TemplateVersionDeletion

delete Permanently deletes a template version. A template’s ‘published_version` can not be deleted.

Parameters:

  • tmpl_id (String)

    The ID of the template to which the version belongs.

  • vrsn_id (String)

    id of the template_version

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



107
108
109
110
# File 'lib/lob/api/template_versions_api.rb', line 107

def delete(tmpl_id, vrsn_id, opts = {})
  data, _status_code, _headers = template_version_delete_with_http_info(tmpl_id, vrsn_id, opts)
  data
end

#get(tmpl_id, vrsn_id, opts = {}) ⇒ TemplateVersion

get Retrieves the template version with the given template and version ids.

Parameters:

  • tmpl_id (String)

    The ID of the template to which the version belongs.

  • vrsn_id (String)

    id of the template_version

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



186
187
188
189
# File 'lib/lob/api/template_versions_api.rb', line 186

def get(tmpl_id, vrsn_id, opts = {})
  data, _status_code, _headers = template_version_retrieve_with_http_info(tmpl_id, vrsn_id, opts)
  data
end

#list(tmpl_id, opts = {}) ⇒ TemplateVersionList

list Returns a list of template versions for the given template ID. The template versions are sorted by creation date, with the most recently created appearing first.

Parameters:

  • tmpl_id (String)

    The ID of the template associated with the retrieved versions

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    How many results to return. (default to 10)

  • :before (String)

    A reference to a list entry used for paginating to the previous set of entries. This field is pre-populated in the &#x60;previous_url&#x60; field in the return response.

  • :after (String)

    A reference to a list entry used for paginating to the next set of entries. This field is pre-populated in the &#x60;next_url&#x60; field in the return response.

  • :include (Array<String>)

    Request that the response include the total count by specifying &#x60;include[]&#x3D;total_count&#x60;.

  • :date_created (Hash<String, Time>)

    Filter by date created.

Returns:



359
360
361
362
# File 'lib/lob/api/template_versions_api.rb', line 359

def list(tmpl_id, opts = {})
  data, _status_code, _headers = template_versions_list_with_http_info(tmpl_id, opts)
  data
end

#template_version_delete_with_http_info(tmpl_id, vrsn_id, opts = {}) ⇒ Array<(TemplateVersionDeletion, Integer, Hash)>

delete Permanently deletes a template version. A template&#39;s &#x60;published_version&#x60; can not be deleted.

Parameters:

  • tmpl_id (String)

    The ID of the template to which the version belongs.

  • vrsn_id (String)

    id of the template_version

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(TemplateVersionDeletion, Integer, Hash)>)

    TemplateVersionDeletion data, response status code and response headers



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/lob/api/template_versions_api.rb', line 118

def template_version_delete_with_http_info(tmpl_id, vrsn_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TemplateVersionsApi.template_version_delete ...'
  end
  # verify the required parameter 'tmpl_id' is set
  if @api_client.config.client_side_validation && tmpl_id.nil?
    fail ArgumentError, "Missing the required parameter 'tmpl_id' when calling TemplateVersionsApi.template_version_delete"
  end
  pattern = Regexp.new(/^tmpl_[a-zA-Z0-9]+$/)
  if @api_client.config.client_side_validation && tmpl_id !~ pattern
    fail ArgumentError, "invalid value for 'tmpl_id' when calling TemplateVersionsApi.template_version_delete, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'vrsn_id' is set
  if @api_client.config.client_side_validation && vrsn_id.nil?
    fail ArgumentError, "Missing the required parameter 'vrsn_id' when calling TemplateVersionsApi.template_version_delete"
  end
  pattern = Regexp.new(/^vrsn_[a-zA-Z0-9]+$/)
  if @api_client.config.client_side_validation && vrsn_id !~ pattern
    fail ArgumentError, "invalid value for 'vrsn_id' when calling TemplateVersionsApi.template_version_delete, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/templates/{tmpl_id}/versions/{vrsn_id}'.sub('{' + 'tmpl_id' + '}', CGI.escape(tmpl_id.to_s)).sub('{' + 'vrsn_id' + '}', CGI.escape(vrsn_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'TemplateVersionDeletion'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"TemplateVersionsApi.template_version_delete",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TemplateVersionsApi#template_version_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#template_version_retrieve_with_http_info(tmpl_id, vrsn_id, opts = {}) ⇒ Array<(TemplateVersion, Integer, Hash)>

get Retrieves the template version with the given template and version ids.

Parameters:

  • tmpl_id (String)

    The ID of the template to which the version belongs.

  • vrsn_id (String)

    id of the template_version

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(TemplateVersion, Integer, Hash)>)

    TemplateVersion data, response status code and response headers



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/lob/api/template_versions_api.rb', line 197

def template_version_retrieve_with_http_info(tmpl_id, vrsn_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TemplateVersionsApi.template_version_retrieve ...'
  end
  # verify the required parameter 'tmpl_id' is set
  if @api_client.config.client_side_validation && tmpl_id.nil?
    fail ArgumentError, "Missing the required parameter 'tmpl_id' when calling TemplateVersionsApi.template_version_retrieve"
  end
  pattern = Regexp.new(/^tmpl_[a-zA-Z0-9]+$/)
  if @api_client.config.client_side_validation && tmpl_id !~ pattern
    fail ArgumentError, "invalid value for 'tmpl_id' when calling TemplateVersionsApi.template_version_retrieve, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'vrsn_id' is set
  if @api_client.config.client_side_validation && vrsn_id.nil?
    fail ArgumentError, "Missing the required parameter 'vrsn_id' when calling TemplateVersionsApi.template_version_retrieve"
  end
  pattern = Regexp.new(/^vrsn_[a-zA-Z0-9]+$/)
  if @api_client.config.client_side_validation && vrsn_id !~ pattern
    fail ArgumentError, "invalid value for 'vrsn_id' when calling TemplateVersionsApi.template_version_retrieve, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/templates/{tmpl_id}/versions/{vrsn_id}'.sub('{' + 'tmpl_id' + '}', CGI.escape(tmpl_id.to_s)).sub('{' + 'vrsn_id' + '}', CGI.escape(vrsn_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'TemplateVersion'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"TemplateVersionsApi.template_version_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TemplateVersionsApi#template_version_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#template_version_update_with_http_info(tmpl_id, vrsn_id, template_version_updatable, opts = {}) ⇒ Array<(TemplateVersion, Integer, Hash)>

update Updates the template version with the given template and version ids.

Parameters:

  • tmpl_id (String)

    The ID of the template to which the version belongs.

  • vrsn_id (String)

    id of the template_version

  • template_version_updatable (TemplateVersionUpdatable)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(TemplateVersion, Integer, Hash)>)

    TemplateVersion data, response status code and response headers



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/lob/api/template_versions_api.rb', line 278

def template_version_update_with_http_info(tmpl_id, vrsn_id, template_version_updatable, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TemplateVersionsApi.template_version_update ...'
  end
  # verify the required parameter 'tmpl_id' is set
  if @api_client.config.client_side_validation && tmpl_id.nil?
    fail ArgumentError, "Missing the required parameter 'tmpl_id' when calling TemplateVersionsApi.template_version_update"
  end
  pattern = Regexp.new(/^tmpl_[a-zA-Z0-9]+$/)
  if @api_client.config.client_side_validation && tmpl_id !~ pattern
    fail ArgumentError, "invalid value for 'tmpl_id' when calling TemplateVersionsApi.template_version_update, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'vrsn_id' is set
  if @api_client.config.client_side_validation && vrsn_id.nil?
    fail ArgumentError, "Missing the required parameter 'vrsn_id' when calling TemplateVersionsApi.template_version_update"
  end
  pattern = Regexp.new(/^vrsn_[a-zA-Z0-9]+$/)
  if @api_client.config.client_side_validation && vrsn_id !~ pattern
    fail ArgumentError, "invalid value for 'vrsn_id' when calling TemplateVersionsApi.template_version_update, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'template_version_updatable' is set
  if @api_client.config.client_side_validation && template_version_updatable.nil?
    fail ArgumentError, "Missing the required parameter 'template_version_updatable' when calling TemplateVersionsApi.template_version_update"
  end
  # resource path
  local_var_path = '/templates/{tmpl_id}/versions/{vrsn_id}'.sub('{' + 'tmpl_id' + '}', CGI.escape(tmpl_id.to_s)).sub('{' + 'vrsn_id' + '}', CGI.escape(vrsn_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(template_version_updatable)

  # return_type
  return_type = opts[:debug_return_type] || 'TemplateVersion'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"TemplateVersionsApi.template_version_update",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TemplateVersionsApi#template_version_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#template_versions_list_with_http_info(tmpl_id, opts = {}) ⇒ Array<(TemplateVersionList, Integer, Hash)>

list Returns a list of template versions for the given template ID. The template versions are sorted by creation date, with the most recently created appearing first.

Parameters:

  • tmpl_id (String)

    The ID of the template associated with the retrieved versions

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    How many results to return. (default to 10)

  • :before (String)

    A reference to a list entry used for paginating to the previous set of entries. This field is pre-populated in the &#x60;previous_url&#x60; field in the return response.

  • :after (String)

    A reference to a list entry used for paginating to the next set of entries. This field is pre-populated in the &#x60;next_url&#x60; field in the return response.

  • :include (Array<String>)

    Request that the response include the total count by specifying &#x60;include[]&#x3D;total_count&#x60;.

  • :date_created (Hash<String, Time>)

    Filter by date created.

Returns:

  • (Array<(TemplateVersionList, Integer, Hash)>)

    TemplateVersionList data, response status code and response headers



374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/lob/api/template_versions_api.rb', line 374

def template_versions_list_with_http_info(tmpl_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TemplateVersionsApi.template_versions_list ...'
  end
  # verify the required parameter 'tmpl_id' is set
  if @api_client.config.client_side_validation && tmpl_id.nil?
    fail ArgumentError, "Missing the required parameter 'tmpl_id' when calling TemplateVersionsApi.template_versions_list"
  end
  pattern = Regexp.new(/^tmpl_[a-zA-Z0-9]+$/)
  if @api_client.config.client_side_validation && tmpl_id !~ pattern
    fail ArgumentError, "invalid value for 'tmpl_id' when calling TemplateVersionsApi.template_versions_list, must conform to the pattern #{pattern}."
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling TemplateVersionsApi.template_versions_list, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling TemplateVersionsApi.template_versions_list, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/templates/{tmpl_id}/versions'.sub('{' + 'tmpl_id' + '}', CGI.escape(tmpl_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'before'] = opts[:'before'] if !opts[:'before'].nil?
  query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil?
  query_params[:'include'] = @api_client.build_collection_param(opts[:'include'], :multi) if !opts[:'include'].nil?
  query_params[:'date_created'] = opts[:'date_created'] if !opts[:'date_created'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'TemplateVersionList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"TemplateVersionsApi.template_versions_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TemplateVersionsApi#template_versions_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update(tmpl_id, vrsn_id, template_version_updatable, opts = {}) ⇒ TemplateVersion

update Updates the template version with the given template and version ids.

Parameters:

  • tmpl_id (String)

    The ID of the template to which the version belongs.

  • vrsn_id (String)

    id of the template_version

  • template_version_updatable (TemplateVersionUpdatable)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



266
267
268
269
# File 'lib/lob/api/template_versions_api.rb', line 266

def update(tmpl_id, vrsn_id, template_version_updatable, opts = {})
  data, _status_code, _headers = template_version_update_with_http_info(tmpl_id, vrsn_id, template_version_updatable, opts)
  data
end