Class: Lob::TemplateWritable
- Inherits:
-
Object
- Object
- Lob::TemplateWritable
- Defined in:
- lib/lob/models/template_writable.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
An internal description that identifies this resource.
-
#engine ⇒ Object
Returns the value of attribute engine.
-
#html ⇒ Object
An HTML string of less than 100,000 characters to be used as the ‘published_version` of this template.
-
#metadata ⇒ Object
Use metadata to store custom information for tagging and labeling back to your internal systems.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TemplateWritable
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ TemplateWritable
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/lob/models/template_writable.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::TemplateWritable` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::TemplateWritable`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'html') self.html = attributes[:'html'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'engine') self.engine = attributes[:'engine'] else self.engine = 'legacy' end end |
Instance Attribute Details
#description ⇒ Object
An internal description that identifies this resource. Must be no longer than 255 characters.
19 20 21 |
# File 'lib/lob/models/template_writable.rb', line 19 def description @description end |
#engine ⇒ Object
Returns the value of attribute engine.
27 28 29 |
# File 'lib/lob/models/template_writable.rb', line 27 def engine @engine end |
#html ⇒ Object
An HTML string of less than 100,000 characters to be used as the ‘published_version` of this template. See [here](#section/HTML-Examples) for guidance on designing HTML templates. Please see endpoint specific documentation for any other product-specific HTML details: - [Postcards](docs.lob.com/#tag/Postcards/operation/postcard_create) - `front` and `back` - [Self Mailers](docs.lob.com/#tag/Self-Mailers/operation/self_mailer_create) - `inside` and `outside` - [Letters](docs.lob.com/#tag/Letters/operation/letter_create) - `file` - [Checks](docs.lob.com/#tag/Checks/operation/check_create) - `check_bottom` and `attachment` - [Cards](docs.lob.com/#tag/Cards/operation/card_create) - `front` and `back` If there is a syntax error with your variable names within your HTML, then an error will be thrown, e.g. using a `Lob::TemplateWritable.{{#users}` opening tag without the corresponding closing tag `{/users}`.
22 23 24 |
# File 'lib/lob/models/template_writable.rb', line 22 def html @html end |
#metadata ⇒ Object
Use metadata to store custom information for tagging and labeling back to your internal systems. Must be an object with up to 20 key-value pairs. Keys must be at most 40 characters and values must be at most 500 characters. Neither can contain the characters ‘"` and `\`. i.e. ’: "NEWYORK2015"‘ Nested objects are not supported. See [Metadata](#section/Metadata) for more information.
25 26 27 |
# File 'lib/lob/models/template_writable.rb', line 25 def @metadata end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
40 41 42 |
# File 'lib/lob/models/template_writable.rb', line 40 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 |
# File 'lib/lob/models/template_writable.rb', line 30 def self.attribute_map { :'description' => :'description', :'html' => :'html', :'metadata' => :'metadata', :'engine' => :'engine' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 |
# File 'lib/lob/models/template_writable.rb', line 183 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
55 56 57 58 59 60 |
# File 'lib/lob/models/template_writable.rb', line 55 def self.openapi_nullable Set.new([ :'description', :'engine' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 |
# File 'lib/lob/models/template_writable.rb', line 45 def self.openapi_types { :'description' => :'String', :'html' => :'String', :'metadata' => :'Hash<String, String>', :'engine' => :'EngineHtml' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
158 159 160 161 162 163 164 165 |
# File 'lib/lob/models/template_writable.rb', line 158 def ==(o) return true if self.equal?(o) self.class == o.class && description == o.description && html == o.html && == o. && engine == o.engine end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/lob/models/template_writable.rb', line 222 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Lob.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/lob/models/template_writable.rb', line 293 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/lob/models/template_writable.rb', line 190 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) # // guardrails-disable-line elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line end elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array) for base_type in type do res = _deserialize(base_type, attributes[self.class.attribute_map[key]]) if !res.nil? self.send("#{key}=", res) # // guardrails-disable-line break end end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line end end self end |
#eql?(o) ⇒ Boolean
169 170 171 |
# File 'lib/lob/models/template_writable.rb', line 169 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
175 176 177 |
# File 'lib/lob/models/template_writable.rb', line 175 def hash [description, html, , engine].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/lob/models/template_writable.rb', line 100 def list_invalid_properties invalid_properties = Array.new if !@description.nil? && @description.to_s.length > 255 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.') end if @html.nil? invalid_properties.push('invalid value for "html", html cannot be nil.') end if @html.to_s.length > 100000 invalid_properties.push('invalid value for "html", the character length must be smaller than or equal to 100000.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
269 270 271 |
# File 'lib/lob/models/template_writable.rb', line 269 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/lob/models/template_writable.rb', line 275 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) # // guardrails-disable-line if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
263 264 265 |
# File 'lib/lob/models/template_writable.rb', line 263 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
119 120 121 122 123 124 |
# File 'lib/lob/models/template_writable.rb', line 119 def valid? return false if !@description.nil? && @description.to_s.length > 255 return false if @html.nil? return false if @html.to_s.length > 100000 true end |