Class: Lob::TrackingEventNormal

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/tracking_event_normal.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TrackingEventNormal

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/lob/models/tracking_event_normal.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::TrackingEventNormal` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::TrackingEventNormal`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'details')
    self.details = attributes[:'details']
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'time')
    self.time = attributes[:'time']
  end

  if attributes.key?(:'date_created')
    self.date_created = attributes[:'date_created']
  end

  if attributes.key?(:'date_modified')
    self.date_modified = attributes[:'date_modified']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = 'tracking_event'
  end
end

Instance Attribute Details

#date_createdObject

A timestamp in ISO 8601 format of the date the resource was created.



37
38
39
# File 'lib/lob/models/tracking_event_normal.rb', line 37

def date_created
  @date_created
end

#date_modifiedObject

A timestamp in ISO 8601 format of the date the resource was last modified.



40
41
42
# File 'lib/lob/models/tracking_event_normal.rb', line 40

def date_modified
  @date_modified
end

#detailsObject

Will be ‘null` for `type=normal` events



25
26
27
# File 'lib/lob/models/tracking_event_normal.rb', line 25

def details
  @details
end

#idObject

Unique identifier prefixed with ‘evnt_`.



31
32
33
# File 'lib/lob/models/tracking_event_normal.rb', line 31

def id
  @id
end

#locationObject

The zip code in which the scan event occurred. Null for ‘Mailed` events.



28
29
30
# File 'lib/lob/models/tracking_event_normal.rb', line 28

def location
  @location
end

#nameObject

Name of tracking event (for normal postcards, self mailers, letters, and checks): * ‘Mailed` - The mailpiece has been handed off to and accepted by USPS and is en route. <a href="help.lob.com/print-and-mail/getting-data-and-results/tracking-your-mail#mailed-tracking-events-4" target="_blank">More about Mailed.</a> Note this data is only available in Enterprise editions of Lob. <a href="lob.com/support/contact#contact" target="_blank">Contact Sales</a> if you want access to this feature. * `In Transit` - The mailpiece is being processed at the entry/origin facility. * `In Local Area` - The mailpiece is being processed at the destination facility. * `Processed for Delivery` - The mailpiece has been greenlit for delivery at the recipient’s nearest postal facility. The mailpiece should reach the mailbox within 1 business day of this tracking event. * ‘Delivered` - The mail piece has been delivered to the recipients address. The final scan is generated when the mail carrier’s GPS unit leaves the delivery area. * ‘Re-Routed` - The mailpiece is re-routed due to recipient change of address, address errors, or USPS relabeling of barcode/ID tag area. * `Returned to Sender` - The mailpiece is being returned to sender due to barcode, ID tag area, or address errors. * `International Exit` - The mail piece has been processed to ship to a destination abroad. This is typically the last scan a US-originated international mail piece will receive from the USPS. [More about tracking](support.lob.com/hc/en-us/articles/115000097404-Can-I-track-my-mail-)



22
23
24
# File 'lib/lob/models/tracking_event_normal.rb', line 22

def name
  @name
end

#objectObject

Returns the value of attribute object.



42
43
44
# File 'lib/lob/models/tracking_event_normal.rb', line 42

def object
  @object
end

#timeObject

A timestamp in ISO 8601 format of the date USPS registered the event.



34
35
36
# File 'lib/lob/models/tracking_event_normal.rb', line 34

def time
  @time
end

#typeObject

non-Certified postcards, self mailers, letters, and checks



19
20
21
# File 'lib/lob/models/tracking_event_normal.rb', line 19

def type
  @type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/lob/models/tracking_event_normal.rb', line 82

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/lob/models/tracking_event_normal.rb', line 67

def self.attribute_map
  {
    :'type' => :'type',
    :'name' => :'name',
    :'details' => :'details',
    :'location' => :'location',
    :'id' => :'id',
    :'time' => :'time',
    :'date_created' => :'date_created',
    :'date_modified' => :'date_modified',
    :'object' => :'object'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



283
284
285
# File 'lib/lob/models/tracking_event_normal.rb', line 283

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
106
107
# File 'lib/lob/models/tracking_event_normal.rb', line 102

def self.openapi_nullable
  Set.new([
    :'details',
    :'location',
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/lob/models/tracking_event_normal.rb', line 87

def self.openapi_types
  {
    :'type' => :'String',
    :'name' => :'String',
    :'details' => :'Object',
    :'location' => :'String',
    :'id' => :'String',
    :'time' => :'Time',
    :'date_created' => :'Time',
    :'date_modified' => :'Time',
    :'object' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/lob/models/tracking_event_normal.rb', line 253

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      name == o.name &&
      details == o.details &&
      location == o.location &&
      id == o.id &&
      time == o.time &&
      date_created == o.date_created &&
      date_modified == o.date_modified &&
      object == o.object
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/lob/models/tracking_event_normal.rb', line 322

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/lob/models/tracking_event_normal.rb', line 393

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/lob/models/tracking_event_normal.rb', line 290

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


269
270
271
# File 'lib/lob/models/tracking_event_normal.rb', line 269

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



275
276
277
# File 'lib/lob/models/tracking_event_normal.rb', line 275

def hash
  [type, name, details, location, id, time, date_created, date_modified, object].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/lob/models/tracking_event_normal.rb', line 165

def list_invalid_properties
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  pattern = Regexp.new(/^evnt_[a-zA-Z0-9]+$/)
  if !@id.nil? && @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



369
370
371
# File 'lib/lob/models/tracking_event_normal.rb', line 369

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/lob/models/tracking_event_normal.rb', line 375

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



363
364
365
# File 'lib/lob/models/tracking_event_normal.rb', line 363

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/lob/models/tracking_event_normal.rb', line 185

def valid?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["normal"])
  return false unless type_validator.valid?(@type)
  return false if @name.nil?
  name_validator = EnumAttributeValidator.new('String', ["Mailed", "In Transit", "In Local Area", "Processed for Delivery", "Delivered", "Re-Routed", "Returned to Sender", "International Exit"])
  return false unless name_validator.valid?(@name)
  details_validator = EnumAttributeValidator.new('Object', ["null"])
  return false unless details_validator.valid?(@details)
  return false if !@id.nil? && @id !~ Regexp.new(/^evnt_[a-zA-Z0-9]+$/)
  object_validator = EnumAttributeValidator.new('String', ["tracking_event"])
  return false unless object_validator.valid?(@object)
  true
end