Class: Lob::Upload

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/upload.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Upload

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/lob/models/upload.rb', line 147

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::Upload` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::Upload`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  end

  if attributes.key?(:'failures_url')
    self.failures_url = attributes[:'failures_url']
  end

  if attributes.key?(:'original_filename')
    self.original_filename = attributes[:'original_filename']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = 'Draft'
  end

  if attributes.key?(:'total_mailpieces')
    self.total_mailpieces = attributes[:'total_mailpieces']
  end

  if attributes.key?(:'failed_mailpieces')
    self.failed_mailpieces = attributes[:'failed_mailpieces']
  end

  if attributes.key?(:'validated_mailpieces')
    self.validated_mailpieces = attributes[:'validated_mailpieces']
  end

  if attributes.key?(:'bytes_processed')
    self.bytes_processed = attributes[:'bytes_processed']
  end

  if attributes.key?(:'date_created')
    self.date_created = attributes[:'date_created']
  end

  if attributes.key?(:'date_modified')
    self.date_modified = attributes[:'date_modified']
  end

  if attributes.key?(:'required_address_column_mapping')
    self.required_address_column_mapping = attributes[:'required_address_column_mapping']
  end

  if attributes.key?(:'optional_address_column_mapping')
    self.optional_address_column_mapping = attributes[:'optional_address_column_mapping']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'merge_variable_column_mapping')
    self.merge_variable_column_mapping = attributes[:'merge_variable_column_mapping']
  end
end

Instance Attribute Details

#account_idObject

Account ID that made the request



22
23
24
# File 'lib/lob/models/upload.rb', line 22

def 
  @account_id
end

#bytes_processedObject

Number of bytes processed in your CSV



48
49
50
# File 'lib/lob/models/upload.rb', line 48

def bytes_processed
  @bytes_processed
end

#campaign_idObject

Campaign ID associated with the upload



28
29
30
# File 'lib/lob/models/upload.rb', line 28

def campaign_id
  @campaign_id
end

#date_createdObject

A timestamp in ISO 8601 format of the date the upload was created



51
52
53
# File 'lib/lob/models/upload.rb', line 51

def date_created
  @date_created
end

#date_modifiedObject

A timestamp in ISO 8601 format of the date the upload was last modified



54
55
56
# File 'lib/lob/models/upload.rb', line 54

def date_modified
  @date_modified
end

#failed_mailpiecesObject

Number of mailpieces that failed to create



42
43
44
# File 'lib/lob/models/upload.rb', line 42

def failed_mailpieces
  @failed_mailpieces
end

#failures_urlObject

Url where your campaign mailpiece failures can be retrieved



31
32
33
# File 'lib/lob/models/upload.rb', line 31

def failures_url
  @failures_url
end

#idObject

Unique identifier prefixed with ‘upl_`.



19
20
21
# File 'lib/lob/models/upload.rb', line 19

def id
  @id
end

#merge_variable_column_mappingObject

The mapping of column headers in your file to the merge variables present in your creative. See our <a href="help.lob.com/print-and-mail/building-a-mail-strategy/campaign-or-triggered-sends/campaign-audience-guide#step-3-map-merge-variable-data-if-applicable-7" target="_blank">Campaign Audience Guide</a> for additional details. <br />If a merge variable has the same "name" as a "key" in the ‘requiredAddressColumnMapping` or `optionalAddressColumnMapping` objects, then they CANNOT have a different value in this object. If a different value is provided, then when the campaign is processing it will get overwritten with the mapped value present in the `requiredAddressColumnMapping` or `optionalAddressColumnMapping` objects.



63
64
65
# File 'lib/lob/models/upload.rb', line 63

def merge_variable_column_mapping
  @merge_variable_column_mapping
end

#metadataObject

Returns the value of attribute metadata.



60
61
62
# File 'lib/lob/models/upload.rb', line 60

def 
  @metadata
end

#modeObject

The environment in which the mailpieces were created. Today, will only be ‘live`.



25
26
27
# File 'lib/lob/models/upload.rb', line 25

def mode
  @mode
end

#optional_address_column_mappingObject

Returns the value of attribute optional_address_column_mapping.



58
59
60
# File 'lib/lob/models/upload.rb', line 58

def optional_address_column_mapping
  @optional_address_column_mapping
end

#original_filenameObject

Filename of the upload



34
35
36
# File 'lib/lob/models/upload.rb', line 34

def original_filename
  @original_filename
end

#required_address_column_mappingObject

Returns the value of attribute required_address_column_mapping.



56
57
58
# File 'lib/lob/models/upload.rb', line 56

def required_address_column_mapping
  @required_address_column_mapping
end

#stateObject

Returns the value of attribute state.



36
37
38
# File 'lib/lob/models/upload.rb', line 36

def state
  @state
end

#total_mailpiecesObject

Total number of recipients for the campaign



39
40
41
# File 'lib/lob/models/upload.rb', line 39

def total_mailpieces
  @total_mailpieces
end

#validated_mailpiecesObject

Number of mailpieces that were successfully created



45
46
47
# File 'lib/lob/models/upload.rb', line 45

def validated_mailpieces
  @validated_mailpieces
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



111
112
113
# File 'lib/lob/models/upload.rb', line 111

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/lob/models/upload.rb', line 88

def self.attribute_map
  {
    :'id' => :'id',
    :'account_id' => :'accountId',
    :'mode' => :'mode',
    :'campaign_id' => :'campaignId',
    :'failures_url' => :'failuresUrl',
    :'original_filename' => :'originalFilename',
    :'state' => :'state',
    :'total_mailpieces' => :'totalMailpieces',
    :'failed_mailpieces' => :'failedMailpieces',
    :'validated_mailpieces' => :'validatedMailpieces',
    :'bytes_processed' => :'bytesProcessed',
    :'date_created' => :'dateCreated',
    :'date_modified' => :'dateModified',
    :'required_address_column_mapping' => :'requiredAddressColumnMapping',
    :'optional_address_column_mapping' => :'optionalAddressColumnMapping',
    :'metadata' => :'metadata',
    :'merge_variable_column_mapping' => :'mergeVariableColumnMapping'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



387
388
389
# File 'lib/lob/models/upload.rb', line 387

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



139
140
141
142
143
# File 'lib/lob/models/upload.rb', line 139

def self.openapi_nullable
  Set.new([
    :'merge_variable_column_mapping'
  ])
end

.openapi_typesObject

Attribute type mapping.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/lob/models/upload.rb', line 116

def self.openapi_types
  {
    :'id' => :'String',
    :'account_id' => :'String',
    :'mode' => :'String',
    :'campaign_id' => :'String',
    :'failures_url' => :'String',
    :'original_filename' => :'String',
    :'state' => :'UploadState',
    :'total_mailpieces' => :'Integer',
    :'failed_mailpieces' => :'Integer',
    :'validated_mailpieces' => :'Integer',
    :'bytes_processed' => :'Integer',
    :'date_created' => :'Time',
    :'date_modified' => :'Time',
    :'required_address_column_mapping' => :'RequiredAddressColumnMapping',
    :'optional_address_column_mapping' => :'OptionalAddressColumnMapping',
    :'metadata' => :'UploadsMetadata',
    :'merge_variable_column_mapping' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/lob/models/upload.rb', line 349

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
       == o. &&
      mode == o.mode &&
      campaign_id == o.campaign_id &&
      failures_url == o.failures_url &&
      original_filename == o.original_filename &&
      state == o.state &&
      total_mailpieces == o.total_mailpieces &&
      failed_mailpieces == o.failed_mailpieces &&
      validated_mailpieces == o.validated_mailpieces &&
      bytes_processed == o.bytes_processed &&
      date_created == o.date_created &&
      date_modified == o.date_modified &&
      required_address_column_mapping == o.required_address_column_mapping &&
      optional_address_column_mapping == o.optional_address_column_mapping &&
       == o. &&
      merge_variable_column_mapping == o.merge_variable_column_mapping
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
# File 'lib/lob/models/upload.rb', line 426

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



497
498
499
500
501
502
503
504
505
506
507
508
509
# File 'lib/lob/models/upload.rb', line 497

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/lob/models/upload.rb', line 394

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


373
374
375
# File 'lib/lob/models/upload.rb', line 373

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



379
380
381
# File 'lib/lob/models/upload.rb', line 379

def hash
  [id, , mode, campaign_id, failures_url, original_filename, state, total_mailpieces, failed_mailpieces, validated_mailpieces, bytes_processed, date_created, date_modified, required_address_column_mapping, optional_address_column_mapping, , merge_variable_column_mapping].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/lob/models/upload.rb', line 233

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  pattern = Regexp.new(/^upl_[a-zA-Z0-9]+$/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @mode.nil?
    invalid_properties.push('invalid value for "mode", mode cannot be nil.')
  end

  if @campaign_id.nil?
    invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if @total_mailpieces.nil?
    invalid_properties.push('invalid value for "total_mailpieces", total_mailpieces cannot be nil.')
  end

  if @failed_mailpieces.nil?
    invalid_properties.push('invalid value for "failed_mailpieces", failed_mailpieces cannot be nil.')
  end

  if @validated_mailpieces.nil?
    invalid_properties.push('invalid value for "validated_mailpieces", validated_mailpieces cannot be nil.')
  end

  if @bytes_processed.nil?
    invalid_properties.push('invalid value for "bytes_processed", bytes_processed cannot be nil.')
  end

  if @date_created.nil?
    invalid_properties.push('invalid value for "date_created", date_created cannot be nil.')
  end

  if @date_modified.nil?
    invalid_properties.push('invalid value for "date_modified", date_modified cannot be nil.')
  end

  if @required_address_column_mapping.nil?
    invalid_properties.push('invalid value for "required_address_column_mapping", required_address_column_mapping cannot be nil.')
  end

  if @optional_address_column_mapping.nil?
    invalid_properties.push('invalid value for "optional_address_column_mapping", optional_address_column_mapping cannot be nil.')
  end

  if @metadata.nil?
    invalid_properties.push('invalid value for "metadata", metadata cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



473
474
475
# File 'lib/lob/models/upload.rb', line 473

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



479
480
481
482
483
484
485
486
487
488
489
490
491
# File 'lib/lob/models/upload.rb', line 479

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



467
468
469
# File 'lib/lob/models/upload.rb', line 467

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/lob/models/upload.rb', line 301

def valid?
  return false if @id.nil?
  return false if @id !~ Regexp.new(/^upl_[a-zA-Z0-9]+$/)
  return false if @account_id.nil?
  return false if @mode.nil?
  mode_validator = EnumAttributeValidator.new('String', ["test", "live"])
  return false unless mode_validator.valid?(@mode)
  return false if @campaign_id.nil?
  return false if @state.nil?
  return false if @total_mailpieces.nil?
  return false if @failed_mailpieces.nil?
  return false if @validated_mailpieces.nil?
  return false if @bytes_processed.nil?
  return false if @date_created.nil?
  return false if @date_modified.nil?
  return false if @required_address_column_mapping.nil?
  return false if @optional_address_column_mapping.nil?
  return false if @metadata.nil?
  true
end