Class: Lob::UploadUpdatable

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/upload_updatable.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UploadUpdatable

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/lob/models/upload_updatable.rb', line 66

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::UploadUpdatable` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::UploadUpdatable`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'original_filename')
    self.original_filename = attributes[:'original_filename']
  end

  if attributes.key?(:'required_address_column_mapping')
    self.required_address_column_mapping = attributes[:'required_address_column_mapping']
  end

  if attributes.key?(:'optional_address_column_mapping')
    self.optional_address_column_mapping = attributes[:'optional_address_column_mapping']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'merge_variable_column_mapping')
    self.merge_variable_column_mapping = attributes[:'merge_variable_column_mapping']
  end
end

Instance Attribute Details

#merge_variable_column_mappingObject

The mapping of column headers in your file to the merge variables present in your creative. See our <a href="help.lob.com/print-and-mail/building-a-mail-strategy/campaign-or-triggered-sends/campaign-audience-guide#step-3-map-merge-variable-data-if-applicable-7" target="_blank">Campaign Audience Guide</a> for additional details. <br />If a merge variable has the same "name" as a "key" in the ‘requiredAddressColumnMapping` or `optionalAddressColumnMapping` objects, then they CANNOT have a different value in this object. If a different value is provided, then when the campaign is processing it will get overwritten with the mapped value present in the `requiredAddressColumnMapping` or `optionalAddressColumnMapping` objects.



28
29
30
# File 'lib/lob/models/upload_updatable.rb', line 28

def merge_variable_column_mapping
  @merge_variable_column_mapping
end

#metadataObject

Returns the value of attribute metadata.



25
26
27
# File 'lib/lob/models/upload_updatable.rb', line 25

def 
  @metadata
end

#optional_address_column_mappingObject

Returns the value of attribute optional_address_column_mapping.



23
24
25
# File 'lib/lob/models/upload_updatable.rb', line 23

def optional_address_column_mapping
  @optional_address_column_mapping
end

#original_filenameObject

Original filename provided when the upload is created.



19
20
21
# File 'lib/lob/models/upload_updatable.rb', line 19

def original_filename
  @original_filename
end

#required_address_column_mappingObject

Returns the value of attribute required_address_column_mapping.



21
22
23
# File 'lib/lob/models/upload_updatable.rb', line 21

def required_address_column_mapping
  @required_address_column_mapping
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/lob/models/upload_updatable.rb', line 42

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
# File 'lib/lob/models/upload_updatable.rb', line 31

def self.attribute_map
  {
    :'original_filename' => :'originalFilename',
    :'required_address_column_mapping' => :'requiredAddressColumnMapping',
    :'optional_address_column_mapping' => :'optionalAddressColumnMapping',
    :'metadata' => :'metadata',
    :'merge_variable_column_mapping' => :'mergeVariableColumnMapping'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



141
142
143
# File 'lib/lob/models/upload_updatable.rb', line 141

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



58
59
60
61
62
# File 'lib/lob/models/upload_updatable.rb', line 58

def self.openapi_nullable
  Set.new([
    :'merge_variable_column_mapping'
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
55
# File 'lib/lob/models/upload_updatable.rb', line 47

def self.openapi_types
  {
    :'original_filename' => :'String',
    :'required_address_column_mapping' => :'RequiredAddressColumnMapping',
    :'optional_address_column_mapping' => :'OptionalAddressColumnMapping',
    :'metadata' => :'UploadsMetadata',
    :'merge_variable_column_mapping' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



115
116
117
118
119
120
121
122
123
# File 'lib/lob/models/upload_updatable.rb', line 115

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      original_filename == o.original_filename &&
      required_address_column_mapping == o.required_address_column_mapping &&
      optional_address_column_mapping == o.optional_address_column_mapping &&
       == o. &&
      merge_variable_column_mapping == o.merge_variable_column_mapping
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/lob/models/upload_updatable.rb', line 180

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/lob/models/upload_updatable.rb', line 251

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/lob/models/upload_updatable.rb', line 148

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


127
128
129
# File 'lib/lob/models/upload_updatable.rb', line 127

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



133
134
135
# File 'lib/lob/models/upload_updatable.rb', line 133

def hash
  [original_filename, required_address_column_mapping, optional_address_column_mapping, , merge_variable_column_mapping].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



102
103
104
105
# File 'lib/lob/models/upload_updatable.rb', line 102

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



227
228
229
# File 'lib/lob/models/upload_updatable.rb', line 227

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/lob/models/upload_updatable.rb', line 233

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



221
222
223
# File 'lib/lob/models/upload_updatable.rb', line 221

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



109
110
111
# File 'lib/lob/models/upload_updatable.rb', line 109

def valid?
  true
end