Class: Lob::UsAddress

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/models/us_address.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UsAddress

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/lob/models/us_address.rb', line 163

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::UsAddress` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::UsAddress`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'company')
    self.company = attributes[:'company']
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'address_line1')
    self.address_line1 = attributes[:'address_line1']
  end

  if attributes.key?(:'address_line2')
    self.address_line2 = attributes[:'address_line2']
  end

  if attributes.key?(:'address_city')
    self.address_city = attributes[:'address_city']
  end

  if attributes.key?(:'address_state')
    self.address_state = attributes[:'address_state']
  end

  if attributes.key?(:'address_zip')
    self.address_zip = attributes[:'address_zip']
  end

  if attributes.key?(:'address_country')
    self.address_country = attributes[:'address_country']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = 'address'
  end

  if attributes.key?(:'date_created')
    self.date_created = attributes[:'date_created']
  end

  if attributes.key?(:'date_modified')
    self.date_modified = attributes[:'date_modified']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end

  if attributes.key?(:'inline')
    self.inline = attributes[:'inline']
  end

  if attributes.key?(:'recipient_moved')
    self.recipient_moved = attributes[:'recipient_moved']
  end
end

Instance Attribute Details

#address_cityObject

Returns the value of attribute address_city.



43
44
45
# File 'lib/lob/models/us_address.rb', line 43

def address_city
  @address_city
end

#address_countryObject

Full name of country



52
53
54
# File 'lib/lob/models/us_address.rb', line 52

def address_country
  @address_country
end

#address_line1Object

Returns the value of attribute address_line1.



39
40
41
# File 'lib/lob/models/us_address.rb', line 39

def address_line1
  @address_line1
end

#address_line2Object

Returns the value of attribute address_line2.



41
42
43
# File 'lib/lob/models/us_address.rb', line 41

def address_line2
  @address_line2
end

#address_stateObject

2 letter state short-name code



46
47
48
# File 'lib/lob/models/us_address.rb', line 46

def address_state
  @address_state
end

#address_zipObject

Must follow the ZIP format of ‘12345` or ZIP+4 format of `12345-1234`.



49
50
51
# File 'lib/lob/models/us_address.rb', line 49

def address_zip
  @address_zip
end

#companyObject

Either ‘name` or `company` is required, you may also add both.



28
29
30
# File 'lib/lob/models/us_address.rb', line 28

def company
  @company
end

#date_createdObject

A timestamp in ISO 8601 format of the date the resource was created.



57
58
59
# File 'lib/lob/models/us_address.rb', line 57

def date_created
  @date_created
end

#date_modifiedObject

A timestamp in ISO 8601 format of the date the resource was last modified.



60
61
62
# File 'lib/lob/models/us_address.rb', line 60

def date_modified
  @date_modified
end

#deletedObject

Only returned if the resource has been successfully deleted.



63
64
65
# File 'lib/lob/models/us_address.rb', line 63

def deleted
  @deleted
end

#descriptionObject

An internal description that identifies this resource. Must be no longer than 255 characters.



22
23
24
# File 'lib/lob/models/us_address.rb', line 22

def description
  @description
end

#emailObject

Must be no longer than 100 characters.



34
35
36
# File 'lib/lob/models/us_address.rb', line 34

def email
  @email
end

#idObject

Unique identifier prefixed with ‘adr_`.



19
20
21
# File 'lib/lob/models/us_address.rb', line 19

def id
  @id
end

#inlineObject

Checks if address id is used or not



66
67
68
# File 'lib/lob/models/us_address.rb', line 66

def inline
  @inline
end

#metadataObject

Use metadata to store custom information for tagging and labeling back to your internal systems. Must be an object with up to 20 key-value pairs. Keys must be at most 40 characters and values must be at most 500 characters. Neither can contain the characters ‘"` and `\`. i.e. ’: "NEWYORK2015"‘ Nested objects are not supported. See [Metadata](#section/Metadata) for more information.



37
38
39
# File 'lib/lob/models/us_address.rb', line 37

def 
  @metadata
end

#nameObject

name associated with address



25
26
27
# File 'lib/lob/models/us_address.rb', line 25

def name
  @name
end

#objectObject

Returns the value of attribute object.



54
55
56
# File 'lib/lob/models/us_address.rb', line 54

def object
  @object
end

#phoneObject

Must be no longer than 40 characters.



31
32
33
# File 'lib/lob/models/us_address.rb', line 31

def phone
  @phone
end

#recipient_movedObject

Only returned for accounts on certain <a href="dashboard.lob.com/#/settings/editions">Print &amp; Mail Editions</a>. Value is ‘true` if the address was altered because the recipient filed for a <a href="#ncoa">National Change of Address (NCOA)</a>, `false` if the NCOA check was run but no altered address was found, and `null` if the NCOA check was not run. The NCOA check does not happen for non-US addresses, for non-deliverable US addresses, or for addresses created before the NCOA feature was added to your account.



69
70
71
# File 'lib/lob/models/us_address.rb', line 69

def recipient_moved
  @recipient_moved
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



119
120
121
# File 'lib/lob/models/us_address.rb', line 119

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/lob/models/us_address.rb', line 94

def self.attribute_map
  {
    :'id' => :'id',
    :'description' => :'description',
    :'name' => :'name',
    :'company' => :'company',
    :'phone' => :'phone',
    :'email' => :'email',
    :'metadata' => :'metadata',
    :'address_line1' => :'address_line1',
    :'address_line2' => :'address_line2',
    :'address_city' => :'address_city',
    :'address_state' => :'address_state',
    :'address_zip' => :'address_zip',
    :'address_country' => :'address_country',
    :'object' => :'object',
    :'date_created' => :'date_created',
    :'date_modified' => :'date_modified',
    :'deleted' => :'deleted',
    :'inline' => :'inline',
    :'recipient_moved' => :'recipient_moved'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



518
519
520
# File 'lib/lob/models/us_address.rb', line 518

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



149
150
151
152
153
154
155
156
157
158
159
# File 'lib/lob/models/us_address.rb', line 149

def self.openapi_nullable
  Set.new([
    :'description',
    :'name',
    :'company',
    :'phone',
    :'email',
    :'address_line2',
    :'recipient_moved'
  ])
end

.openapi_typesObject

Attribute type mapping.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/lob/models/us_address.rb', line 124

def self.openapi_types
  {
    :'id' => :'String',
    :'description' => :'String',
    :'name' => :'String',
    :'company' => :'String',
    :'phone' => :'String',
    :'email' => :'String',
    :'metadata' => :'Hash<String, String>',
    :'address_line1' => :'String',
    :'address_line2' => :'String',
    :'address_city' => :'String',
    :'address_state' => :'String',
    :'address_zip' => :'String',
    :'address_country' => :'String',
    :'object' => :'String',
    :'date_created' => :'Time',
    :'date_modified' => :'Time',
    :'deleted' => :'Boolean',
    :'inline' => :'Boolean',
    :'recipient_moved' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/lob/models/us_address.rb', line 478

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      description == o.description &&
      name == o.name &&
      company == o.company &&
      phone == o.phone &&
      email == o.email &&
       == o. &&
      address_line1 == o.address_line1 &&
      address_line2 == o.address_line2 &&
      address_city == o.address_city &&
      address_state == o.address_state &&
      address_zip == o.address_zip &&
      address_country == o.address_country &&
      object == o.object &&
      date_created == o.date_created &&
      date_modified == o.date_modified &&
      deleted == o.deleted &&
      inline == o.inline &&
      recipient_moved == o.recipient_moved
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
# File 'lib/lob/models/us_address.rb', line 557

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Lob.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



628
629
630
631
632
633
634
635
636
637
638
639
640
# File 'lib/lob/models/us_address.rb', line 628

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
# File 'lib/lob/models/us_address.rb', line 525

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil) # // guardrails-disable-line
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line
      end
    elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array)
      for base_type in type do
        res = _deserialize(base_type, attributes[self.class.attribute_map[key]])
        if !res.nil?
          self.send("#{key}=", res) # // guardrails-disable-line
          break
        end
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


504
505
506
# File 'lib/lob/models/us_address.rb', line 504

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



510
511
512
# File 'lib/lob/models/us_address.rb', line 510

def hash
  [id, description, name, company, phone, email, , address_line1, address_line2, address_city, address_state, address_zip, address_country, object, date_created, date_modified, deleted, inline, recipient_moved].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/lob/models/us_address.rb', line 259

def list_invalid_properties
  invalid_properties = Array.new
  pattern = Regexp.new(/^adr_[a-zA-Z0-9]+$/)
  if !@id.nil? && @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if !@description.nil? && @description.to_s.length > 255
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.')
  end

  if !@name.nil? && @name.to_s.length > 40
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 40.')
  end

  if !@company.nil? && @company.to_s.length > 40
    invalid_properties.push('invalid value for "company", the character length must be smaller than or equal to 40.')
  end

  if !@phone.nil? && @phone.to_s.length > 40
    invalid_properties.push('invalid value for "phone", the character length must be smaller than or equal to 40.')
  end

  if !@email.nil? && @email.to_s.length > 100
    invalid_properties.push('invalid value for "email", the character length must be smaller than or equal to 100.')
  end

  if !@address_line1.nil? && @address_line1.to_s.length > 64
    invalid_properties.push('invalid value for "address_line1", the character length must be smaller than or equal to 64.')
  end

  if !@address_line2.nil? && @address_line2.to_s.length > 64
    invalid_properties.push('invalid value for "address_line2", the character length must be smaller than or equal to 64.')
  end

  if !@address_city.nil? && @address_city.to_s.length > 200
    invalid_properties.push('invalid value for "address_city", the character length must be smaller than or equal to 200.')
  end

  pattern = Regexp.new(/^[a-zA-Z]{2}$/)
  if !@address_state.nil? && @address_state !~ pattern
    invalid_properties.push("invalid value for \"address_state\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^\d{5}(-\d{4})?$/)
  if !@address_zip.nil? && @address_zip !~ pattern
    invalid_properties.push("invalid value for \"address_zip\", must conform to the pattern #{pattern}.")
  end

  if !@address_country.nil? && @address_country.to_s.length > 200
    invalid_properties.push('invalid value for "address_country", the character length must be smaller than or equal to 200.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



604
605
606
# File 'lib/lob/models/us_address.rb', line 604

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



610
611
612
613
614
615
616
617
618
619
620
621
622
# File 'lib/lob/models/us_address.rb', line 610

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr) # // guardrails-disable-line
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



598
599
600
# File 'lib/lob/models/us_address.rb', line 598

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/lob/models/us_address.rb', line 317

def valid?
  return false if !@id.nil? && @id !~ Regexp.new(/^adr_[a-zA-Z0-9]+$/)
  return false if !@description.nil? && @description.to_s.length > 255
  return false if !@name.nil? && @name.to_s.length > 40
  return false if !@company.nil? && @company.to_s.length > 40
  return false if !@phone.nil? && @phone.to_s.length > 40
  return false if !@email.nil? && @email.to_s.length > 100
  return false if !@address_line1.nil? && @address_line1.to_s.length > 64
  return false if !@address_line2.nil? && @address_line2.to_s.length > 64
  return false if !@address_city.nil? && @address_city.to_s.length > 200
  return false if !@address_state.nil? && @address_state !~ Regexp.new(/^[a-zA-Z]{2}$/)
  return false if !@address_zip.nil? && @address_zip !~ Regexp.new(/^\d{5}(-\d{4})?$/)
  address_country_validator = EnumAttributeValidator.new('String', ["UNITED STATES"])
  return false unless address_country_validator.valid?(@address_country)
  return false if !@address_country.nil? && @address_country.to_s.length > 200
  object_validator = EnumAttributeValidator.new('String', ["address"])
  return false unless object_validator.valid?(@object)
  true
end