Class: Lob::UsAutocompletionsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/lob/api/us_autocompletions_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ UsAutocompletionsApi

Returns a new instance of UsAutocompletionsApi.



19
20
21
# File 'lib/lob/api/us_autocompletions_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/lob/api/us_autocompletions_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#autocomplete(us_autocompletions_writable, opts = {}) ⇒ UsAutocompletions

autocomplete Given an address prefix consisting of a partial primary line, as well as optional input of city, state, and zip code, this functionality returns up to 10 full US address suggestions. Not all of them will turn out to be valid addresses; they’ll need to be [verified](#operation/verification_us).

Parameters:

Returns:



27
28
29
30
# File 'lib/lob/api/us_autocompletions_api.rb', line 27

def autocomplete(us_autocompletions_writable, opts = {})
  data, _status_code, _headers = us_autocompletion_with_http_info(us_autocompletions_writable, opts)
  data
end

#us_autocompletion_with_http_info(us_autocompletions_writable, opts = {}) ⇒ Array<(UsAutocompletions, Integer, Hash)>

autocomplete Given an address prefix consisting of a partial primary line, as well as optional input of city, state, and zip code, this functionality returns up to 10 full US address suggestions. Not all of them will turn out to be valid addresses; they&#39;ll need to be [verified](#operation/verification_us).

Parameters:

Returns:

  • (Array<(UsAutocompletions, Integer, Hash)>)

    UsAutocompletions data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/lob/api/us_autocompletions_api.rb', line 37

def us_autocompletion_with_http_info(us_autocompletions_writable, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsAutocompletionsApi.us_autocompletion ...'
  end
  # verify the required parameter 'us_autocompletions_writable' is set
  if @api_client.config.client_side_validation && us_autocompletions_writable.nil?
    fail ArgumentError, "Missing the required parameter 'us_autocompletions_writable' when calling UsAutocompletionsApi.us_autocompletion"
  end
  # resource path
  local_var_path = '/us_autocompletions'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(us_autocompletions_writable)

  # return_type
  return_type = opts[:debug_return_type] || 'UsAutocompletions'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"UsAutocompletionsApi.us_autocompletion",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsAutocompletionsApi#us_autocompletion\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end