Class: Lob::Zip
- Inherits:
-
Object
- Object
- Lob::Zip
- Defined in:
- lib/lob/models/zip.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#cities ⇒ Object
An array of city objects containing valid cities for the ‘zip_code`.
-
#id ⇒ Object
Unique identifier prefixed with ‘us_zip_`.
-
#object ⇒ Object
Returns the value of attribute object.
-
#zip_code ⇒ Object
A 5-digit ZIP code.
-
#zip_code_type ⇒ Object
Returns the value of attribute zip_code_type.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Zip
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Zip
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/lob/models/zip.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::Zip` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::Zip`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'zip_code') self.zip_code = attributes[:'zip_code'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'cities') if (value = attributes[:'cities']).is_a?(Array) self.cities = value end end if attributes.key?(:'zip_code_type') self.zip_code_type = attributes[:'zip_code_type'] end if attributes.key?(:'object') self.object = attributes[:'object'] else self.object = 'us_zip_lookup' end end |
Instance Attribute Details
#cities ⇒ Object
An array of city objects containing valid cities for the ‘zip_code`. Multiple cities will be returned if more than one city is associated with the input ZIP code.
25 26 27 |
# File 'lib/lob/models/zip.rb', line 25 def cities @cities end |
#id ⇒ Object
Unique identifier prefixed with ‘us_zip_`.
22 23 24 |
# File 'lib/lob/models/zip.rb', line 22 def id @id end |
#object ⇒ Object
Returns the value of attribute object.
29 30 31 |
# File 'lib/lob/models/zip.rb', line 29 def object @object end |
#zip_code ⇒ Object
A 5-digit ZIP code.
19 20 21 |
# File 'lib/lob/models/zip.rb', line 19 def zip_code @zip_code end |
#zip_code_type ⇒ Object
Returns the value of attribute zip_code_type.
27 28 29 |
# File 'lib/lob/models/zip.rb', line 27 def zip_code_type @zip_code_type end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/lob/models/zip.rb', line 65 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 |
# File 'lib/lob/models/zip.rb', line 54 def self.attribute_map { :'zip_code' => :'zip_code', :'id' => :'id', :'cities' => :'cities', :'zip_code_type' => :'zip_code_type', :'object' => :'object' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
237 238 239 |
# File 'lib/lob/models/zip.rb', line 237 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/lob/models/zip.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 |
# File 'lib/lob/models/zip.rb', line 70 def self.openapi_types { :'zip_code' => :'String', :'id' => :'String', :'cities' => :'Array<ZipLookupCity>', :'zip_code_type' => :'ZipCodeType', :'object' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
211 212 213 214 215 216 217 218 219 |
# File 'lib/lob/models/zip.rb', line 211 def ==(o) return true if self.equal?(o) self.class == o.class && zip_code == o.zip_code && id == o.id && cities == o.cities && zip_code_type == o.zip_code_type && object == o.object end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/lob/models/zip.rb', line 276 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Lob.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/lob/models/zip.rb', line 347 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/lob/models/zip.rb', line 244 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) # // guardrails-disable-line elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line end elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array) for base_type in type do res = _deserialize(base_type, attributes[self.class.attribute_map[key]]) if !res.nil? self.send("#{key}=", res) # // guardrails-disable-line break end end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line end end self end |
#eql?(o) ⇒ Boolean
223 224 225 |
# File 'lib/lob/models/zip.rb', line 223 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
229 230 231 |
# File 'lib/lob/models/zip.rb', line 229 def hash [zip_code, id, cities, zip_code_type, object].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/lob/models/zip.rb', line 128 def list_invalid_properties invalid_properties = Array.new pattern = Regexp.new(/^\d{5}$/) if !@zip_code.nil? && @zip_code !~ pattern invalid_properties.push("invalid value for \"zip_code\", must conform to the pattern #{pattern}.") end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end pattern = Regexp.new(/^us_zip_[a-zA-Z0-9]+$/) if @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end if @cities.nil? invalid_properties.push('invalid value for "cities", cities cannot be nil.') end if @zip_code_type.nil? invalid_properties.push('invalid value for "zip_code_type", zip_code_type cannot be nil.') end if @object.nil? invalid_properties.push('invalid value for "object", object cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
323 324 325 |
# File 'lib/lob/models/zip.rb', line 323 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/lob/models/zip.rb', line 329 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) # // guardrails-disable-line if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
317 318 319 |
# File 'lib/lob/models/zip.rb', line 317 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/lob/models/zip.rb', line 161 def valid? return false if !@zip_code.nil? && @zip_code !~ Regexp.new(/^\d{5}$/) return false if @id.nil? return false if @id !~ Regexp.new(/^us_zip_[a-zA-Z0-9]+$/) return false if @cities.nil? return false if @zip_code_type.nil? return false if @object.nil? object_validator = EnumAttributeValidator.new('String', ["us_zip_lookup"]) return false unless object_validator.valid?(@object) true end |