Class: Lob::AddressesApi
- Inherits:
-
Object
- Object
- Lob::AddressesApi
- Defined in:
- lib/lob/api/addresses_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#address_create_with_http_info(address_editable, opts = {}) ⇒ Array<(Address, Integer, Hash)>
create Creates a new address given information.
-
#address_delete_with_http_info(adr_id, opts = {}) ⇒ Array<(AddressDeletion, Integer, Hash)>
delete Deletes the details of an existing address.
-
#address_retrieve_with_http_info(adr_id, opts = {}) ⇒ Array<(Address, Integer, Hash)>
get Retrieves the details of an existing address.
-
#addresses_list_with_http_info(opts = {}) ⇒ Array<(AddressList, Integer, Hash)>
list Returns a list of your addresses.
-
#create(address_editable, opts = {}) ⇒ Address
create Creates a new address given information.
-
#delete(adr_id, opts = {}) ⇒ AddressDeletion
delete Deletes the details of an existing address.
-
#get(adr_id, opts = {}) ⇒ Address
get Retrieves the details of an existing address.
-
#initialize(api_client = ApiClient.default) ⇒ AddressesApi
constructor
A new instance of AddressesApi.
-
#list(opts = {}) ⇒ AddressList
list Returns a list of your addresses.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AddressesApi
Returns a new instance of AddressesApi.
19 20 21 |
# File 'lib/lob/api/addresses_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/lob/api/addresses_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#address_create_with_http_info(address_editable, opts = {}) ⇒ Array<(Address, Integer, Hash)>
create Creates a new address given information
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/lob/api/addresses_api.rb', line 37 def address_create_with_http_info(address_editable, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AddressesApi.address_create ...' end # verify the required parameter 'address_editable' is set if @api_client.config.client_side_validation && address_editable.nil? fail ArgumentError, "Missing the required parameter 'address_editable' when calling AddressesApi.address_create" end # resource path local_var_path = '/addresses' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(address_editable) # return_type return_type = opts[:debug_return_type] || 'Address' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"AddressesApi.address_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AddressesApi#address_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#address_delete_with_http_info(adr_id, opts = {}) ⇒ Array<(AddressDeletion, Integer, Hash)>
delete Deletes the details of an existing address.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/lob/api/addresses_api.rb', line 105 def address_delete_with_http_info(adr_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AddressesApi.address_delete ...' end # verify the required parameter 'adr_id' is set if @api_client.config.client_side_validation && adr_id.nil? fail ArgumentError, "Missing the required parameter 'adr_id' when calling AddressesApi.address_delete" end pattern = Regexp.new(/^adr_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && adr_id !~ pattern fail ArgumentError, "invalid value for 'adr_id' when calling AddressesApi.address_delete, must conform to the pattern #{pattern}." end # resource path local_var_path = '/addresses/{adr_id}'.sub('{' + 'adr_id' + '}', CGI.escape(adr_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AddressDeletion' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"AddressesApi.address_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AddressesApi#address_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#address_retrieve_with_http_info(adr_id, opts = {}) ⇒ Array<(Address, Integer, Hash)>
get Retrieves the details of an existing address.
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/lob/api/addresses_api.rb', line 173 def address_retrieve_with_http_info(adr_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AddressesApi.address_retrieve ...' end # verify the required parameter 'adr_id' is set if @api_client.config.client_side_validation && adr_id.nil? fail ArgumentError, "Missing the required parameter 'adr_id' when calling AddressesApi.address_retrieve" end pattern = Regexp.new(/^adr_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && adr_id !~ pattern fail ArgumentError, "invalid value for 'adr_id' when calling AddressesApi.address_retrieve, must conform to the pattern #{pattern}." end # resource path local_var_path = '/addresses/{adr_id}'.sub('{' + 'adr_id' + '}', CGI.escape(adr_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Address' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"AddressesApi.address_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AddressesApi#address_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#addresses_list_with_http_info(opts = {}) ⇒ Array<(AddressList, Integer, Hash)>
list Returns a list of your addresses.
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/lob/api/addresses_api.rb', line 251 def addresses_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AddressesApi.addresses_list ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling AddressesApi.addresses_list, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling AddressesApi.addresses_list, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'metadata'].nil? && opts[:'metadata'].to_s.length > 500 fail ArgumentError, 'invalid value for "opts[:"metadata"]" when calling AddressesApi.addresses_list, the character length must be smaller than or equal to 500.' end pattern = Regexp.new(/[^"\\]{0,500}/) if @api_client.config.client_side_validation && !opts[:'metadata'].nil? && opts[:'metadata'] !~ pattern fail ArgumentError, "invalid value for 'opts[:\"metadata\"]' when calling AddressesApi.addresses_list, must conform to the pattern #{pattern}." end # resource path local_var_path = '/addresses' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'before'] = opts[:'before'] if !opts[:'before'].nil? query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil? query_params[:'include'] = @api_client.build_collection_param(opts[:'include'], :multi) if !opts[:'include'].nil? query_params[:'date_created'] = opts[:'date_created'] if !opts[:'date_created'].nil? query_params[:'metadata'] = opts[:'metadata'] if !opts[:'metadata'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AddressList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"AddressesApi.addresses_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AddressesApi#addresses_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create(address_editable, opts = {}) ⇒ Address
create Creates a new address given information
27 28 29 30 |
# File 'lib/lob/api/addresses_api.rb', line 27 def create(address_editable, opts = {}) data, _status_code, _headers = address_create_with_http_info(address_editable, opts) data end |
#delete(adr_id, opts = {}) ⇒ AddressDeletion
delete Deletes the details of an existing address.
95 96 97 98 |
# File 'lib/lob/api/addresses_api.rb', line 95 def delete(adr_id, opts = {}) data, _status_code, _headers = address_delete_with_http_info(adr_id, opts) data end |
#get(adr_id, opts = {}) ⇒ Address
get Retrieves the details of an existing address.
163 164 165 166 |
# File 'lib/lob/api/addresses_api.rb', line 163 def get(adr_id, opts = {}) data, _status_code, _headers = address_retrieve_with_http_info(adr_id, opts) data end |
#list(opts = {}) ⇒ AddressList
list Returns a list of your addresses.
236 237 238 239 |
# File 'lib/lob/api/addresses_api.rb', line 236 def list(opts = {}) data, _status_code, _headers = addresses_list_with_http_info(opts) data end |