Class: Lob::BankAccountsApi
- Inherits:
-
Object
- Object
- Lob::BankAccountsApi
- Defined in:
- lib/lob/api/bank_accounts_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#bank_account_create_with_http_info(bank_account_writable, opts = {}) ⇒ Array<(BankAccount, Integer, Hash)>
create Creates a new bank account with the provided properties.
-
#bank_account_delete_with_http_info(bank_id, opts = {}) ⇒ Array<(BankAccountDeletion, Integer, Hash)>
delete Permanently deletes a bank account.
-
#bank_account_retrieve_with_http_info(bank_id, opts = {}) ⇒ Array<(BankAccount, Integer, Hash)>
get Retrieves the details of an existing bank account.
-
#bank_account_verify_with_http_info(bank_id, bank_account_verify, opts = {}) ⇒ Array<(BankAccount, Integer, Hash)>
verify Verify a bank account in order to create a check.
-
#bank_accounts_list_with_http_info(opts = {}) ⇒ Array<(BankAccountList, Integer, Hash)>
list Returns a list of your bank accounts.
-
#create(bank_account_writable, opts = {}) ⇒ BankAccount
create Creates a new bank account with the provided properties.
-
#delete(bank_id, opts = {}) ⇒ BankAccountDeletion
delete Permanently deletes a bank account.
-
#get(bank_id, opts = {}) ⇒ BankAccount
get Retrieves the details of an existing bank account.
-
#initialize(api_client = ApiClient.default) ⇒ BankAccountsApi
constructor
A new instance of BankAccountsApi.
-
#list(opts = {}) ⇒ BankAccountList
list Returns a list of your bank accounts.
-
#verify(bank_id, bank_account_verify, opts = {}) ⇒ BankAccount
verify Verify a bank account in order to create a check.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ BankAccountsApi
Returns a new instance of BankAccountsApi.
19 20 21 |
# File 'lib/lob/api/bank_accounts_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/lob/api/bank_accounts_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#bank_account_create_with_http_info(bank_account_writable, opts = {}) ⇒ Array<(BankAccount, Integer, Hash)>
create Creates a new bank account with the provided properties. Bank accounts created in live mode will need to be verified via micro deposits before being able to send live checks. The deposits will appear in the bank account in 2-3 business days and have the description "VERIFICATION".
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/lob/api/bank_accounts_api.rb', line 37 def bank_account_create_with_http_info(bank_account_writable, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BankAccountsApi.bank_account_create ...' end # verify the required parameter 'bank_account_writable' is set if @api_client.config.client_side_validation && bank_account_writable.nil? fail ArgumentError, "Missing the required parameter 'bank_account_writable' when calling BankAccountsApi.bank_account_create" end # resource path local_var_path = '/bank_accounts' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(bank_account_writable) # return_type return_type = opts[:debug_return_type] || 'BankAccount' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"BankAccountsApi.bank_account_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BankAccountsApi#bank_account_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#bank_account_delete_with_http_info(bank_id, opts = {}) ⇒ Array<(BankAccountDeletion, Integer, Hash)>
delete Permanently deletes a bank account. It cannot be undone.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/lob/api/bank_accounts_api.rb', line 105 def bank_account_delete_with_http_info(bank_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BankAccountsApi.bank_account_delete ...' end # verify the required parameter 'bank_id' is set if @api_client.config.client_side_validation && bank_id.nil? fail ArgumentError, "Missing the required parameter 'bank_id' when calling BankAccountsApi.bank_account_delete" end pattern = Regexp.new(/^bank_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && bank_id !~ pattern fail ArgumentError, "invalid value for 'bank_id' when calling BankAccountsApi.bank_account_delete, must conform to the pattern #{pattern}." end # resource path local_var_path = '/bank_accounts/{bank_id}'.sub('{' + 'bank_id' + '}', CGI.escape(bank_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'BankAccountDeletion' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"BankAccountsApi.bank_account_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BankAccountsApi#bank_account_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#bank_account_retrieve_with_http_info(bank_id, opts = {}) ⇒ Array<(BankAccount, Integer, Hash)>
get Retrieves the details of an existing bank account. You need only supply the unique bank account identifier that was returned upon bank account creation.
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/lob/api/bank_accounts_api.rb', line 173 def bank_account_retrieve_with_http_info(bank_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BankAccountsApi.bank_account_retrieve ...' end # verify the required parameter 'bank_id' is set if @api_client.config.client_side_validation && bank_id.nil? fail ArgumentError, "Missing the required parameter 'bank_id' when calling BankAccountsApi.bank_account_retrieve" end pattern = Regexp.new(/^bank_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && bank_id !~ pattern fail ArgumentError, "invalid value for 'bank_id' when calling BankAccountsApi.bank_account_retrieve, must conform to the pattern #{pattern}." end # resource path local_var_path = '/bank_accounts/{bank_id}'.sub('{' + 'bank_id' + '}', CGI.escape(bank_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'BankAccount' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"BankAccountsApi.bank_account_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BankAccountsApi#bank_account_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#bank_account_verify_with_http_info(bank_id, bank_account_verify, opts = {}) ⇒ Array<(BankAccount, Integer, Hash)>
verify Verify a bank account in order to create a check.
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/lob/api/bank_accounts_api.rb', line 243 def bank_account_verify_with_http_info(bank_id, bank_account_verify, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BankAccountsApi.bank_account_verify ...' end # verify the required parameter 'bank_id' is set if @api_client.config.client_side_validation && bank_id.nil? fail ArgumentError, "Missing the required parameter 'bank_id' when calling BankAccountsApi.bank_account_verify" end pattern = Regexp.new(/^bank_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && bank_id !~ pattern fail ArgumentError, "invalid value for 'bank_id' when calling BankAccountsApi.bank_account_verify, must conform to the pattern #{pattern}." end # verify the required parameter 'bank_account_verify' is set if @api_client.config.client_side_validation && bank_account_verify.nil? fail ArgumentError, "Missing the required parameter 'bank_account_verify' when calling BankAccountsApi.bank_account_verify" end # resource path local_var_path = '/bank_accounts/{bank_id}/verify'.sub('{' + 'bank_id' + '}', CGI.escape(bank_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(bank_account_verify) # return_type return_type = opts[:debug_return_type] || 'BankAccount' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"BankAccountsApi.bank_account_verify", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BankAccountsApi#bank_account_verify\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#bank_accounts_list_with_http_info(opts = {}) ⇒ Array<(BankAccountList, Integer, Hash)>
list Returns a list of your bank accounts. The bank accounts are returned sorted by creation date, with the most recently created bank accounts appearing first.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/lob/api/bank_accounts_api.rb', line 330 def bank_accounts_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BankAccountsApi.bank_accounts_list ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling BankAccountsApi.bank_accounts_list, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling BankAccountsApi.bank_accounts_list, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'metadata'].nil? && opts[:'metadata'].to_s.length > 500 fail ArgumentError, 'invalid value for "opts[:"metadata"]" when calling BankAccountsApi.bank_accounts_list, the character length must be smaller than or equal to 500.' end pattern = Regexp.new(/[^"\\]{0,500}/) if @api_client.config.client_side_validation && !opts[:'metadata'].nil? && opts[:'metadata'] !~ pattern fail ArgumentError, "invalid value for 'opts[:\"metadata\"]' when calling BankAccountsApi.bank_accounts_list, must conform to the pattern #{pattern}." end # resource path local_var_path = '/bank_accounts' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'before'] = opts[:'before'] if !opts[:'before'].nil? query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil? query_params[:'include'] = @api_client.build_collection_param(opts[:'include'], :multi) if !opts[:'include'].nil? query_params[:'date_created'] = opts[:'date_created'] if !opts[:'date_created'].nil? query_params[:'metadata'] = opts[:'metadata'] if !opts[:'metadata'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'BankAccountList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"BankAccountsApi.bank_accounts_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BankAccountsApi#bank_accounts_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create(bank_account_writable, opts = {}) ⇒ BankAccount
create Creates a new bank account with the provided properties. Bank accounts created in live mode will need to be verified via micro deposits before being able to send live checks. The deposits will appear in the bank account in 2-3 business days and have the description "VERIFICATION".
27 28 29 30 |
# File 'lib/lob/api/bank_accounts_api.rb', line 27 def create(bank_account_writable, opts = {}) data, _status_code, _headers = bank_account_create_with_http_info(bank_account_writable, opts) data end |
#delete(bank_id, opts = {}) ⇒ BankAccountDeletion
delete Permanently deletes a bank account. It cannot be undone.
95 96 97 98 |
# File 'lib/lob/api/bank_accounts_api.rb', line 95 def delete(bank_id, opts = {}) data, _status_code, _headers = bank_account_delete_with_http_info(bank_id, opts) data end |
#get(bank_id, opts = {}) ⇒ BankAccount
get Retrieves the details of an existing bank account. You need only supply the unique bank account identifier that was returned upon bank account creation.
163 164 165 166 |
# File 'lib/lob/api/bank_accounts_api.rb', line 163 def get(bank_id, opts = {}) data, _status_code, _headers = bank_account_retrieve_with_http_info(bank_id, opts) data end |
#list(opts = {}) ⇒ BankAccountList
list Returns a list of your bank accounts. The bank accounts are returned sorted by creation date, with the most recently created bank accounts appearing first.
315 316 317 318 |
# File 'lib/lob/api/bank_accounts_api.rb', line 315 def list(opts = {}) data, _status_code, _headers = bank_accounts_list_with_http_info(opts) data end |
#verify(bank_id, bank_account_verify, opts = {}) ⇒ BankAccount
verify Verify a bank account in order to create a check.
232 233 234 235 |
# File 'lib/lob/api/bank_accounts_api.rb', line 232 def verify(bank_id, bank_account_verify, opts = {}) data, _status_code, _headers = bank_account_verify_with_http_info(bank_id, bank_account_verify, opts) data end |