Class: Lob::BillingGroupsApi
- Inherits:
-
Object
- Object
- Lob::BillingGroupsApi
- Defined in:
- lib/lob/api/billing_groups_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#billing_group_create_with_http_info(billing_group_editable, opts = {}) ⇒ Array<(BillingGroup, Integer, Hash)>
create Creates a new billing_group with the provided properties.
-
#billing_group_retrieve_with_http_info(bg_id, opts = {}) ⇒ Array<(BillingGroup, Integer, Hash)>
get Retrieves the details of an existing billing_group.
-
#billing_group_update_with_http_info(bg_id, billing_group_editable, opts = {}) ⇒ Array<(BillingGroup, Integer, Hash)>
update Updates all editable attributes of the billing_group with the given id.
-
#billing_groups_list_with_http_info(opts = {}) ⇒ Array<(BillingGroupList, Integer, Hash)>
list Returns a list of your billing_groups.
-
#create(billing_group_editable, opts = {}) ⇒ BillingGroup
create Creates a new billing_group with the provided properties.
-
#get(bg_id, opts = {}) ⇒ BillingGroup
get Retrieves the details of an existing billing_group.
-
#initialize(api_client = ApiClient.default) ⇒ BillingGroupsApi
constructor
A new instance of BillingGroupsApi.
-
#list(opts = {}) ⇒ BillingGroupList
list Returns a list of your billing_groups.
-
#update(bg_id, billing_group_editable, opts = {}) ⇒ BillingGroup
update Updates all editable attributes of the billing_group with the given id.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ BillingGroupsApi
Returns a new instance of BillingGroupsApi.
19 20 21 |
# File 'lib/lob/api/billing_groups_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/lob/api/billing_groups_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#billing_group_create_with_http_info(billing_group_editable, opts = {}) ⇒ Array<(BillingGroup, Integer, Hash)>
create Creates a new billing_group with the provided properties.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/lob/api/billing_groups_api.rb', line 37 def billing_group_create_with_http_info(billing_group_editable, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BillingGroupsApi.billing_group_create ...' end # verify the required parameter 'billing_group_editable' is set if @api_client.config.client_side_validation && billing_group_editable.nil? fail ArgumentError, "Missing the required parameter 'billing_group_editable' when calling BillingGroupsApi.billing_group_create" end # resource path local_var_path = '/billing_groups' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(billing_group_editable) # return_type return_type = opts[:debug_return_type] || 'BillingGroup' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"BillingGroupsApi.billing_group_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BillingGroupsApi#billing_group_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#billing_group_retrieve_with_http_info(bg_id, opts = {}) ⇒ Array<(BillingGroup, Integer, Hash)>
get Retrieves the details of an existing billing_group. You need only supply the unique billing_group identifier that was returned upon billing_group creation.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/lob/api/billing_groups_api.rb', line 105 def billing_group_retrieve_with_http_info(bg_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BillingGroupsApi.billing_group_retrieve ...' end # verify the required parameter 'bg_id' is set if @api_client.config.client_side_validation && bg_id.nil? fail ArgumentError, "Missing the required parameter 'bg_id' when calling BillingGroupsApi.billing_group_retrieve" end pattern = Regexp.new(/^bg_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && bg_id !~ pattern fail ArgumentError, "invalid value for 'bg_id' when calling BillingGroupsApi.billing_group_retrieve, must conform to the pattern #{pattern}." end # resource path local_var_path = '/billing_groups/{bg_id}'.sub('{' + 'bg_id' + '}', CGI.escape(bg_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'BillingGroup' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"BillingGroupsApi.billing_group_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BillingGroupsApi#billing_group_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#billing_group_update_with_http_info(bg_id, billing_group_editable, opts = {}) ⇒ Array<(BillingGroup, Integer, Hash)>
update Updates all editable attributes of the billing_group with the given id.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/lob/api/billing_groups_api.rb', line 175 def billing_group_update_with_http_info(bg_id, billing_group_editable, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BillingGroupsApi.billing_group_update ...' end # verify the required parameter 'bg_id' is set if @api_client.config.client_side_validation && bg_id.nil? fail ArgumentError, "Missing the required parameter 'bg_id' when calling BillingGroupsApi.billing_group_update" end pattern = Regexp.new(/^bg_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && bg_id !~ pattern fail ArgumentError, "invalid value for 'bg_id' when calling BillingGroupsApi.billing_group_update, must conform to the pattern #{pattern}." end # verify the required parameter 'billing_group_editable' is set if @api_client.config.client_side_validation && billing_group_editable.nil? fail ArgumentError, "Missing the required parameter 'billing_group_editable' when calling BillingGroupsApi.billing_group_update" end # resource path local_var_path = '/billing_groups/{bg_id}'.sub('{' + 'bg_id' + '}', CGI.escape(bg_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(billing_group_editable) # return_type return_type = opts[:debug_return_type] || 'BillingGroup' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"BillingGroupsApi.billing_group_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BillingGroupsApi#billing_group_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#billing_groups_list_with_http_info(opts = {}) ⇒ Array<(BillingGroupList, Integer, Hash)>
list Returns a list of your billing_groups. The billing_groups are returned sorted by creation date, with the most recently created billing_groups appearing first.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/lob/api/billing_groups_api.rb', line 262 def billing_groups_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BillingGroupsApi.billing_groups_list ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling BillingGroupsApi.billing_groups_list, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling BillingGroupsApi.billing_groups_list, must be greater than or equal to 1.' end # resource path local_var_path = '/billing_groups' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'include'] = @api_client.build_collection_param(opts[:'include'], :multi) if !opts[:'include'].nil? query_params[:'date_created'] = opts[:'date_created'] if !opts[:'date_created'].nil? query_params[:'date_modified'] = opts[:'date_modified'] if !opts[:'date_modified'].nil? query_params[:'sort_by_date_modified'] = opts[:'sort_by_date_modified'] if !opts[:'sort_by_date_modified'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'BillingGroupList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"BillingGroupsApi.billing_groups_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BillingGroupsApi#billing_groups_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create(billing_group_editable, opts = {}) ⇒ BillingGroup
create Creates a new billing_group with the provided properties.
27 28 29 30 |
# File 'lib/lob/api/billing_groups_api.rb', line 27 def create(billing_group_editable, opts = {}) data, _status_code, _headers = billing_group_create_with_http_info(billing_group_editable, opts) data end |
#get(bg_id, opts = {}) ⇒ BillingGroup
get Retrieves the details of an existing billing_group. You need only supply the unique billing_group identifier that was returned upon billing_group creation.
95 96 97 98 |
# File 'lib/lob/api/billing_groups_api.rb', line 95 def get(bg_id, opts = {}) data, _status_code, _headers = billing_group_retrieve_with_http_info(bg_id, opts) data end |
#list(opts = {}) ⇒ BillingGroupList
list Returns a list of your billing_groups. The billing_groups are returned sorted by creation date, with the most recently created billing_groups appearing first.
247 248 249 250 |
# File 'lib/lob/api/billing_groups_api.rb', line 247 def list(opts = {}) data, _status_code, _headers = billing_groups_list_with_http_info(opts) data end |
#update(bg_id, billing_group_editable, opts = {}) ⇒ BillingGroup
update Updates all editable attributes of the billing_group with the given id.
164 165 166 167 |
# File 'lib/lob/api/billing_groups_api.rb', line 164 def update(bg_id, billing_group_editable, opts = {}) data, _status_code, _headers = billing_group_update_with_http_info(bg_id, billing_group_editable, opts) data end |