Class: Lob::CampaignsApi
- Inherits:
-
Object
- Object
- Lob::CampaignsApi
- Defined in:
- lib/lob/api/campaigns_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#campaign_create_with_http_info(campaign_writable, opts = {}) ⇒ Array<(Campaign, Integer, Hash)>
create Creates a new campaign with the provided properties.
-
#campaign_delete_with_http_info(cmp_id, opts = {}) ⇒ Array<(CampaignDeletion, Integer, Hash)>
delete Delete an existing campaign.
-
#campaign_retrieve_with_http_info(cmp_id, opts = {}) ⇒ Array<(Campaign, Integer, Hash)>
get Retrieves the details of an existing campaign.
-
#campaign_update_with_http_info(cmp_id, campaign_updatable, opts = {}) ⇒ Array<(Campaign, Integer, Hash)>
update Update the details of an existing campaign.
-
#campaigns_list_with_http_info(opts = {}) ⇒ Array<(CampaignsList, Integer, Hash)>
list Returns a list of your campaigns.
-
#create(campaign_writable, opts = {}) ⇒ Campaign
create Creates a new campaign with the provided properties.
-
#delete(cmp_id, opts = {}) ⇒ CampaignDeletion
delete Delete an existing campaign.
-
#get(cmp_id, opts = {}) ⇒ Campaign
get Retrieves the details of an existing campaign.
-
#initialize(api_client = ApiClient.default) ⇒ CampaignsApi
constructor
A new instance of CampaignsApi.
-
#list(opts = {}) ⇒ CampaignsList
list Returns a list of your campaigns.
-
#update(cmp_id, campaign_updatable, opts = {}) ⇒ Campaign
update Update the details of an existing campaign.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CampaignsApi
Returns a new instance of CampaignsApi.
19 20 21 |
# File 'lib/lob/api/campaigns_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/lob/api/campaigns_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#campaign_create_with_http_info(campaign_writable, opts = {}) ⇒ Array<(Campaign, Integer, Hash)>
create Creates a new campaign with the provided properties. See how to launch your first campaign [here](help.lob.com/best-practices/launching-your-first-campaign).
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/lob/api/campaigns_api.rb', line 39 def campaign_create_with_http_info(campaign_writable, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CampaignsApi.campaign_create ...' end # verify the required parameter 'campaign_writable' is set if @api_client.config.client_side_validation && campaign_writable.nil? fail ArgumentError, "Missing the required parameter 'campaign_writable' when calling CampaignsApi.campaign_create" end allowable_values = ["native", "match"] if @api_client.config.client_side_validation && opts[:'x_lang_output'] && !allowable_values.include?(opts[:'x_lang_output']) fail ArgumentError, "invalid value for \"x_lang_output\", must be one of #{allowable_values}" end # resource path local_var_path = '/campaigns' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'x-lang-output'] = opts[:'x_lang_output'] if !opts[:'x_lang_output'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(campaign_writable) # return_type return_type = opts[:debug_return_type] || 'Campaign' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"CampaignsApi.campaign_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CampaignsApi#campaign_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#campaign_delete_with_http_info(cmp_id, opts = {}) ⇒ Array<(CampaignDeletion, Integer, Hash)>
delete Delete an existing campaign. You need only supply the unique identifier that was returned upon campaign creation. Deleting a campaign also deletes any associated mail pieces that have been created but not sent. A campaign's `send_date` matches its associated mail pieces' `send_date`s.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/lob/api/campaigns_api.rb', line 112 def campaign_delete_with_http_info(cmp_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CampaignsApi.campaign_delete ...' end # verify the required parameter 'cmp_id' is set if @api_client.config.client_side_validation && cmp_id.nil? fail ArgumentError, "Missing the required parameter 'cmp_id' when calling CampaignsApi.campaign_delete" end pattern = Regexp.new(/^cmp_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && cmp_id !~ pattern fail ArgumentError, "invalid value for 'cmp_id' when calling CampaignsApi.campaign_delete, must conform to the pattern #{pattern}." end # resource path local_var_path = '/campaigns/{cmp_id}'.sub('{' + 'cmp_id' + '}', CGI.escape(cmp_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CampaignDeletion' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"CampaignsApi.campaign_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CampaignsApi#campaign_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#campaign_retrieve_with_http_info(cmp_id, opts = {}) ⇒ Array<(Campaign, Integer, Hash)>
get Retrieves the details of an existing campaign. You need only supply the unique campaign identifier that was returned upon campaign creation.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/lob/api/campaigns_api.rb', line 180 def campaign_retrieve_with_http_info(cmp_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CampaignsApi.campaign_retrieve ...' end # verify the required parameter 'cmp_id' is set if @api_client.config.client_side_validation && cmp_id.nil? fail ArgumentError, "Missing the required parameter 'cmp_id' when calling CampaignsApi.campaign_retrieve" end pattern = Regexp.new(/^cmp_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && cmp_id !~ pattern fail ArgumentError, "invalid value for 'cmp_id' when calling CampaignsApi.campaign_retrieve, must conform to the pattern #{pattern}." end # resource path local_var_path = '/campaigns/{cmp_id}'.sub('{' + 'cmp_id' + '}', CGI.escape(cmp_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Campaign' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"CampaignsApi.campaign_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CampaignsApi#campaign_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#campaign_update_with_http_info(cmp_id, campaign_updatable, opts = {}) ⇒ Array<(Campaign, Integer, Hash)>
update Update the details of an existing campaign. You need only supply the unique identifier that was returned upon campaign creation.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/lob/api/campaigns_api.rb', line 250 def campaign_update_with_http_info(cmp_id, campaign_updatable, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CampaignsApi.campaign_update ...' end # verify the required parameter 'cmp_id' is set if @api_client.config.client_side_validation && cmp_id.nil? fail ArgumentError, "Missing the required parameter 'cmp_id' when calling CampaignsApi.campaign_update" end pattern = Regexp.new(/^cmp_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && cmp_id !~ pattern fail ArgumentError, "invalid value for 'cmp_id' when calling CampaignsApi.campaign_update, must conform to the pattern #{pattern}." end # verify the required parameter 'campaign_updatable' is set if @api_client.config.client_side_validation && campaign_updatable.nil? fail ArgumentError, "Missing the required parameter 'campaign_updatable' when calling CampaignsApi.campaign_update" end # resource path local_var_path = '/campaigns/{cmp_id}'.sub('{' + 'cmp_id' + '}', CGI.escape(cmp_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(campaign_updatable) # return_type return_type = opts[:debug_return_type] || 'Campaign' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"CampaignsApi.campaign_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CampaignsApi#campaign_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#campaigns_list_with_http_info(opts = {}) ⇒ Array<(CampaignsList, Integer, Hash)>
list Returns a list of your campaigns. The campaigns are returned sorted by creation date, with the most recently created campaigns appearing first.
333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/lob/api/campaigns_api.rb', line 333 def campaigns_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CampaignsApi.campaigns_list ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CampaignsApi.campaigns_list, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CampaignsApi.campaigns_list, must be greater than or equal to 1.' end # resource path local_var_path = '/campaigns' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'include'] = @api_client.build_collection_param(opts[:'include'], :multi) if !opts[:'include'].nil? query_params[:'before'] = opts[:'before'] if !opts[:'before'].nil? query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CampaignsList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"CampaignsApi.campaigns_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CampaignsApi#campaigns_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create(campaign_writable, opts = {}) ⇒ Campaign
create Creates a new campaign with the provided properties. See how to launch your first campaign [here](help.lob.com/best-practices/launching-your-first-campaign).
28 29 30 31 |
# File 'lib/lob/api/campaigns_api.rb', line 28 def create(campaign_writable, opts = {}) data, _status_code, _headers = campaign_create_with_http_info(campaign_writable, opts) data end |
#delete(cmp_id, opts = {}) ⇒ CampaignDeletion
delete Delete an existing campaign. You need only supply the unique identifier that was returned upon campaign creation. Deleting a campaign also deletes any associated mail pieces that have been created but not sent. A campaign’s ‘send_date` matches its associated mail pieces’ ‘send_date`s.
102 103 104 105 |
# File 'lib/lob/api/campaigns_api.rb', line 102 def delete(cmp_id, opts = {}) data, _status_code, _headers = campaign_delete_with_http_info(cmp_id, opts) data end |
#get(cmp_id, opts = {}) ⇒ Campaign
get Retrieves the details of an existing campaign. You need only supply the unique campaign identifier that was returned upon campaign creation.
170 171 172 173 |
# File 'lib/lob/api/campaigns_api.rb', line 170 def get(cmp_id, opts = {}) data, _status_code, _headers = campaign_retrieve_with_http_info(cmp_id, opts) data end |
#list(opts = {}) ⇒ CampaignsList
list Returns a list of your campaigns. The campaigns are returned sorted by creation date, with the most recently created campaigns appearing first.
320 321 322 323 |
# File 'lib/lob/api/campaigns_api.rb', line 320 def list(opts = {}) data, _status_code, _headers = campaigns_list_with_http_info(opts) data end |
#update(cmp_id, campaign_updatable, opts = {}) ⇒ Campaign
update Update the details of an existing campaign. You need only supply the unique identifier that was returned upon campaign creation.
239 240 241 242 |
# File 'lib/lob/api/campaigns_api.rb', line 239 def update(cmp_id, campaign_updatable, opts = {}) data, _status_code, _headers = campaign_update_with_http_info(cmp_id, campaign_updatable, opts) data end |