Class: Lob::CreativesApi
- Inherits:
-
Object
- Object
- Lob::CreativesApi
- Defined in:
- lib/lob/api/creatives_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create(creative_writable, opts = {}) ⇒ CreativeResponse
create Creates a new creative with the provided properties.
-
#creative_create_with_http_info(creative_writable, opts = {}) ⇒ Array<(CreativeResponse, Integer, Hash)>
create Creates a new creative with the provided properties.
-
#creative_retrieve_with_http_info(crv_id, opts = {}) ⇒ Array<(CreativeResponse, Integer, Hash)>
get Retrieves the details of an existing creative.
-
#creative_update_with_http_info(crv_id, creative_patch, opts = {}) ⇒ Array<(CreativeResponse, Integer, Hash)>
update Update the details of an existing creative.
-
#get(crv_id, opts = {}) ⇒ CreativeResponse
get Retrieves the details of an existing creative.
-
#initialize(api_client = ApiClient.default) ⇒ CreativesApi
constructor
A new instance of CreativesApi.
-
#update(crv_id, creative_patch, opts = {}) ⇒ CreativeResponse
update Update the details of an existing creative.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CreativesApi
Returns a new instance of CreativesApi.
19 20 21 |
# File 'lib/lob/api/creatives_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/lob/api/creatives_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create(creative_writable, opts = {}) ⇒ CreativeResponse
create Creates a new creative with the provided properties
28 29 30 31 |
# File 'lib/lob/api/creatives_api.rb', line 28 def create(creative_writable, opts = {}) data, _status_code, _headers = creative_create_with_http_info(creative_writable, opts) data end |
#creative_create_with_http_info(creative_writable, opts = {}) ⇒ Array<(CreativeResponse, Integer, Hash)>
create Creates a new creative with the provided properties
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/lob/api/creatives_api.rb', line 39 def creative_create_with_http_info(creative_writable, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CreativesApi.creative_create ...' end # verify the required parameter 'creative_writable' is set if @api_client.config.client_side_validation && creative_writable.nil? fail ArgumentError, "Missing the required parameter 'creative_writable' when calling CreativesApi.creative_create" end allowable_values = ["native", "match"] if @api_client.config.client_side_validation && opts[:'x_lang_output'] && !allowable_values.include?(opts[:'x_lang_output']) fail ArgumentError, "invalid value for \"x_lang_output\", must be one of #{allowable_values}" end # resource path local_var_path = '/creatives' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'x-lang-output'] = opts[:'x_lang_output'] if !opts[:'x_lang_output'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(creative_writable) # return_type return_type = opts[:debug_return_type] || 'CreativeResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"CreativesApi.creative_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CreativesApi#creative_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#creative_retrieve_with_http_info(crv_id, opts = {}) ⇒ Array<(CreativeResponse, Integer, Hash)>
get Retrieves the details of an existing creative. You need only supply the unique creative identifier that was returned upon creative creation.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/lob/api/creatives_api.rb', line 112 def creative_retrieve_with_http_info(crv_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CreativesApi.creative_retrieve ...' end # verify the required parameter 'crv_id' is set if @api_client.config.client_side_validation && crv_id.nil? fail ArgumentError, "Missing the required parameter 'crv_id' when calling CreativesApi.creative_retrieve" end pattern = Regexp.new(/^crv_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && crv_id !~ pattern fail ArgumentError, "invalid value for 'crv_id' when calling CreativesApi.creative_retrieve, must conform to the pattern #{pattern}." end # resource path local_var_path = '/creatives/{crv_id}'.sub('{' + 'crv_id' + '}', CGI.escape(crv_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CreativeResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"CreativesApi.creative_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CreativesApi#creative_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#creative_update_with_http_info(crv_id, creative_patch, opts = {}) ⇒ Array<(CreativeResponse, Integer, Hash)>
update Update the details of an existing creative. You need only supply the unique identifier that was returned upon creative creation.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/lob/api/creatives_api.rb', line 182 def creative_update_with_http_info(crv_id, creative_patch, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CreativesApi.creative_update ...' end # verify the required parameter 'crv_id' is set if @api_client.config.client_side_validation && crv_id.nil? fail ArgumentError, "Missing the required parameter 'crv_id' when calling CreativesApi.creative_update" end pattern = Regexp.new(/^crv_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && crv_id !~ pattern fail ArgumentError, "invalid value for 'crv_id' when calling CreativesApi.creative_update, must conform to the pattern #{pattern}." end # verify the required parameter 'creative_patch' is set if @api_client.config.client_side_validation && creative_patch.nil? fail ArgumentError, "Missing the required parameter 'creative_patch' when calling CreativesApi.creative_update" end # resource path local_var_path = '/creatives/{crv_id}'.sub('{' + 'crv_id' + '}', CGI.escape(crv_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(creative_patch) # return_type return_type = opts[:debug_return_type] || 'CreativeResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"CreativesApi.creative_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CreativesApi#creative_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get(crv_id, opts = {}) ⇒ CreativeResponse
get Retrieves the details of an existing creative. You need only supply the unique creative identifier that was returned upon creative creation.
102 103 104 105 |
# File 'lib/lob/api/creatives_api.rb', line 102 def get(crv_id, opts = {}) data, _status_code, _headers = creative_retrieve_with_http_info(crv_id, opts) data end |
#update(crv_id, creative_patch, opts = {}) ⇒ CreativeResponse
update Update the details of an existing creative. You need only supply the unique identifier that was returned upon creative creation.
171 172 173 174 |
# File 'lib/lob/api/creatives_api.rb', line 171 def update(crv_id, creative_patch, opts = {}) data, _status_code, _headers = creative_update_with_http_info(crv_id, creative_patch, opts) data end |