Class: Lob::IntlAutocompletionsApi
- Inherits:
-
Object
- Object
- Lob::IntlAutocompletionsApi
- Defined in:
- lib/lob/api/intl_autocompletions_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#autocomplete(intl_autocompletions_writable, opts = {}) ⇒ IntlAutocompletions
autocomplete Given an address prefix consisting of a partial primary line and country, as well as optional input of city, state, and zip code, this functionality returns up to 10 full International address suggestions.
-
#initialize(api_client = ApiClient.default) ⇒ IntlAutocompletionsApi
constructor
A new instance of IntlAutocompletionsApi.
-
#intl_autocompletion_with_http_info(intl_autocompletions_writable, opts = {}) ⇒ Array<(IntlAutocompletions, Integer, Hash)>
autocomplete Given an address prefix consisting of a partial primary line and country, as well as optional input of city, state, and zip code, this functionality returns up to 10 full International address suggestions.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ IntlAutocompletionsApi
Returns a new instance of IntlAutocompletionsApi.
19 20 21 |
# File 'lib/lob/api/intl_autocompletions_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/lob/api/intl_autocompletions_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#autocomplete(intl_autocompletions_writable, opts = {}) ⇒ IntlAutocompletions
autocomplete Given an address prefix consisting of a partial primary line and country, as well as optional input of city, state, and zip code, this functionality returns up to 10 full International address suggestions. Not all of them will turn out to be valid addresses; they’ll need to be [verified](#operation/intl_verification).
28 29 30 31 |
# File 'lib/lob/api/intl_autocompletions_api.rb', line 28 def autocomplete(intl_autocompletions_writable, opts = {}) data, _status_code, _headers = intl_autocompletion_with_http_info(intl_autocompletions_writable, opts) data end |
#intl_autocompletion_with_http_info(intl_autocompletions_writable, opts = {}) ⇒ Array<(IntlAutocompletions, Integer, Hash)>
autocomplete Given an address prefix consisting of a partial primary line and country, as well as optional input of city, state, and zip code, this functionality returns up to 10 full International address suggestions. Not all of them will turn out to be valid addresses; they'll need to be [verified](#operation/intl_verification).
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/lob/api/intl_autocompletions_api.rb', line 39 def intl_autocompletion_with_http_info(intl_autocompletions_writable, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntlAutocompletionsApi.intl_autocompletion ...' end # verify the required parameter 'intl_autocompletions_writable' is set if @api_client.config.client_side_validation && intl_autocompletions_writable.nil? fail ArgumentError, "Missing the required parameter 'intl_autocompletions_writable' when calling IntlAutocompletionsApi.intl_autocompletion" end allowable_values = ["native", "match"] if @api_client.config.client_side_validation && opts[:'x_lang_output'] && !allowable_values.include?(opts[:'x_lang_output']) fail ArgumentError, "invalid value for \"x_lang_output\", must be one of #{allowable_values}" end # resource path local_var_path = '/intl_autocompletions' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'x-lang-output'] = opts[:'x_lang_output'] if !opts[:'x_lang_output'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(intl_autocompletions_writable) # return_type return_type = opts[:debug_return_type] || 'IntlAutocompletions' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"IntlAutocompletionsApi.intl_autocompletion", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntlAutocompletionsApi#intl_autocompletion\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |