Class: Lob::LetterDetailsReturned
- Inherits:
-
Object
- Object
- Lob::LetterDetailsReturned
- Defined in:
- lib/lob/models/letter_details_returned.rb
Overview
Properties that the letters in your Creative should have.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#address_placement ⇒ Object
Specifies the location of the address information that will show through the double-window envelope.
-
#bleed ⇒ Object
Allows for letter bleed.
-
#cards ⇒ Object
A single-element array containing an existing card id in a string format.
-
#color ⇒ Object
Set this key to ‘true` if you would like to print in color, false for black and white.
-
#custom_envelope ⇒ Object
Returns the value of attribute custom_envelope.
-
#double_sided ⇒ Object
Set this attribute to ‘true` for double sided printing, `false` for for single sided printing.
-
#extra_service ⇒ Object
Add an extra service to your letter.
-
#file_original_url ⇒ Object
Returns the value of attribute file_original_url.
-
#mail_type ⇒ Object
Returns the value of attribute mail_type.
-
#return_envelope ⇒ Object
Returns the value of attribute return_envelope.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LetterDetailsReturned
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ LetterDetailsReturned
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/lob/models/letter_details_returned.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::LetterDetailsReturned` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::LetterDetailsReturned`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'color') self.color = attributes[:'color'] end if attributes.key?(:'cards') if (value = attributes[:'cards']).is_a?(Array) self.cards = value end end if attributes.key?(:'address_placement') self.address_placement = attributes[:'address_placement'] else self.address_placement = 'top_first_page' end if attributes.key?(:'custom_envelope') self.custom_envelope = attributes[:'custom_envelope'] end if attributes.key?(:'double_sided') self.double_sided = attributes[:'double_sided'] else self.double_sided = true end if attributes.key?(:'extra_service') self.extra_service = attributes[:'extra_service'] end if attributes.key?(:'mail_type') self.mail_type = attributes[:'mail_type'] else self.mail_type = 'usps_first_class' end if attributes.key?(:'return_envelope') self.return_envelope = attributes[:'return_envelope'] end if attributes.key?(:'bleed') self.bleed = attributes[:'bleed'] else self.bleed = false end if attributes.key?(:'file_original_url') self.file_original_url = attributes[:'file_original_url'] end end |
Instance Attribute Details
#address_placement ⇒ Object
Specifies the location of the address information that will show through the double-window envelope.
26 27 28 |
# File 'lib/lob/models/letter_details_returned.rb', line 26 def address_placement @address_placement end |
#bleed ⇒ Object
Allows for letter bleed. Enabled only with specific feature flags.
41 42 43 |
# File 'lib/lob/models/letter_details_returned.rb', line 41 def bleed @bleed end |
#cards ⇒ Object
A single-element array containing an existing card id in a string format. See [cards](#tag/Cards) for more information.
23 24 25 |
# File 'lib/lob/models/letter_details_returned.rb', line 23 def cards @cards end |
#color ⇒ Object
Set this key to ‘true` if you would like to print in color, false for black and white.
20 21 22 |
# File 'lib/lob/models/letter_details_returned.rb', line 20 def color @color end |
#custom_envelope ⇒ Object
Returns the value of attribute custom_envelope.
28 29 30 |
# File 'lib/lob/models/letter_details_returned.rb', line 28 def custom_envelope @custom_envelope end |
#double_sided ⇒ Object
Set this attribute to ‘true` for double sided printing, `false` for for single sided printing.
31 32 33 |
# File 'lib/lob/models/letter_details_returned.rb', line 31 def double_sided @double_sided end |
#extra_service ⇒ Object
Add an extra service to your letter.
34 35 36 |
# File 'lib/lob/models/letter_details_returned.rb', line 34 def extra_service @extra_service end |
#file_original_url ⇒ Object
Returns the value of attribute file_original_url.
43 44 45 |
# File 'lib/lob/models/letter_details_returned.rb', line 43 def file_original_url @file_original_url end |
#mail_type ⇒ Object
Returns the value of attribute mail_type.
36 37 38 |
# File 'lib/lob/models/letter_details_returned.rb', line 36 def mail_type @mail_type end |
#return_envelope ⇒ Object
Returns the value of attribute return_envelope.
38 39 40 |
# File 'lib/lob/models/letter_details_returned.rb', line 38 def return_envelope @return_envelope end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/lob/models/letter_details_returned.rb', line 84 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/lob/models/letter_details_returned.rb', line 68 def self.attribute_map { :'color' => :'color', :'cards' => :'cards', :'address_placement' => :'address_placement', :'custom_envelope' => :'custom_envelope', :'double_sided' => :'double_sided', :'extra_service' => :'extra_service', :'mail_type' => :'mail_type', :'return_envelope' => :'return_envelope', :'bleed' => :'bleed', :'file_original_url' => :'file_original_url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
267 268 269 |
# File 'lib/lob/models/letter_details_returned.rb', line 267 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 109 110 111 112 |
# File 'lib/lob/models/letter_details_returned.rb', line 105 def self.openapi_nullable Set.new([ :'cards', :'custom_envelope', :'return_envelope', :'file_original_url' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/lob/models/letter_details_returned.rb', line 89 def self.openapi_types { :'color' => :'Boolean', :'cards' => :'Array<String>', :'address_placement' => :'String', :'custom_envelope' => :'CustomEnvelopeReturned', :'double_sided' => :'Boolean', :'extra_service' => :'String', :'mail_type' => :'MailType', :'return_envelope' => Array[:'Boolean', :'String'], :'bleed' => :'Boolean', :'file_original_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/lob/models/letter_details_returned.rb', line 236 def ==(o) return true if self.equal?(o) self.class == o.class && color == o.color && cards == o.cards && address_placement == o.address_placement && custom_envelope == o.custom_envelope && double_sided == o.double_sided && extra_service == o.extra_service && mail_type == o.mail_type && return_envelope == o.return_envelope && bleed == o.bleed && file_original_url == o.file_original_url end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/lob/models/letter_details_returned.rb', line 306 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Lob.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/lob/models/letter_details_returned.rb', line 377 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/lob/models/letter_details_returned.rb', line 274 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) # // guardrails-disable-line elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line end elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array) for base_type in type do res = _deserialize(base_type, attributes[self.class.attribute_map[key]]) if !res.nil? self.send("#{key}=", res) # // guardrails-disable-line break end end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line end end self end |
#eql?(o) ⇒ Boolean
253 254 255 |
# File 'lib/lob/models/letter_details_returned.rb', line 253 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
259 260 261 |
# File 'lib/lob/models/letter_details_returned.rb', line 259 def hash [color, cards, address_placement, custom_envelope, double_sided, extra_service, mail_type, return_envelope, bleed, file_original_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/lob/models/letter_details_returned.rb', line 182 def list_invalid_properties invalid_properties = Array.new if @color.nil? invalid_properties.push('invalid value for "color", color cannot be nil.') end if @cards.length > 1 invalid_properties.push('invalid value for "cards", number of items must be less than or equal to 1.') end if @cards.length < 0 invalid_properties.push('invalid value for "cards", number of items must be greater than or equal to 0.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
353 354 355 |
# File 'lib/lob/models/letter_details_returned.rb', line 353 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/lob/models/letter_details_returned.rb', line 359 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) # // guardrails-disable-line if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
347 348 349 |
# File 'lib/lob/models/letter_details_returned.rb', line 347 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
201 202 203 204 205 206 207 208 |
# File 'lib/lob/models/letter_details_returned.rb', line 201 def valid? return false if @color.nil? return false if @cards.length > 1 return false if @cards.length < 0 address_placement_validator = EnumAttributeValidator.new('String', ["top_first_page", "insert_blank_page", "bottom_first_page_center", "bottom_first_page"]) return false unless address_placement_validator.valid?(@address_placement) true end |