Class: Lob::LettersApi
- Inherits:
-
Object
- Object
- Lob::LettersApi
- Defined in:
- lib/lob/api/letters_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#cancel(ltr_id, opts = {}) ⇒ LetterDeletion
cancel Completely removes a letter from production.
-
#create(letter_editable, opts = {}) ⇒ Letter
create Creates a new letter given information.
-
#get(ltr_id, opts = {}) ⇒ Letter
get Retrieves the details of an existing letter.
-
#initialize(api_client = ApiClient.default) ⇒ LettersApi
constructor
A new instance of LettersApi.
-
#letter_cancel_with_http_info(ltr_id, opts = {}) ⇒ Array<(LetterDeletion, Integer, Hash)>
cancel Completely removes a letter from production.
-
#letter_create_with_http_info(letter_editable, opts = {}) ⇒ Array<(Letter, Integer, Hash)>
create Creates a new letter given information.
-
#letter_retrieve_with_http_info(ltr_id, opts = {}) ⇒ Array<(Letter, Integer, Hash)>
get Retrieves the details of an existing letter.
-
#letters_list_with_http_info(opts = {}) ⇒ Array<(LetterList, Integer, Hash)>
list Returns a list of your letters.
-
#list(opts = {}) ⇒ LetterList
list Returns a list of your letters.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ LettersApi
Returns a new instance of LettersApi.
19 20 21 |
# File 'lib/lob/api/letters_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/lob/api/letters_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#cancel(ltr_id, opts = {}) ⇒ LetterDeletion
cancel Completely removes a letter from production. This can only be done if the letter has a ‘send_date` and the `send_date` has not yet passed. If the letter is successfully canceled, you will not be charged for it. Read more on [cancellation windows](#section/Cancellation-Windows) and [scheduling](#section/Scheduled-Mailings). Scheduling and cancellation is a premium feature. Upgrade to the appropriate [Print & Mail Edition](dashboard.lob.com/#/settings/editions) to gain access.
27 28 29 30 |
# File 'lib/lob/api/letters_api.rb', line 27 def cancel(ltr_id, opts = {}) data, _status_code, _headers = letter_cancel_with_http_info(ltr_id, opts) data end |
#create(letter_editable, opts = {}) ⇒ Letter
create Creates a new letter given information
97 98 99 100 |
# File 'lib/lob/api/letters_api.rb', line 97 def create(letter_editable, opts = {}) data, _status_code, _headers = letter_create_with_http_info(letter_editable, opts) data end |
#get(ltr_id, opts = {}) ⇒ Letter
get Retrieves the details of an existing letter. You need only supply the unique letter identifier that was returned upon letter creation.
173 174 175 176 |
# File 'lib/lob/api/letters_api.rb', line 173 def get(ltr_id, opts = {}) data, _status_code, _headers = letter_retrieve_with_http_info(ltr_id, opts) data end |
#letter_cancel_with_http_info(ltr_id, opts = {}) ⇒ Array<(LetterDeletion, Integer, Hash)>
cancel Completely removes a letter from production. This can only be done if the letter has a `send_date` and the `send_date` has not yet passed. If the letter is successfully canceled, you will not be charged for it. Read more on [cancellation windows](#section/Cancellation-Windows) and [scheduling](#section/Scheduled-Mailings). Scheduling and cancellation is a premium feature. Upgrade to the appropriate [Print & Mail Edition](dashboard.lob.com/#/settings/editions) to gain access.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/lob/api/letters_api.rb', line 37 def letter_cancel_with_http_info(ltr_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LettersApi.letter_cancel ...' end # verify the required parameter 'ltr_id' is set if @api_client.config.client_side_validation && ltr_id.nil? fail ArgumentError, "Missing the required parameter 'ltr_id' when calling LettersApi.letter_cancel" end pattern = Regexp.new(/^ltr_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && ltr_id !~ pattern fail ArgumentError, "invalid value for 'ltr_id' when calling LettersApi.letter_cancel, must conform to the pattern #{pattern}." end # resource path local_var_path = '/letters/{ltr_id}'.sub('{' + 'ltr_id' + '}', CGI.escape(ltr_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'LetterDeletion' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"LettersApi.letter_cancel", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LettersApi#letter_cancel\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#letter_create_with_http_info(letter_editable, opts = {}) ⇒ Array<(Letter, Integer, Hash)>
create Creates a new letter given information
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/lob/api/letters_api.rb', line 109 def letter_create_with_http_info(letter_editable, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LettersApi.letter_create ...' end # verify the required parameter 'letter_editable' is set if @api_client.config.client_side_validation && letter_editable.nil? fail ArgumentError, "Missing the required parameter 'letter_editable' when calling LettersApi.letter_create" end if @api_client.config.client_side_validation && !opts[:'idempotency_key'].nil? && opts[:'idempotency_key'].to_s.length > 256 fail ArgumentError, 'invalid value for "opts[:"idempotency_key"]" when calling LettersApi.letter_create, the character length must be smaller than or equal to 256.' end # resource path local_var_path = '/letters' # query parameters query_params = opts[:query_params] || {} query_params[:'file'] = opts[:'file'] if !opts[:'file'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Idempotency-Key'] = opts[:'idempotency_key'] if !opts[:'idempotency_key'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(letter_editable) # return_type return_type = opts[:debug_return_type] || 'Letter' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"LettersApi.letter_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LettersApi#letter_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#letter_retrieve_with_http_info(ltr_id, opts = {}) ⇒ Array<(Letter, Integer, Hash)>
get Retrieves the details of an existing letter. You need only supply the unique letter identifier that was returned upon letter creation.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/lob/api/letters_api.rb', line 183 def letter_retrieve_with_http_info(ltr_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LettersApi.letter_retrieve ...' end # verify the required parameter 'ltr_id' is set if @api_client.config.client_side_validation && ltr_id.nil? fail ArgumentError, "Missing the required parameter 'ltr_id' when calling LettersApi.letter_retrieve" end pattern = Regexp.new(/^ltr_[a-zA-Z0-9]+$/) if @api_client.config.client_side_validation && ltr_id !~ pattern fail ArgumentError, "invalid value for 'ltr_id' when calling LettersApi.letter_retrieve, must conform to the pattern #{pattern}." end # resource path local_var_path = '/letters/{ltr_id}'.sub('{' + 'ltr_id' + '}', CGI.escape(ltr_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Letter' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"LettersApi.letter_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LettersApi#letter_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#letters_list_with_http_info(opts = {}) ⇒ Array<(LetterList, Integer, Hash)>
list Returns a list of your letters. The letters are returned sorted by creation date, with the most recently created letters appearing first.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/lob/api/letters_api.rb', line 271 def letters_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LettersApi.letters_list ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling LettersApi.letters_list, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling LettersApi.letters_list, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'metadata'].nil? && opts[:'metadata'].to_s.length > 500 fail ArgumentError, 'invalid value for "opts[:"metadata"]" when calling LettersApi.letters_list, the character length must be smaller than or equal to 500.' end pattern = Regexp.new(/[^"\\]{0,500}/) if @api_client.config.client_side_validation && !opts[:'metadata'].nil? && opts[:'metadata'] !~ pattern fail ArgumentError, "invalid value for 'opts[:\"metadata\"]' when calling LettersApi.letters_list, must conform to the pattern #{pattern}." end # resource path local_var_path = '/letters' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'before'] = opts[:'before'] if !opts[:'before'].nil? query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil? query_params[:'include'] = @api_client.build_collection_param(opts[:'include'], :multi) if !opts[:'include'].nil? query_params[:'date_created'] = opts[:'date_created'] if !opts[:'date_created'].nil? query_params[:'metadata'] = opts[:'metadata'] if !opts[:'metadata'].nil? query_params[:'color'] = opts[:'color'] if !opts[:'color'].nil? query_params[:'scheduled'] = opts[:'scheduled'] if !opts[:'scheduled'].nil? query_params[:'send_date'] = opts[:'send_date'] if !opts[:'send_date'].nil? query_params[:'mail_type'] = opts[:'mail_type'] if !opts[:'mail_type'].nil? query_params[:'sort_by'] = opts[:'sort_by'] if !opts[:'sort_by'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'LetterList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"LettersApi.letters_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LettersApi#letters_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ LetterList
list Returns a list of your letters. The letters are returned sorted by creation date, with the most recently created letters appearing first.
251 252 253 254 |
# File 'lib/lob/api/letters_api.rb', line 251 def list(opts = {}) data, _status_code, _headers = letters_list_with_http_info(opts) data end |