Class: Lob::MultiLineAddress
- Inherits:
-
Object
- Object
- Lob::MultiLineAddress
- Defined in:
- lib/lob/models/multi_line_address.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
Returns the value of attribute city.
-
#company ⇒ Object
Either ‘name` or `company` is required, you may also add both.
-
#primary_line ⇒ Object
The primary delivery line (usually the street address) of the address.
-
#recipient ⇒ Object
The intended recipient, typically a person’s or firm’s name.
-
#secondary_line ⇒ Object
The secondary delivery line of the address.
-
#state ⇒ Object
The <a href="en.wikipedia.org/wiki/ISO_3166-2:US" target="_blank">ISO 3166-2</a> two letter code or subdivision name for the state.
-
#urbanization ⇒ Object
Only present for addresses in Puerto Rico.
-
#zip_code ⇒ Object
Required if ‘city` and `state` are not passed in.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MultiLineAddress
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ MultiLineAddress
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/lob/models/multi_line_address.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::MultiLineAddress` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::MultiLineAddress`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'recipient') self.recipient = attributes[:'recipient'] end if attributes.key?(:'company') self.company = attributes[:'company'] end if attributes.key?(:'primary_line') self.primary_line = attributes[:'primary_line'] end if attributes.key?(:'secondary_line') self.secondary_line = attributes[:'secondary_line'] end if attributes.key?(:'urbanization') self.urbanization = attributes[:'urbanization'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'zip_code') self.zip_code = attributes[:'zip_code'] end end |
Instance Attribute Details
#city ⇒ Object
Returns the value of attribute city.
33 34 35 |
# File 'lib/lob/models/multi_line_address.rb', line 33 def city @city end |
#company ⇒ Object
Either ‘name` or `company` is required, you may also add both.
22 23 24 |
# File 'lib/lob/models/multi_line_address.rb', line 22 def company @company end |
#primary_line ⇒ Object
The primary delivery line (usually the street address) of the address. Combination of the following applicable ‘components`: * `primary_number` * `street_predirection` * `street_name` * `street_suffix` * `street_postdirection` * `secondary_designator` * `secondary_number` * `pmb_designator` * `pmb_number`
25 26 27 |
# File 'lib/lob/models/multi_line_address.rb', line 25 def primary_line @primary_line end |
#recipient ⇒ Object
The intended recipient, typically a person’s or firm’s name.
19 20 21 |
# File 'lib/lob/models/multi_line_address.rb', line 19 def recipient @recipient end |
#secondary_line ⇒ Object
The secondary delivery line of the address. This field is typically empty but may contain information if ‘primary_line` is too long.
28 29 30 |
# File 'lib/lob/models/multi_line_address.rb', line 28 def secondary_line @secondary_line end |
#state ⇒ Object
The <a href="en.wikipedia.org/wiki/ISO_3166-2:US" target="_blank">ISO 3166-2</a> two letter code or subdivision name for the state. ‘city` and `state` are required if no `zip_code` is passed.
36 37 38 |
# File 'lib/lob/models/multi_line_address.rb', line 36 def state @state end |
#urbanization ⇒ Object
Only present for addresses in Puerto Rico. An urbanization refers to an area, sector, or development within a city. See [USPS documentation](pe.usps.com/text/pub28/28api_008.htm#:~:text=I51.,-4%20Urbanizations&text=In%20Puerto%20Rico%2C%20identical%20street,placed%20before%20the%20urbanization%20name.) for clarification.
31 32 33 |
# File 'lib/lob/models/multi_line_address.rb', line 31 def urbanization @urbanization end |
#zip_code ⇒ Object
Required if ‘city` and `state` are not passed in. If included, must be formatted as a US ZIP or ZIP+4 (e.g. `94107`, `941072282`, `94107-2282`).
39 40 41 |
# File 'lib/lob/models/multi_line_address.rb', line 39 def zip_code @zip_code end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
56 57 58 |
# File 'lib/lob/models/multi_line_address.rb', line 56 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/lob/models/multi_line_address.rb', line 42 def self.attribute_map { :'recipient' => :'recipient', :'company' => :'company', :'primary_line' => :'primary_line', :'secondary_line' => :'secondary_line', :'urbanization' => :'urbanization', :'city' => :'city', :'state' => :'state', :'zip_code' => :'zip_code' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
305 306 307 |
# File 'lib/lob/models/multi_line_address.rb', line 305 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 79 80 |
# File 'lib/lob/models/multi_line_address.rb', line 75 def self.openapi_nullable Set.new([ :'recipient', :'company', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/lob/models/multi_line_address.rb', line 61 def self.openapi_types { :'recipient' => :'String', :'company' => :'String', :'primary_line' => :'String', :'secondary_line' => :'String', :'urbanization' => :'String', :'city' => :'String', :'state' => :'String', :'zip_code' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/lob/models/multi_line_address.rb', line 276 def ==(o) return true if self.equal?(o) self.class == o.class && recipient == o.recipient && company == o.company && primary_line == o.primary_line && secondary_line == o.secondary_line && urbanization == o.urbanization && city == o.city && state == o.state && zip_code == o.zip_code end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/lob/models/multi_line_address.rb', line 344 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Lob.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
415 416 417 418 419 420 421 422 423 424 425 426 427 |
# File 'lib/lob/models/multi_line_address.rb', line 415 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/lob/models/multi_line_address.rb', line 312 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) # // guardrails-disable-line elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line end elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array) for base_type in type do res = _deserialize(base_type, attributes[self.class.attribute_map[key]]) if !res.nil? self.send("#{key}=", res) # // guardrails-disable-line break end end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line end end self end |
#eql?(o) ⇒ Boolean
291 292 293 |
# File 'lib/lob/models/multi_line_address.rb', line 291 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
297 298 299 |
# File 'lib/lob/models/multi_line_address.rb', line 297 def hash [recipient, company, primary_line, secondary_line, urbanization, city, state, zip_code].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/lob/models/multi_line_address.rb', line 132 def list_invalid_properties invalid_properties = Array.new if !@recipient.nil? && @recipient.to_s.length > 500 invalid_properties.push('invalid value for "recipient", the character length must be smaller than or equal to 500.') end if !@company.nil? && @company.to_s.length > 40 invalid_properties.push('invalid value for "company", the character length must be smaller than or equal to 40.') end if @primary_line.nil? invalid_properties.push('invalid value for "primary_line", primary_line cannot be nil.') end if @primary_line.to_s.length > 500 invalid_properties.push('invalid value for "primary_line", the character length must be smaller than or equal to 500.') end if !@secondary_line.nil? && @secondary_line.to_s.length > 500 invalid_properties.push('invalid value for "secondary_line", the character length must be smaller than or equal to 500.') end if !@urbanization.nil? && @urbanization.to_s.length > 500 invalid_properties.push('invalid value for "urbanization", the character length must be smaller than or equal to 500.') end if !@city.nil? && @city.to_s.length > 200 invalid_properties.push('invalid value for "city", the character length must be smaller than or equal to 200.') end if !@state.nil? && @state.to_s.length > 50 invalid_properties.push('invalid value for "state", the character length must be smaller than or equal to 50.') end pattern = Regexp.new(/^\d{5}((-)?\d{4})?$/) if !@zip_code.nil? && @zip_code !~ pattern invalid_properties.push("invalid value for \"zip_code\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
391 392 393 |
# File 'lib/lob/models/multi_line_address.rb', line 391 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
397 398 399 400 401 402 403 404 405 406 407 408 409 |
# File 'lib/lob/models/multi_line_address.rb', line 397 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) # // guardrails-disable-line if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
385 386 387 |
# File 'lib/lob/models/multi_line_address.rb', line 385 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/lob/models/multi_line_address.rb', line 176 def valid? return false if !@recipient.nil? && @recipient.to_s.length > 500 return false if !@company.nil? && @company.to_s.length > 40 return false if @primary_line.nil? return false if @primary_line.to_s.length > 500 return false if !@secondary_line.nil? && @secondary_line.to_s.length > 500 return false if !@urbanization.nil? && @urbanization.to_s.length > 500 return false if !@city.nil? && @city.to_s.length > 200 return false if !@state.nil? && @state.to_s.length > 50 return false if !@zip_code.nil? && @zip_code !~ Regexp.new(/^\d{5}((-)?\d{4})?$/) true end |