Class: Lob::QrCode
- Inherits:
-
Object
- Object
- Lob::QrCode
- Defined in:
- lib/lob/models/qr_code.rb
Overview
Customize and place a QR code on the creative at the required position.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#bottom ⇒ Object
Vertical distance(in inches) to place QR code from the bottom.
-
#left ⇒ Object
Horizonal distance(in inches) to place QR code from the left.
-
#position ⇒ Object
Sets how a QR code is being positioned in the document.
-
#redirect_url ⇒ Object
The url to redirect the user when a QR code is scanned.
-
#right ⇒ Object
Horizonal distance(in inches) to place QR code from the right.
-
#top ⇒ Object
Vertical distance(in inches) to place QR code from the top.
-
#width ⇒ Object
The size(in inches) of the QR code.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ QrCode
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ QrCode
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/lob/models/qr_code.rb', line 101 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::QrCode` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::QrCode`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'position') self.position = attributes[:'position'] end if attributes.key?(:'top') self.top = attributes[:'top'] end if attributes.key?(:'right') self.right = attributes[:'right'] end if attributes.key?(:'left') self.left = attributes[:'left'] end if attributes.key?(:'bottom') self.bottom = attributes[:'bottom'] end if attributes.key?(:'redirect_url') self.redirect_url = attributes[:'redirect_url'] end if attributes.key?(:'width') self.width = attributes[:'width'] end end |
Instance Attribute Details
#bottom ⇒ Object
Vertical distance(in inches) to place QR code from the bottom.
32 33 34 |
# File 'lib/lob/models/qr_code.rb', line 32 def bottom @bottom end |
#left ⇒ Object
Horizonal distance(in inches) to place QR code from the left.
29 30 31 |
# File 'lib/lob/models/qr_code.rb', line 29 def left @left end |
#position ⇒ Object
Sets how a QR code is being positioned in the document.
20 21 22 |
# File 'lib/lob/models/qr_code.rb', line 20 def position @position end |
#redirect_url ⇒ Object
The url to redirect the user when a QR code is scanned. The url must start with ‘https://`
35 36 37 |
# File 'lib/lob/models/qr_code.rb', line 35 def redirect_url @redirect_url end |
#right ⇒ Object
Horizonal distance(in inches) to place QR code from the right.
26 27 28 |
# File 'lib/lob/models/qr_code.rb', line 26 def right @right end |
#top ⇒ Object
Vertical distance(in inches) to place QR code from the top.
23 24 25 |
# File 'lib/lob/models/qr_code.rb', line 23 def top @top end |
#width ⇒ Object
The size(in inches) of the QR code. All QR codes are generated as a square.
38 39 40 |
# File 'lib/lob/models/qr_code.rb', line 38 def width @width end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/lob/models/qr_code.rb', line 76 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/lob/models/qr_code.rb', line 63 def self.attribute_map { :'position' => :'position', :'top' => :'top', :'right' => :'right', :'left' => :'left', :'bottom' => :'bottom', :'redirect_url' => :'redirect_url', :'width' => :'width' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
213 214 215 |
# File 'lib/lob/models/qr_code.rb', line 213 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
94 95 96 97 |
# File 'lib/lob/models/qr_code.rb', line 94 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/lob/models/qr_code.rb', line 81 def self.openapi_types { :'position' => :'String', :'top' => :'String', :'right' => :'String', :'left' => :'String', :'bottom' => :'String', :'redirect_url' => :'String', :'width' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/lob/models/qr_code.rb', line 185 def ==(o) return true if self.equal?(o) self.class == o.class && position == o.position && top == o.top && right == o.right && left == o.left && bottom == o.bottom && redirect_url == o.redirect_url && width == o.width end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/lob/models/qr_code.rb', line 252 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Lob.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/lob/models/qr_code.rb', line 323 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/lob/models/qr_code.rb', line 220 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) # // guardrails-disable-line elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line end elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array) for base_type in type do res = _deserialize(base_type, attributes[self.class.attribute_map[key]]) if !res.nil? self.send("#{key}=", res) # // guardrails-disable-line break end end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line end end self end |
#eql?(o) ⇒ Boolean
199 200 201 |
# File 'lib/lob/models/qr_code.rb', line 199 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
205 206 207 |
# File 'lib/lob/models/qr_code.rb', line 205 def hash [position, top, right, left, bottom, redirect_url, width].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/lob/models/qr_code.rb', line 145 def list_invalid_properties invalid_properties = Array.new if @position.nil? invalid_properties.push('invalid value for "position", position cannot be nil.') end if @redirect_url.nil? invalid_properties.push('invalid value for "redirect_url", redirect_url cannot be nil.') end if @width.nil? invalid_properties.push('invalid value for "width", width cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
299 300 301 |
# File 'lib/lob/models/qr_code.rb', line 299 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/lob/models/qr_code.rb', line 305 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) # // guardrails-disable-line if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
293 294 295 |
# File 'lib/lob/models/qr_code.rb', line 293 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
164 165 166 167 168 169 170 171 |
# File 'lib/lob/models/qr_code.rb', line 164 def valid? return false if @position.nil? position_validator = EnumAttributeValidator.new('String', ["fixed", "relative"]) return false unless position_validator.valid?(@position) return false if @redirect_url.nil? return false if @width.nil? true end |