Class: Lob::ReverseGeocodeLookupsApi
- Inherits:
-
Object
- Object
- Lob::ReverseGeocodeLookupsApi
- Defined in:
- lib/lob/api/reverse_geocode_lookups_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ReverseGeocodeLookupsApi
constructor
A new instance of ReverseGeocodeLookupsApi.
-
#lookup(location, opts = {}) ⇒ ReverseGeocode
lookup Reverse geocode a valid US location with a live API key.
-
#reverse_geocode_lookup_with_http_info(location, opts = {}) ⇒ Array<(ReverseGeocode, Integer, Hash)>
lookup Reverse geocode a valid US location with a live API key.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ReverseGeocodeLookupsApi
Returns a new instance of ReverseGeocodeLookupsApi.
19 20 21 |
# File 'lib/lob/api/reverse_geocode_lookups_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/lob/api/reverse_geocode_lookups_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#lookup(location, opts = {}) ⇒ ReverseGeocode
lookup Reverse geocode a valid US location with a live API key.
28 29 30 31 |
# File 'lib/lob/api/reverse_geocode_lookups_api.rb', line 28 def lookup(location, opts = {}) data, _status_code, _headers = reverse_geocode_lookup_with_http_info(location, opts) data end |
#reverse_geocode_lookup_with_http_info(location, opts = {}) ⇒ Array<(ReverseGeocode, Integer, Hash)>
lookup Reverse geocode a valid US location with a live API key.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/lob/api/reverse_geocode_lookups_api.rb', line 39 def reverse_geocode_lookup_with_http_info(location, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReverseGeocodeLookupsApi.reverse_geocode_lookup ...' end # verify the required parameter 'location' is set if @api_client.config.client_side_validation && location.nil? fail ArgumentError, "Missing the required parameter 'location' when calling ReverseGeocodeLookupsApi.reverse_geocode_lookup" end if @api_client.config.client_side_validation && !opts[:'size'].nil? && opts[:'size'] > 50 fail ArgumentError, 'invalid value for "opts[:"size"]" when calling ReverseGeocodeLookupsApi.reverse_geocode_lookup, must be smaller than or equal to 50.' end if @api_client.config.client_side_validation && !opts[:'size'].nil? && opts[:'size'] < 1 fail ArgumentError, 'invalid value for "opts[:"size"]" when calling ReverseGeocodeLookupsApi.reverse_geocode_lookup, must be greater than or equal to 1.' end # resource path local_var_path = '/us_reverse_geocode_lookups' # query parameters query_params = opts[:query_params] || {} query_params[:'size'] = opts[:'size'] if !opts[:'size'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(location) # return_type return_type = opts[:debug_return_type] || 'ReverseGeocode' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ReverseGeocodeLookupsApi.reverse_geocode_lookup", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ReverseGeocodeLookupsApi#reverse_geocode_lookup\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |