Class: Lob::TrackingEventCertified
- Inherits:
-
Object
- Object
- Lob::TrackingEventCertified
- Defined in:
- lib/lob/models/tracking_event_certified.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#date_created ⇒ Object
A timestamp in ISO 8601 format of the date the resource was created.
-
#date_modified ⇒ Object
A timestamp in ISO 8601 format of the date the resource was last modified.
-
#details ⇒ Object
Returns the value of attribute details.
-
#id ⇒ Object
Unique identifier prefixed with ‘evnt_`.
-
#location ⇒ Object
The zip code in which the event occurred if it exists, otherwise will be the name of a Regional Distribution Center if it exists, otherwise will be null.
-
#name ⇒ Object
Name of tracking event for Certified letters.
-
#object ⇒ Object
Returns the value of attribute object.
-
#time ⇒ Object
A timestamp in ISO 8601 format of the date USPS registered the event.
-
#type ⇒ Object
a Certified letter tracking event.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TrackingEventCertified
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ TrackingEventCertified
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/lob/models/tracking_event_certified.rb', line 109 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lob::TrackingEventCertified` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lob::TrackingEventCertified`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'details') self.details = attributes[:'details'] end if attributes.key?(:'location') self.location = attributes[:'location'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'time') self.time = attributes[:'time'] end if attributes.key?(:'date_created') self.date_created = attributes[:'date_created'] end if attributes.key?(:'date_modified') self.date_modified = attributes[:'date_modified'] end if attributes.key?(:'object') self.object = attributes[:'object'] else self.object = 'tracking_event' end end |
Instance Attribute Details
#date_created ⇒ Object
A timestamp in ISO 8601 format of the date the resource was created.
36 37 38 |
# File 'lib/lob/models/tracking_event_certified.rb', line 36 def date_created @date_created end |
#date_modified ⇒ Object
A timestamp in ISO 8601 format of the date the resource was last modified.
39 40 41 |
# File 'lib/lob/models/tracking_event_certified.rb', line 39 def date_modified @date_modified end |
#details ⇒ Object
Returns the value of attribute details.
24 25 26 |
# File 'lib/lob/models/tracking_event_certified.rb', line 24 def details @details end |
#id ⇒ Object
Unique identifier prefixed with ‘evnt_`.
30 31 32 |
# File 'lib/lob/models/tracking_event_certified.rb', line 30 def id @id end |
#location ⇒ Object
The zip code in which the event occurred if it exists, otherwise will be the name of a Regional Distribution Center if it exists, otherwise will be null.
27 28 29 |
# File 'lib/lob/models/tracking_event_certified.rb', line 27 def location @location end |
#name ⇒ Object
Name of tracking event for Certified letters. Letters sent with USPS Certified Mail are fully tracked by USPS, therefore their tracking events have an additional details object with more detailed information about the tracking event. Some certified tracking event names have multiple meanings, noted in the list here. See the description of the details object for the full set of combined certified tracking event name meanings. * ‘Mailed` - Package has been accepted into the carrier network for delivery. * `In Transit` - Maps to four distinct stages of transit. * `In Local Area` - Package is at a location near the end destination. * `Processed for Delivery` - Maps to two distinct stages of delivery. * `Pickup Available` - Package is available for pickup at carrier location. * `Delivered` - Package has been delivered. * `Re-Routed` - Package has been forwarded. * `Returned to Sender` - Package is to be returned to sender. * `Issue` - Maps to (at least) 15 possible issues, some of which are actionable.
22 23 24 |
# File 'lib/lob/models/tracking_event_certified.rb', line 22 def name @name end |
#object ⇒ Object
Returns the value of attribute object.
41 42 43 |
# File 'lib/lob/models/tracking_event_certified.rb', line 41 def object @object end |
#time ⇒ Object
A timestamp in ISO 8601 format of the date USPS registered the event.
33 34 35 |
# File 'lib/lob/models/tracking_event_certified.rb', line 33 def time @time end |
#type ⇒ Object
a Certified letter tracking event
19 20 21 |
# File 'lib/lob/models/tracking_event_certified.rb', line 19 def type @type end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
81 82 83 |
# File 'lib/lob/models/tracking_event_certified.rb', line 81 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/lob/models/tracking_event_certified.rb', line 66 def self.attribute_map { :'type' => :'type', :'name' => :'name', :'details' => :'details', :'location' => :'location', :'id' => :'id', :'time' => :'time', :'date_created' => :'date_created', :'date_modified' => :'date_modified', :'object' => :'object' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
293 294 295 |
# File 'lib/lob/models/tracking_event_certified.rb', line 293 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 105 |
# File 'lib/lob/models/tracking_event_certified.rb', line 101 def self.openapi_nullable Set.new([ :'location', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/lob/models/tracking_event_certified.rb', line 86 def self.openapi_types { :'type' => :'String', :'name' => :'String', :'details' => :'TrackingEventDetails', :'location' => :'String', :'id' => :'String', :'time' => :'Time', :'date_created' => :'Time', :'date_modified' => :'Time', :'object' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/lob/models/tracking_event_certified.rb', line 263 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && name == o.name && details == o.details && location == o.location && id == o.id && time == o.time && date_created == o.date_created && date_modified == o.date_modified && object == o.object end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'lib/lob/models/tracking_event_certified.rb', line 332 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Lob.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
403 404 405 406 407 408 409 410 411 412 413 414 415 |
# File 'lib/lob/models/tracking_event_certified.rb', line 403 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/lob/models/tracking_event_certified.rb', line 300 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) # // guardrails-disable-line elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) # // guardrails-disable-line end elsif !attributes[self.class.attribute_map[key]].nil? && type.kind_of?(Array) for base_type in type do res = _deserialize(base_type, attributes[self.class.attribute_map[key]]) if !res.nil? self.send("#{key}=", res) # // guardrails-disable-line break end end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) # // guardrails-disable-line end end self end |
#eql?(o) ⇒ Boolean
279 280 281 |
# File 'lib/lob/models/tracking_event_certified.rb', line 279 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
285 286 287 |
# File 'lib/lob/models/tracking_event_certified.rb', line 285 def hash [type, name, details, location, id, time, date_created, date_modified, object].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/lob/models/tracking_event_certified.rb', line 163 def list_invalid_properties invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end pattern = Regexp.new(/^evnt_[a-zA-Z0-9]+$/) if @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end if @date_created.nil? invalid_properties.push('invalid value for "date_created", date_created cannot be nil.') end if @date_modified.nil? invalid_properties.push('invalid value for "date_modified", date_modified cannot be nil.') end if @object.nil? invalid_properties.push('invalid value for "object", object cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
379 380 381 |
# File 'lib/lob/models/tracking_event_certified.rb', line 379 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/lob/models/tracking_event_certified.rb', line 385 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) # // guardrails-disable-line if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
373 374 375 |
# File 'lib/lob/models/tracking_event_certified.rb', line 373 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/lob/models/tracking_event_certified.rb', line 199 def valid? return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["certified"]) return false unless type_validator.valid?(@type) return false if @name.nil? name_validator = EnumAttributeValidator.new('String', ["Mailed", "In Transit", "In Local Area", "Processed for Delivery", "Pickup Available", "Delivered", "Re-Routed", "Returned to Sender", "Issue"]) return false unless name_validator.valid?(@name) return false if @id.nil? return false if @id !~ Regexp.new(/^evnt_[a-zA-Z0-9]+$/) return false if @date_created.nil? return false if @date_modified.nil? return false if @object.nil? object_validator = EnumAttributeValidator.new('String', ["tracking_event"]) return false unless object_validator.valid?(@object) true end |